/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Timer = void 0;
class Timer {
    constructor(callback, delay) {
        this.timerId = null;
        this.startTime = null;
        this._status = 'stopped';
        this.callback = callback;
        this.delay = delay;
        this.remaining = delay;
        this.resume();
    }
    get status() {
        return this._status;
    }
    set status(status) {
        this._status = status;
    }
    reset() {
        this.clear();
        this.remaining = this.delay;
        this.status = 'stopped';
    }
    pause() {
        if (this.timerId === null || this.startTime === null) {
            return;
        }
        this.clear();
        this.remaining -= Date.now() - this.startTime;
        this.status = 'paused';
    }
    resume() {
        if (this.timerId !== null)
            return;
        this.startTime = Date.now();
        this.clear();
        this.timerId = setTimeout(() => {
            this.reset();
            this.callback();
        }, this.remaining);
        this.status = 'running';
    }
    clear() {
        if (this.timerId === null) {
            return;
        }
        clearTimeout(this.timerId);
        this.timerId = null;
    }
}
exports.Timer = Timer;

        