/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useWarn = void 0;
const react_1 = require("react");
const warnings_1 = require("../../utils/warnings");
const use_event_1 = require("./use-event");
const GLOBAL_WARNED = new Set();
function useWarn(condition, params) {
    const { once = true, key, args } = params;
    const hasWarnedRef = (0, react_1.useRef)(false);
    const execute = (0, use_event_1.useEvent)((condition, args) => {
        if (condition) {
            (0, warnings_1.warn)(...args);
            return true;
        }
        return false;
    });
    if (once) {
        const keyString = JSON.stringify(key);
        if (GLOBAL_WARNED.has(keyString))
            return;
        if (execute(condition, args)) {
            GLOBAL_WARNED.add(keyString);
            return;
        }
    }
    if (hasWarnedRef.current)
        return;
    if (execute(condition, args)) {
        hasWarnedRef.current = true;
        return;
    }
}
exports.useWarn = useWarn;

        