/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Root = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const overlays_1 = require("@react-aria/overlays");
const styled_components_1 = require("styled-components");
const react_2 = require("@jengaicons/react");
const tasty_1 = require("../tasty");
const provider_1 = require("../provider");
const tokens_1 = require("../tokens");
const react_3 = require("../utils/react");
const TrackingProvider_1 = require("../providers/TrackingProvider");
const portal_1 = require("./portal");
const GlobalStyles_1 = require("./GlobalStyles");
const AlertDialog_1 = require("./overlays/AlertDialog");
const NewNotifications_1 = require("./overlays/NewNotifications");
const RootElement = (0, tasty_1.tasty)({
    id: 'jenga-ui-kit-root',
    className: 'root',
});
const DEFAULT_STYLES = {
    display: 'block',
    preset: 't3',
    ...Object.keys(tokens_1.TOKENS).reduce((map, key) => {
        map[`@${key}`] = tokens_1.TOKENS[key];
        return map;
    }, {}),
};
const STYLES = [...tasty_1.BASE_STYLES, ...tasty_1.BLOCK_STYLES];
const IS_DVH_SUPPORTED = typeof CSS !== 'undefined' && typeof CSS?.supports === 'function'
    ? CSS.supports('height: 100dvh')
    : false;
function Root(allProps) {
    let { children, 
    /** Raw css styles for body element */
    bodyStyles, fonts, publicUrl, router, font, monospaceFont, applyLegacyTokens, tracking, ...props } = allProps;
    const ref = (0, react_1.useRef)(null);
    const [rootRef, setRootRef] = (0, react_1.useState)();
    // We need to measure the window's height in JS rather than using percentages in CSS
    // so that contents (e.g. menu) can inherit the max-height properly. Using percentages
    // does not work properly because there is nothing to base the percentage on.
    // We cannot use vh units because mobile browsers adjust the window height dynamically
    // when the address bar/bottom toolbars show and hide on scroll and vh units are fixed.
    // Also, the visual viewport is smaller than the layout viewport when the virtual keyboard
    // is up, so use the VisualViewport API to ensure the tray is displayed above the keyboard.
    let viewport = (0, react_3.useViewportSize)({ isDisabled: IS_DVH_SUPPORTED });
    let [height, setHeight] = (0, react_1.useState)(IS_DVH_SUPPORTED ? undefined : viewport.height);
    let timeoutRef = (0, react_1.useRef)();
    (0, react_1.useEffect)(() => {
        if (IS_DVH_SUPPORTED && typeof window !== 'undefined') {
            return;
        }
        if (timeoutRef.current) {
            clearTimeout(timeoutRef.current);
        }
        // When the height is decreasing, and the keyboard is visible
        // (visual viewport smaller than layout viewport), delay setting
        // the new max height until after the animation is complete
        // so that there isn't an empty space under the tray briefly.
        if (viewport.height < (height || 0) &&
            viewport.height < window.innerHeight) {
            timeoutRef.current = setTimeout(() => {
                setHeight(viewport.height);
            }, 500);
        }
        else {
            setHeight(viewport.height);
        }
    }, [height, viewport.height]);
    (0, react_1.useEffect)(() => {
        if (!rootRef) {
            // @ts-ignore
            setRootRef(ref?.current);
        }
    }, []);
    const styles = (0, tasty_1.extractStyles)(props, STYLES, DEFAULT_STYLES);
    return ((0, jsx_runtime_1.jsx)(provider_1.Provider, { router: router, root: rootRef, children: (0, jsx_runtime_1.jsx)(TrackingProvider_1.TrackingProvider, { event: tracking?.event, children: (0, jsx_runtime_1.jsx)(styled_components_1.StyleSheetManager, { enableVendorPrefixes: false, children: (0, jsx_runtime_1.jsxs)(RootElement, { ref: ref, ...(0, tasty_1.filterBaseProps)(props, { eventProps: true }), styles: styles, style: {
                        '--jenga-dynamic-viewport-height': height
                            ? height + 'px'
                            : '100dvh',
                    }, children: [(0, jsx_runtime_1.jsx)(GlobalStyles_1.GlobalStyles, { bodyStyles: bodyStyles, applyLegacyTokens: applyLegacyTokens, publicUrl: publicUrl, fonts: fonts, font: font, monospaceFont: monospaceFont }, void 0), (0, jsx_runtime_1.jsx)(overlays_1.ModalProvider, { children: (0, jsx_runtime_1.jsx)(portal_1.PortalProvider, { value: ref, children: (0, jsx_runtime_1.jsx)(NewNotifications_1.NotificationsProvider, { rootRef: ref, children: (0, jsx_runtime_1.jsx)(AlertDialog_1.AlertDialogApiProvider, { children: (0, jsx_runtime_1.jsx)(react_2.JengaIconContext.Provider, { value: {
                                                size: '1rem',
                                                color: 'currentColor',
                                            }, children: children }, void 0) }, void 0) }, void 0) }, void 0) }, void 0)] }, void 0) }, void 0) }, void 0) }, void 0));
}
exports.Root = Root;

        