/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAction = exports.performClickHandler = exports.parseTo = exports.openLink = void 0;
const react_1 = require("react");
const interactions_1 = require("@react-aria/interactions");
const button_1 = require("@react-aria/button");
const utils_1 = require("@react-spectrum/utils");
const provider_1 = require("../../provider");
const react_2 = require("../../utils/react");
const interactions_2 = require("../../utils/react/interactions");
const tasty_1 = require("../../tasty");
const TrackingProvider_1 = require("../../providers/TrackingProvider");
const _internal_1 = require("../../_internal");
const LINK_PRESS_EVENT = 'Link Press';
const BUTTON_PRESS_EVENT = 'Button Press';
const FILTER_OPTIONS = { propNames: new Set(['onMouseEnter', 'onMouseLeave']) };
/**
 * Helper to open link.
 * @param {String} href
 * @param {String|Boolean} [target]
 */
function openLink(href, target) {
    const link = document.createElement('a');
    link.href = href;
    if (target) {
        link.target = target === true ? '_blank' : target;
    }
    document.body.appendChild(link);
    link.click();
    document.body.removeChild(link);
}
exports.openLink = openLink;
function parseTo(to) {
    const newTab = to && typeof to === 'string' && to.startsWith('!');
    const nativeRoute = to && typeof to === 'string' && to.startsWith('@');
    const href = to && typeof to === 'string'
        ? newTab || nativeRoute
            ? to.slice(1)
            : to
        : undefined;
    return {
        newTab,
        nativeRoute,
        href,
    };
}
exports.parseTo = parseTo;
function performClickHandler(evt, { router, to, onPress, tracking }) {
    const { newTab, nativeRoute, href } = parseTo(to);
    const element = evt.target;
    const qa = element?.getAttribute('data-qa');
    onPress?.(evt);
    if (!to) {
        tracking.event(BUTTON_PRESS_EVENT, { qa }, element);
        return;
    }
    if (evt.shiftKey || evt.metaKey || newTab) {
        openLink(href, true);
        tracking.event(LINK_PRESS_EVENT, { qa, href, type: 'tab' }, element);
        return;
    }
    if (nativeRoute) {
        openLink(href || window.location.href);
        tracking.event(LINK_PRESS_EVENT, { qa, href, type: 'native' }, element);
    }
    else if (href && href.startsWith('#')) {
        const id = href.slice(1);
        const element = document.getElementById(id);
        tracking.event(LINK_PRESS_EVENT, { qa, href, type: 'hash', target: id }, element);
        if (element) {
            element.scrollIntoView({
                behavior: 'smooth',
                block: 'start',
                inline: 'nearest',
            });
            return;
        }
    }
    if (router) {
        tracking.event(LINK_PRESS_EVENT, { qa, href, type: 'router' }, element);
        router.push(href);
    }
    else if (href) {
        tracking.event(LINK_PRESS_EVENT, { qa, href, type: 'native' }, element);
        window.location.href = href;
    }
}
exports.performClickHandler = performClickHandler;
const useAction = function useAction({ to, as, htmlType, label, mods, onPress, ...props }, ref) {
    as = to ? 'a' : as || 'button';
    const tracking = (0, TrackingProvider_1.useTracking)();
    const router = (0, react_1.useContext)(provider_1.UIKitContext).router;
    const isDisabled = props.isDisabled;
    const { newTab, href } = parseTo(to);
    const target = newTab ? '_blank' : undefined;
    const domRef = (0, utils_1.useFocusableRef)(ref);
    const customOnPress = (0, _internal_1.useEvent)((evt) => {
        performClickHandler(evt, { router, to, onPress, tracking });
    });
    let { buttonProps, isPressed } = (0, button_1.useButton)({
        'aria-label': label,
        ...props,
        onPress: customOnPress,
    }, domRef);
    let { hoverProps, isHovered } = (0, interactions_1.useHover)({ isDisabled });
    let { focusProps, isFocused } = (0, interactions_2.useFocus)({ isDisabled }, true);
    const customProps = to
        ? {
            onClick(evt) {
                evt.preventDefault();
            },
        }
        : {};
    return {
        actionProps: {
            mods: {
                hovered: isHovered && !isDisabled,
                pressed: isPressed && !isDisabled,
                focused: isFocused && !isDisabled,
                disabled: isDisabled,
                ...mods,
            },
            ...(0, react_2.mergeProps)(buttonProps, hoverProps, focusProps, customProps, (0, tasty_1.filterBaseProps)(props, FILTER_OPTIONS)),
            ref: domRef,
            type: htmlType || 'button',
            rel: as === 'a' && newTab ? 'rel="noopener noreferrer"' : undefined,
            as,
            isDisabled,
            target,
            href,
        },
    };
};
exports.useAction = useAction;

        