/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CopySnippet = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_2 = require("@jengaicons/react");
const clipboard_copy_1 = __importDefault(require("clipboard-copy"));
const actions_1 = require("../../actions");
const Card_1 = require("../Card/Card");
const tasty_1 = require("../../../tasty");
const PrismCode_1 = require("../../content/PrismCode/PrismCode");
const TooltipTrigger_1 = require("../../overlays/Tooltip/TooltipTrigger");
const Tooltip_1 = require("../../overlays/Tooltip/Tooltip");
const Toasts_1 = require("../../overlays/Toasts");
const ActionElement = (0, tasty_1.tasty)(actions_1.Action, {
    styles: {
        display: 'block',
        cursor: 'default',
        width: '100%',
    },
});
const StyledBlock = (0, tasty_1.tasty)({
    styles: {
        position: 'relative',
        overflow: {
            '': 'hidden',
            scroll: 'auto hidden',
        },
        maxWidth: '100%',
        whiteSpace: {
            '': 'initial',
            nowrap: 'nowrap',
        },
        styledScrollbar: true,
        '& code': {
            font: {
                '': 'monospace',
                serif: true,
            },
        },
    },
});
const ButtonContainer = (0, tasty_1.tasty)({
    styles: {
        position: 'relative',
        display: 'grid',
        gridAutoFlow: 'column',
        margin: '(-1x - 1bw) -1.5x (-1x - 1bw) -1x',
        '&::after': {
            display: {
                '': 'none',
                overlay: 'block',
            },
            content: '""',
            width: '2x',
            position: 'absolute',
            left: '-1x',
            top: 0,
            bottom: 0,
            backgroundImage: 'linear-gradient(to right,rgba(var(--context-fill-color-rgb),0),rgba(var(--context-fill-color-rgb),1))',
        },
    },
});
const CopySnippetElement = (0, tasty_1.tasty)(Card_1.Card, {
    qa: 'CopySnippet',
    styles: {
        display: 'block',
        fill: '#grey-light',
        radius: '1r',
        border: 0,
        padding: 0,
        Grid: {
            display: 'grid',
            flow: 'row',
            gridColumns: 'minmax(0, 1fr) auto',
            width: 'min 20x',
            radius: '1r',
            position: 'relative',
            overflow: 'hidden',
        },
    },
});
const ActionButton = (0, tasty_1.tasty)(actions_1.Button, {
    type: 'clear',
    styles: {
        padding: '1x 1.5x',
        radius: 0,
        placeSelf: {
            '': 'none',
            '!multiline & !with-scroll': 'stretch',
        },
        border: '#clear',
        outline: {
            '': '#purple-03.0',
            'focused & focus-visible': '#purple-03 inset',
        },
    },
});
const CopyButton = (0, tasty_1.tasty)(ActionButton, {
    icon: (0, jsx_runtime_1.jsx)(react_2.Copy, {}, void 0),
    'aria-label': 'Copy to clipboard',
    styles: {
        radius: {
            '': '0 1r 1r 0',
            'multiline | with-scroll': '0 1r 0 0',
        },
    },
});
const ShowButton = (0, tasty_1.tasty)(ActionButton, {
    'aria-label': 'Show hidden parts',
    styles: {
        radius: 0,
    },
});
// const HIDDEN_SYMBOL = '●';
const HIDDEN_SYMBOL = '•';
function CopySnippet(allProps) {
    const { code = '', title = 'Code example', nowrap, prefix = '', language, showScroll = true, serif, actions, padding = '1.125x 1.5x', showOverlay = true, showTooltip = false, styles, hideText, ...props } = allProps;
    const { toast } = (0, Toasts_1.useToastsApi)();
    const [showHidden, setShowHidden] = (0, react_1.useState)(false);
    async function onCopy() {
        await (0, clipboard_copy_1.default)(code);
        toast.success(`${title} copied`);
    }
    const pristineCode = code.replace(/\n$/, '');
    const multiline = pristineCode.includes('\n') && !nowrap;
    let formattedCode = pristineCode
        .split(/\n/g)
        .map((line) => `${prefix}${line} `)
        .join('\n');
    if (!showHidden) {
        if (hideText === true) {
            formattedCode = formattedCode
                .split('')
                .map((s) => HIDDEN_SYMBOL)
                .join('');
        }
        else if (typeof hideText === 'string') {
            formattedCode = formattedCode.replaceAll(hideText, hideText
                .split('')
                .map((s) => HIDDEN_SYMBOL)
                .join(''));
        }
        else if (Array.isArray(hideText)) {
            hideText.forEach((text) => {
                formattedCode = formattedCode.replaceAll(text, text
                    .split('')
                    .map((s) => HIDDEN_SYMBOL)
                    .join(''));
            });
        }
    }
    const Snippet = ((0, jsx_runtime_1.jsx)(CopySnippetElement, { styles: { preset: 'default', ...styles }, ...props, children: (0, jsx_runtime_1.jsxs)("div", { "data-element": "Grid", children: [(0, jsx_runtime_1.jsx)(StyledBlock, { mods: { nowrap, multiline, scroll: showScroll, serif }, styles: { padding }, children: (0, jsx_runtime_1.jsx)(PrismCode_1.PrismCode, { style: { margin: 0, overflow: 'visible' }, code: formattedCode, language: language || 'javascript' }, void 0) }, void 0), (0, jsx_runtime_1.jsxs)(ButtonContainer, { styles: { padding }, mods: { overlay: showOverlay }, children: [actions, hideText && ((0, jsx_runtime_1.jsx)(ShowButton, { icon: showHidden ? (0, jsx_runtime_1.jsx)(react_2.EyeSlash, {}, void 0) : (0, jsx_runtime_1.jsx)(react_2.Eye, {}, void 0), mods: { multiline, withScroll: showScroll }, onPress: () => setShowHidden(!showHidden) }, void 0)), (0, jsx_runtime_1.jsx)(CopyButton, { "aria-label": `Copy ${title}`, mods: { multiline, withScroll: showScroll, hidden: !!hideText }, onPress: onCopy }, void 0)] }, void 0)] }, void 0) }, void 0));
    if (showTooltip) {
        return ((0, jsx_runtime_1.jsxs)(TooltipTrigger_1.TooltipTrigger, { children: [(0, jsx_runtime_1.jsx)(ActionElement, { children: Snippet }, void 0), (0, jsx_runtime_1.jsx)(Tooltip_1.Tooltip, { children: formattedCode }, void 0)] }, void 0));
    }
    return Snippet;
}
const _CopySnippet = Object.assign(CopySnippet, {
    Button: ActionButton,
});
exports.CopySnippet = _CopySnippet;

        