/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Result = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_2 = require("@jengaicons/react");
const Title_1 = require("../Title");
const tasty_1 = require("../../../tasty");
const react_3 = require("../../../utils/react");
const Container = (0, tasty_1.tasty)({
    qa: 'Result_Container',
    as: 'section',
    styles: {
        display: 'flex',
        flow: 'column',
        placeItems: 'center',
        gap: '3x',
        padding: '6x 4x',
        textAlign: 'center',
        Content: {
            display: 'block',
        },
        Title: {
            display: 'flex',
            flow: 'column',
            placeItems: 'inherit',
            gap: '1x',
        },
    },
});
const IconWrapper = (0, tasty_1.tasty)({
    styles: {
        fontSize: '10x',
    },
});
const statusIconMap = {
    success: {
        color: '#success',
        component: react_2.CheckCircleFill,
    },
    error: {
        color: '#danger',
        component: react_2.XCircleFill,
    },
    info: {
        color: '#purple',
        component: react_2.InfoFill,
    },
    warning: {
        color: '#note',
        component: react_2.WarningFill,
    },
    404: {
        color: '#purple',
        component: () => {
            // TODO: Needs to be implemented in the future
            return null;
        },
    },
    403: {
        color: '#purple',
        component: () => {
            // TODO: Needs to be implemented in the future
            return null;
        },
    },
    500: {
        color: '#purple',
        component: () => {
            // TODO: Needs to be implemented in the future
            return null;
        },
    },
};
function Result(props, ref) {
    let { children, icon, status, subTitle, subtitle, title, ...otherProps } = props;
    subtitle = subtitle ?? subTitle;
    if (icon && status) {
        console.warn('Don\'t use "icon" and "status" together, it can lead to possible errors.');
    }
    const iconNode = (0, react_1.useMemo)(() => {
        if (icon) {
            return icon;
        }
        const { color, component: Component } = status && statusIconMap.hasOwnProperty(status)
            ? statusIconMap[status]
            : statusIconMap.info;
        return ((0, jsx_runtime_1.jsx)(IconWrapper, { "data-element": "IconWrapper", styles: { color }, children: (0, jsx_runtime_1.jsx)(Component, { "data-element": "Icon" }, void 0) }, void 0));
    }, [icon, status]);
    const styles = (0, tasty_1.extractStyles)(otherProps, tasty_1.CONTAINER_STYLES);
    return ((0, jsx_runtime_1.jsxs)(Container, { ...(0, tasty_1.filterBaseProps)(otherProps, { eventProps: true }), ref: ref, styles: styles, children: [iconNode, (title || subtitle) && ((0, jsx_runtime_1.jsxs)("div", { "data-element": "Title", children: [(0, react_3.wrapNodeIfPlain)(title, () => ((0, jsx_runtime_1.jsx)(Title_1.Title, { level: 2, preset: "h4", children: title }, void 0))), (0, react_3.wrapNodeIfPlain)(subtitle, () => ((0, jsx_runtime_1.jsx)(Title_1.Title, { level: 3, preset: "t2m", children: subtitle }, void 0)))] }, void 0)), children && (0, jsx_runtime_1.jsx)("div", { "data-element": "Content", children: children }, void 0)] }, void 0));
}
const _Result = (0, react_1.forwardRef)(Result);
exports.Result = _Result;

        