/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Text = exports.TEXT_PROP_MAP = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tasty_1 = require("../../tasty");
const react_2 = require("../../utils/react");
const STYLE_LIST = [...tasty_1.BASE_STYLES, ...tasty_1.TEXT_STYLES, ...tasty_1.COLOR_STYLES];
exports.TEXT_PROP_MAP = {
    transform: 'textTransform',
    weight: 'fontWeight',
    italic: 'fontStyle',
};
const TextElement = (0, tasty_1.tasty)({
    qa: 'Text',
    as: 'span',
    styles: {
        display: {
            '': 'inline',
            ellipsis: 'block',
        },
        margin: '0',
        whiteSpace: {
            '': 'inherit',
            'nowrap | ellipsis': 'nowrap',
        },
        textOverflow: {
            '': false,
            ellipsis: 'ellipsis',
        },
        overflow: {
            '': false,
            ellipsis: 'hidden',
        },
        width: {
            '': false,
            ellipsis: 'max 100%',
        },
    },
});
const _Text = (0, react_1.forwardRef)(function Text(allProps, ref) {
    allProps = (0, react_2.useSlotProps)(allProps, 'text');
    const { as, qa, block, styleName, ellipsis, nowrap, ...props } = allProps;
    const styles = (0, tasty_1.extractStyles)(props, STYLE_LIST, {}, exports.TEXT_PROP_MAP);
    return ((0, jsx_runtime_1.jsx)(TextElement, { as: as || 'span', qa: qa || 'Text', styleName: styleName, mods: {
            nowrap,
            ellipsis,
        }, block: !!(block || ellipsis), ...(0, tasty_1.filterBaseProps)(props, { eventProps: true }), ref: ref, styles: styles }, void 0));
});
const Text = Object.assign(_Text, {
    Minor: (0, react_1.forwardRef)(function MinorText(props, ref) {
        return (0, jsx_runtime_1.jsx)(_Text, { ref: ref, color: "#minor", ...props }, void 0);
    }),
    Danger: (0, react_1.forwardRef)(function DangerText(props, ref) {
        return (0, jsx_runtime_1.jsx)(_Text, { ref: ref, role: "alert", color: "#danger-text", ...props }, void 0);
    }),
    Success: (0, react_1.forwardRef)(function SuccessText(props, ref) {
        return (0, jsx_runtime_1.jsx)(_Text, { ref: ref, color: "#success-text", ...props }, void 0);
    }),
    Strong: (0, react_1.forwardRef)(function StrongText(props, ref) {
        return ((0, jsx_runtime_1.jsx)(_Text, { ref: ref, as: "strong", preset: "strong", color: "#dark", ...props }, void 0));
    }),
    Emphasis: (0, react_1.forwardRef)(function EmphasisText(props, ref) {
        return (0, jsx_runtime_1.jsx)(_Text, { ref: ref, as: "em", preset: "em", ...props }, void 0);
    }),
    Selection: (0, react_1.forwardRef)(function SelectionText(props, ref) {
        return (0, jsx_runtime_1.jsx)(_Text, { ref: ref, color: "#dark", fill: "#note.30", ...props }, void 0);
    }),
});
exports.Text = Text;

        