/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Checkbox = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const utils_1 = require("@react-spectrum/utils");
const react_1 = require("react");
const checkbox_1 = require("@react-aria/checkbox");
const interactions_1 = require("@react-aria/interactions");
const toggle_1 = require("@react-stately/toggle");
const provider_1 = require("../../../provider");
const tasty_1 = require("../../../tasty");
const interactions_2 = require("../../../utils/react/interactions");
const react_2 = require("../../../utils/react");
const Label_1 = require("../Label");
const HiddenInput_1 = require("../../HiddenInput");
const Form_1 = require("../Form");
const FieldWrapper_1 = require("../FieldWrapper");
const nullableValue_1 = require("../../../utils/react/nullableValue");
const Text_1 = require("../../content/Text");
const CheckboxGroup_1 = require("./CheckboxGroup");
const context_1 = require("./context");
function Check() {
    return ((0, jsx_runtime_1.jsx)("svg", { width: "10", height: "8", xmlns: "http://www.w3.org/2000/svg", children: (0, jsx_runtime_1.jsx)("path", { d: "M3.417 7.604l-.017.018-3.4-3.4 1.433-1.433 1.985 1.985L8.192 0l1.432 1.433-6.189 6.189-.018-.018z", fill: "currentColor" }, void 0) }, void 0));
}
function IndeterminateOutline() {
    return ((0, jsx_runtime_1.jsx)("svg", { width: "9", height: "3", fill: "none", xmlns: "http://www.w3.org/2000/svg", children: (0, jsx_runtime_1.jsx)("path", { d: "M0 .044v2.001l.026.025h8.063V.044H0z" }, void 0) }, void 0));
}
const CheckboxWrapperElement = (0, tasty_1.tasty)({
    as: 'label',
    qa: 'CheckboxWrapper',
    styles: {
        position: 'relative',
        display: 'flex',
        placeItems: 'center start',
        placeContent: 'baseline',
        gap: '1x',
        flow: 'row',
        preset: 'default',
        cursor: 'pointer',
    },
});
const CheckboxElement = (0, tasty_1.tasty)({
    qa: 'Checkbox',
    styles: {
        display: 'grid',
        placeItems: 'center',
        radius: '0.5x',
        fill: {
            '': '#op-surface',
            'checked | indeterminate': '#op-surface-primary',
            'invalid & checked': '#op-text-critical',
        },
        color: {
            '': '#op-surface',
            checked: '#op-surface',
            'disabled & !checked & !indeterminate': '#clear',
        },
        border: {
            '': '#op-border',
            invalid: '#op-border-critical',
            'disabled | ((indeterminate | checked) & !invalid)': '#clear',
        },
        cursor: {
            disabled: 'not-allowed',
        },
        width: '2.5x',
        height: '2.5x',
        outline: {
            '': '#clear',
            focused: '#op-border-focus',
        },
        transition: 'theme',
        opacity: {
            '': 1,
            disabled: 0.5,
        },
    },
});
function Checkbox(props, ref) {
    // Swap hooks depending on whether this checkbox is inside a CheckboxGroup.
    // This is a bit unorthodox. Typically, hooks cannot be called in a conditional,
    // but since the checkbox won't move in and out of a group, it should be safe.
    let groupState = (0, react_1.useContext)(context_1.CheckboxGroupContext);
    props = (0, nullableValue_1.castNullableIsSelected)(props);
    let originalProps = props;
    props = (0, provider_1.useProviderProps)(props);
    props = (0, Form_1.useFormProps)(props);
    props = (0, Form_1.useFieldProps)(props, {
        defaultValidationTrigger: 'onChange',
        valuePropsMapper: ({ value, onChange }) => ({
            isSelected: value ?? false,
            isIndeterminate: false,
            onChange: onChange,
        }),
        unsafe__isDisabled: !!groupState,
    });
    let { qa, isIndeterminate = false, isDisabled = false, insideForm, isRequired, autoFocus, children, label, extra, validationState, labelProps, labelStyles, labelPosition, necessityLabel, necessityIndicator, message, description, requiredMark = true, tooltip, isHidden, labelSuffix, ...otherProps } = props;
    let styles = (0, tasty_1.extractStyles)(props, tasty_1.OUTER_STYLES);
    let inputStyles = (0, tasty_1.extractStyles)(props, tasty_1.BLOCK_STYLES);
    labelStyles = {
        ...(insideForm && !groupState ? Label_1.LABEL_STYLES : Label_1.INLINE_LABEL_STYLES),
        ...labelStyles,
    };
    let { isFocused, focusProps } = (0, interactions_2.useFocus)({ isDisabled }, true);
    let { hoverProps, isHovered } = (0, interactions_1.useHover)({ isDisabled });
    let inputRef = (0, react_1.useRef)(null);
    let domRef = (0, utils_1.useFocusableRef)(ref, inputRef);
    const toggleState = (0, toggle_1.useToggleState)(props);
    let { inputProps } = groupState // eslint-disable-next-line react-hooks/rules-of-hooks
        ? (0, checkbox_1.useCheckboxGroupItem)({
            ...props,
            // Value is optional for standalone checkboxes, but required for CheckboxGroup items;
            // it's passed explicitly here to avoid typescript error (requires strictNullChecks disabled).
            value: props.value || '',
            // Only pass isRequired and validationState to react-aria if they came from
            // the props for this individual checkbox, and not from the group via context.
            isRequired: originalProps.isRequired,
            validationState: originalProps.validationState,
        }, groupState, inputRef) // eslint-disable-next-line react-hooks/rules-of-hooks
        : (0, checkbox_1.useCheckbox)({
            ...props,
            ...(typeof label === 'string' && label.trim()
                ? { 'aria-label': label }
                : {}),
        }, toggleState, inputRef);
    let markIcon = isIndeterminate ? (0, jsx_runtime_1.jsx)(IndeterminateOutline, {}, void 0) : (0, jsx_runtime_1.jsx)(Check, {}, void 0);
    if (groupState) {
        for (let key of ['isSelected', 'defaultSelected', 'isEmphasized']) {
            if (originalProps[key] != null) {
                console.warn(`JengaUIKit: ${key} is unsupported on individual <Checkbox> elements within a <CheckboxGroup>. Please apply these props to the group instead.`);
            }
        }
        if (props.value == null) {
            console.warn('JengaUIKit: A <Checkbox> element within a <CheckboxGroup> requires a `value` property.');
        }
    }
    const mods = {
        checked: inputProps.checked,
        indeterminate: isIndeterminate,
        invalid: validationState === 'invalid',
        valid: validationState === 'valid',
        disabled: isDisabled,
        hovered: isHovered,
        focused: isFocused,
        'side-label': labelPosition === 'side',
        'inside-form': insideForm,
    };
    const checkboxField = ((0, jsx_runtime_1.jsxs)(CheckboxWrapperElement, { isHidden: isHidden, mods: mods, styles: {
            position: 'relative',
        }, children: [(0, jsx_runtime_1.jsx)(HiddenInput_1.HiddenInput, { "data-qa": qa || 'Checkbox', ...(0, react_2.mergeProps)(inputProps, focusProps), ref: inputRef }, void 0), (0, jsx_runtime_1.jsx)(CheckboxElement, { qa: "Checkbox", mods: mods, styles: inputStyles, children: markIcon }, void 0), children && (0, jsx_runtime_1.jsx)(Text_1.Text, { children: children }, void 0)] }, void 0));
    if (insideForm && !groupState) {
        return ((0, jsx_runtime_1.jsx)(FieldWrapper_1.FieldWrapper, { ...{
                as: 'label',
                labelPosition,
                label,
                children,
                extra,
                styles,
                isRequired,
                labelStyles,
                isHidden,
                labelProps,
                isDisabled,
                validationState,
                necessityLabel,
                necessityIndicator,
                message,
                description,
                requiredMark,
                tooltip,
                labelSuffix,
                Component: checkboxField,
                ref: domRef,
            } }, void 0));
    }
    return ((0, jsx_runtime_1.jsxs)(CheckboxWrapperElement, { as: "label", styles: styles, isHidden: isHidden, ...hoverProps, ...(0, tasty_1.filterBaseProps)(otherProps), ref: domRef, children: [checkboxField, label ? ((0, jsx_runtime_1.jsx)(tasty_1.Element, { styles: labelStyles, mods: {
                    invalid: validationState === 'invalid',
                    valid: validationState === 'valid',
                    disabled: isDisabled,
                }, ...(0, tasty_1.filterBaseProps)(labelProps), children: label }, void 0)) : null] }, void 0));
}
/**
 * Checkboxes allow users to select multiple items from a list of individual items,
 * or to mark one individual item as selected.
 */
let _Checkbox = (0, react_1.forwardRef)(Checkbox);
_Checkbox.jengaInputType = 'Checkbox';
let __Checkbox = Object.assign(_Checkbox, { Group: CheckboxGroup_1.CheckboxGroup });
exports.Checkbox = __Checkbox;

        