/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FieldWrapper = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_2 = require("@jengaicons/react");
const Paragraph_1 = require("../../content/Paragraph");
const tasty_1 = require("../../../tasty");
const TooltipProvider_1 = require("../../overlays/Tooltip/TooltipProvider");
const Text_1 = require("../../content/Text");
const react_3 = require("../../../utils/react");
const Space_1 = require("../../layout/Space");
const Flex_1 = require("../../layout/Flex");
const Label_1 = require("../Label");
const FieldElement = (0, tasty_1.tasty)({
    qa: 'Field',
    styles: {
        display: 'grid',
        gridColumns: {
            '': 'minmax(0, 1fr)',
            'has-sider': '@(full-label-width, auto) minmax(0, 1fr)',
        },
        gap: 0,
        placeItems: 'baseline stretch',
        '@full-label-width': '(@label-width + 1x)',
        LabelArea: {
            display: 'block',
            width: {
                '': 'initial',
                'has-sider': '@label-width',
            },
            margin: {
                '': '1x bottom',
                'has-sider': '1x right',
                ':empty': '0',
            },
        },
        InputArea: {
            display: 'block',
            flow: 'column',
            gridColumn: {
                '': 'initial',
                'has-sider': 2,
            },
        },
    },
});
if (process.env.NODE_ENV === 'development') {
    FieldElement.displayName = 'FieldWrapperElement';
}
const MessageElement = (0, tasty_1.tasty)({
    qa: 'Field_Message',
    styles: {
        preset: 't3',
        color: {
            '': '#dark.75',
            invalid: '#danger-text',
            valid: '#success-text',
            disabled: '#dark.40',
        },
        textAlign: 'left',
        userSelect: 'none',
    },
});
/**
 * A wrapper for form fields to provide additional decoration for inputs.
 * @internal Do not use this component directly.
 */
exports.FieldWrapper = (0, react_1.forwardRef)(function FieldWrapper(props, ref) {
    const { as, labelPosition = 'top', label, extra, styles, isRequired, isDisabled, labelStyles, necessityIndicator, labelProps, fieldProps, message, messageStyles, description, Component, validationState, requiredMark = true, tooltip, isHidden, labelSuffix, } = props;
    const labelComponent = label ? ((0, jsx_runtime_1.jsx)(Label_1.Label, { as: as === 'label' ? 'div' : 'label', styles: labelStyles, labelPosition: labelPosition, isRequired: requiredMark ? isRequired : false, isDisabled: isDisabled, necessityIndicator: necessityIndicator, validationState: validationState, "aria-label": label, ...labelProps, children: (0, jsx_runtime_1.jsxs)(Flex_1.Flex, { placeContent: "baseline space-between", width: "100%", children: [(0, jsx_runtime_1.jsxs)(Space_1.Space, { placeItems: "center", gap: "0.25x", children: [(0, jsx_runtime_1.jsx)("div", { children: label }, void 0), tooltip ? ((0, jsx_runtime_1.jsx)(TooltipProvider_1.TooltipProvider, { activeWrap: true, title: tooltip, width: "initial max-content 40x", children: (0, jsx_runtime_1.jsx)(react_2.Info, { style: {
                                    color: 'var(--primary-color)',
                                    margin: '0 4px',
                                } }, void 0) }, void 0)) : null, (0, jsx_runtime_1.jsx)("div", { children: labelSuffix }, void 0)] }, void 0), extra && (0, jsx_runtime_1.jsx)(Text_1.Text, { preset: "t3", children: extra }, void 0)] }, void 0) }, void 0)) : null;
    let descriptionComponent = description ? ((0, jsx_runtime_1.jsx)("div", { "data-element": "Description", children: (0, react_3.wrapNodeIfPlain)(description, () => ((0, jsx_runtime_1.jsx)(Paragraph_1.Paragraph, { children: description }, void 0))) }, void 0)) : null;
    const mods = {
        'has-sider': labelPosition === 'side',
        'has-description': !!description,
        invalid: validationState === 'invalid',
        valid: validationState === 'valid',
    };
    return ((0, jsx_runtime_1.jsxs)(FieldElement, { ref: ref, as: as ?? 'div', mods: mods, isHidden: isHidden, styles: { width: '100%', ...styles }, ...fieldProps, children: [labelComponent || descriptionComponent ? ((0, jsx_runtime_1.jsxs)("div", { "data-element": "LabelArea", children: [labelComponent, descriptionComponent] }, void 0)) : null, (0, jsx_runtime_1.jsxs)("div", { "data-element": "InputArea", children: [Component, message && !isDisabled && ((0, jsx_runtime_1.jsx)(MessageElement, { mods: mods, styles: messageStyles, role: validationState === 'invalid' ? 'alert' : undefined, children: message }, void 0))] }, void 0)] }, void 0));
});

        