/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileInput = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const utils_1 = require("@react-spectrum/utils");
const provider_1 = require("../../../provider");
const Action_1 = require("../../actions/Action");
const tasty_1 = require("../../../tasty");
const FieldWrapper_1 = require("../FieldWrapper");
const FileInputElement = (0, tasty_1.tasty)(Action_1.Action, {
    styles: {
        display: 'inline-flex',
        position: 'relative',
        preset: 't3',
        padding: '.5x 1x',
        gap: '1x',
        flow: 'row',
        placeItems: 'center start',
        fill: {
            '': '#white',
            'drag-hover': '#purple.16',
        },
        border: true,
        radius: true,
        cursor: 'pointer',
        overflow: 'hidden',
        whiteSpace: 'nowrap',
        Button: {
            radius: true,
            border: {
                '': '#clear',
                pressed: '#purple.30',
            },
            fill: {
                '': '#purple.10',
                hovered: '#purple.16',
                pressed: '#purple.10',
                '[disabled]': '#dark.04',
            },
            color: {
                '': '#purple',
                '[disabled]': '#dark.30',
            },
            padding: '.5x (1.5x - 1px)',
            transition: 'theme',
        },
        Placeholder: {
            color: '#dark-02',
            whiteSpace: 'nowrap',
            textOverflow: 'ellipsis',
            width: 'max 100%',
            overflow: 'hidden',
        },
        Value: {
            color: '#dark-02',
            whiteSpace: 'nowrap',
            textOverflow: 'ellipsis',
            width: 'max 100%',
            overflow: 'hidden',
        },
        Input: {
            position: 'absolute',
            top: '-50px',
            right: 0,
            bottom: 0,
            left: 0,
            radius: '@content-radius',
            opacity: 0.01,
            cursor: 'pointer',
            zIndex: 10,
        },
    },
});
function extractContents(element, callback) {
    const files = element?.files;
    if (files && files.length > 0) {
        const fileReader = new FileReader();
        fileReader.onload = function () {
            callback(fileReader.result);
        };
        fileReader.readAsText(files[0]);
    }
}
function FileInput(props, ref) {
    let { id, name, qa, qaVal, onChange, placeholder, inputRef, label, extra, labelPosition, isRequired, necessityIndicator, necessityLabel, labelStyles, labelProps, isDisabled, validationState, message, description, requiredMark, tooltip, isHidden, inputStyles, labelSuffix, type = 'file', inputProps, ...otherProps } = (0, provider_1.useProviderProps)(props);
    const [value, setValue] = (0, react_1.useState)();
    const [dragHover, setDragHover] = (0, react_1.useState)(false);
    let domRef = (0, react_1.useRef)(null);
    let defaultInputRef = (0, react_1.useRef)(null);
    inputRef = inputRef || defaultInputRef;
    let styles = (0, tasty_1.extractStyles)(otherProps, tasty_1.CONTAINER_STYLES);
    const onLocalChange = (0, react_1.useCallback)((event) => {
        const value = event.target.value;
        if (type === 'file') {
            onChange?.(value);
        }
        else if (onChange) {
            extractContents(event.target, onChange);
        }
        setValue(value);
    }, [onChange]);
    // Expose imperative interface for ref
    (0, react_1.useImperativeHandle)(ref, () => ({
        ...(0, utils_1.createFocusableRef)(domRef, inputRef),
        select() {
            if (inputRef?.current) {
                inputRef.current.select();
            }
        },
        getInputElement() {
            return inputRef?.current;
        },
    }));
    const fileName = typeof value === 'string'
        ? value.split('\\')?.pop()
        : undefined;
    const fileInput = ((0, jsx_runtime_1.jsxs)(FileInputElement, { ref: domRef, qa: qa || 'FileInput', styles: inputStyles, isDisabled: isDisabled, mods: {
            selected: !!value,
            'drag-hover': dragHover,
        }, onKeyDown: (e) => {
            if (e.key === 'Enter' || e.key === 'Space') {
                inputRef?.current?.click();
            }
        }, children: [(0, jsx_runtime_1.jsx)("input", { ref: inputRef, id: id, name: name, "data-element": "Input", type: "file", tabIndex: -1, onChange: onLocalChange, onDragEnter: () => {
                    setDragHover(true);
                }, onDragLeave: () => {
                    setDragHover(false);
                }, onDrop: () => {
                    setDragHover(false);
                }, ...inputProps }, void 0), (0, jsx_runtime_1.jsx)("div", { "data-element": "Button", children: "Choose file" }, void 0), (0, jsx_runtime_1.jsx)("div", { "data-element": !!fileName ? 'Value' : 'Placeholder', children: fileName || placeholder || 'No file selected' }, void 0)] }, void 0));
    return ((0, jsx_runtime_1.jsx)(FieldWrapper_1.FieldWrapper, { ...{
            labelPosition,
            label,
            extra,
            styles,
            isRequired,
            labelStyles,
            necessityIndicator,
            necessityLabel,
            labelProps,
            isDisabled,
            validationState,
            message,
            description,
            requiredMark,
            tooltip,
            isHidden,
            labelSuffix,
            Component: fileInput,
            ref: domRef,
        } }, void 0));
}
/**
 * FileInputs are file inputs that allow users to select local files to
 * upload them to the server.
 */
const _FileInput = (0, react_1.forwardRef)(FileInput);
exports.FileInput = _FileInput;

        