/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useInsideLegacyField = exports.Field = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
/* eslint-disable @typescript-eslint/no-explicit-any */
const react_1 = require("react");
const react_2 = require("../../../utils/react");
const FieldWrapper_1 = require("../FieldWrapper");
const warnings_1 = require("../../../utils/warnings");
const Form_1 = require("./Form");
const use_field_1 = require("./use-field");
function getDefaultValidateTrigger(type) {
    type = type || '';
    return type === 'Number' || type.includes('Text') ? 'onBlur' : 'onChange';
}
function getValueProps(type, value, onChange, allowsCustomValue) {
    type = type || '';
    if (type === 'Number') {
        return {
            value: value != null ? value : null,
            onChange: onChange,
        };
    }
    else if (type === 'Text') {
        return {
            value: typeof value === 'string' || typeof value === 'number'
                ? String(value)
                : '',
            onChange: onChange,
        };
    }
    else if (type === 'Checkbox') {
        return {
            isSelected: value != null ? value : false,
            isIndeterminate: false,
            onChange: onChange,
        };
    }
    else if (type === 'CheckboxGroup') {
        return {
            value: value != null ? value : [],
            onChange: onChange,
        };
    }
    else if (type === 'RangeSlider') {
        return {
            value: value != null ? value : undefined,
            onChange: onChange,
        };
    }
    else if (type === 'ComboBox') {
        return {
            inputValue: value != null ? value : '',
            onInputChange: (val) => onChange(val, !allowsCustomValue),
            onSelectionChange: onChange,
        };
    }
    else if (type === 'Select') {
        return {
            selectedKey: value != null ? value : null,
            onSelectionChange: onChange,
        };
    }
    return {
        value: value != null ? value : null,
        onChange,
    };
}
function Field(props) {
    const allProps = (0, Form_1.useFormProps)(props);
    let { type: inputType, children, form, label, extra, validationState, necessityLabel, necessityIndicator, message, description, tooltip, isHidden, isDisabled, isLoading, styles, labelPosition = 'top', labelStyles, labelSuffix, } = allProps;
    if (typeof children === 'function') {
        children = children(form);
    }
    let child = children == null ? null : react_1.Children.only(children);
    inputType = inputType ?? child?.type?.jengaInputType ?? 'Text';
    const __props = (0, use_field_1.useField)(allProps, {
        defaultValidationTrigger: getDefaultValidateTrigger(inputType),
    });
    const { field, isRequired, name, id } = __props;
    if (!child)
        return null;
    if (__props.nonInput) {
        return ((0, jsx_runtime_1.jsx)(LegacyFieldProvider, { children: (0, jsx_runtime_1.jsx)(FieldWrapper_1.FieldWrapper, { isHidden: isHidden, isDisabled: isDisabled, validationState: validationState, necessityIndicator: necessityIndicator, necessityLabel: necessityLabel, isRequired: isRequired, label: label, extra: extra, tooltip: tooltip, message: message, description: description, Component: child, styles: styles, labelPosition: labelPosition, labelStyles: labelStyles, labelSuffix: labelSuffix }, void 0) }, void 0));
    }
    if (!form) {
        (0, warnings_1.warn)('Form Field requires declared form instance if field name is specified');
        return null;
    }
    if (!__props.field) {
        return ((0, jsx_runtime_1.jsx)(LegacyFieldProvider, { children: (0, react_1.cloneElement)(child, (0, react_2.mergeProps)(child.props, {
                ...getValueProps(inputType),
                label: name,
                name,
                id,
            })) }, void 0));
    }
    const newProps = {
        id,
        name,
        onBlur: __props.onBlur,
    };
    if (necessityIndicator != null) {
        newProps.necessityIndicator = necessityIndicator;
    }
    if (necessityLabel) {
        newProps.necessityLabel = necessityLabel;
    }
    if (validationState) {
        newProps.validationState = validationState;
    }
    if (isRequired) {
        newProps.isRequired = isRequired;
    }
    if (label) {
        newProps.label = label;
    }
    if (extra) {
        newProps.extra = extra;
    }
    if (tooltip) {
        newProps.tooltip = tooltip;
    }
    if (message) {
        newProps.message = message;
    }
    if (isHidden != null) {
        newProps.isHidden = isHidden;
    }
    if (isDisabled != null) {
        newProps.isDisabled = isDisabled;
    }
    if (isLoading != null) {
        newProps.isLoading = isLoading;
    }
    if (field?.errors?.length) {
        if (!validationState) {
            newProps.validationState = 'invalid';
        }
        if (!message) {
            newProps.message = field.errors[0];
        }
    }
    Object.assign(newProps, getValueProps(inputType, __props.field?.inputValue, __props.onChange, child.props.allowsCustomValue));
    const { onChange, onSelectionChange, ...childProps } = child.props;
    // onChange event passed to the child should be executed after Form onChange logic
    return ((0, jsx_runtime_1.jsx)(LegacyFieldProvider, { children: (0, react_1.cloneElement)(child, (0, react_2.mergeProps)(childProps, newProps, onChange ? { onChange: __props.onChange } : {}, onSelectionChange ? { onSelectionChange: __props.onChange } : {})) }, void 0));
}
exports.Field = Field;
const LegacyFieldContext = (0, react_1.createContext)({
    insideLegacyField: false,
});
function LegacyFieldProvider(props) {
    const value = (0, react_1.useMemo)(() => ({ insideLegacyField: true }), []);
    return ((0, jsx_runtime_1.jsx)(LegacyFieldContext.Provider, { value: value, children: props.children }, void 0));
}
function useInsideLegacyField() {
    const { insideLegacyField } = (0, react_1.useContext)(LegacyFieldContext);
    return insideLegacyField;
}
exports.useInsideLegacyField = useInsideLegacyField;

        