/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Form = exports.useFormProps = exports.FormContext = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const utils_1 = require("@react-spectrum/utils");
const react_1 = require("react");
const provider_1 = require("../../../provider");
const tasty_1 = require("../../../tasty");
const react_2 = require("../../../utils/react");
const promise_1 = require("../../../utils/promise");
const useForm_1 = require("./useForm");
exports.FormContext = (0, react_1.createContext)({});
const FormElement = (0, tasty_1.tasty)({
    as: 'form',
    qa: 'Form',
    styles: {
        display: {
            '': 'block',
            horizontal: 'flex',
        },
        flow: {
            '': 'column',
            horizontal: 'row',
        },
        placeItems: {
            '': 'initial',
            horizontal: 'center',
        },
        gap: '2x',
        '@label-width': '25x',
    },
});
function useFormProps(props) {
    const ctx = (0, react_1.useContext)(exports.FormContext);
    return { ...ctx, ...props };
}
exports.useFormProps = useFormProps;
const formPropNames = new Set([
    'action',
    'autoComplete',
    'encType',
    'method',
    'target',
]);
function Form(props, ref) {
    props = (0, provider_1.useProviderProps)(props);
    let { qa, name, children, labelPosition, orientation, isRequired, necessityIndicator, isDisabled, isReadOnly, validationState, labelStyles, validateTrigger, defaultValues, onValuesChange, requiredMark = true, form, labelWidth, onSubmit, onSubmitFailed, ...otherProps } = props;
    const firstRunRef = (0, react_1.useRef)(true);
    const isHorizontal = orientation === 'horizontal';
    if (!orientation) {
        orientation = 'vertical';
    }
    if (!labelPosition) {
        labelPosition = isHorizontal ? 'side' : 'top';
    }
    if (!labelWidth) {
        labelWidth = isHorizontal ? 'auto' : undefined;
    }
    ref = (0, react_2.useCombinedRefs)(ref);
    let onSubmitCallback;
    if ((onSubmit || onSubmitFailed) && !otherProps.action) {
        onSubmitCallback = async (e) => {
            if (e && e?.preventDefault) {
                e && e?.preventDefault && e?.preventDefault();
                e && e?.stopPropagation && e?.stopPropagation();
                if (e.nativeEvent) {
                    const evt = e.nativeEvent;
                    if (evt.submitter &&
                        evt.submitter.getAttribute('type') !== 'submit') {
                        return;
                    }
                }
            }
            if (!form || form.isSubmitting)
                return;
            form.submitError = null;
            form.setSubmitting(true);
            try {
                try {
                    await form.validateFields();
                }
                catch (e) {
                    form?.setSubmitting(false);
                    return;
                }
                await (0, promise_1.timeout)();
                await onSubmit?.(form.getFormData());
            }
            catch (e) {
                await (0, promise_1.timeout)();
                // errors are shown
                form.submitError = e;
                // transfer errors to the callback
                onSubmitFailed?.(e);
                if (e instanceof Error) {
                    throw e;
                }
            }
            finally {
                form?.setSubmitting(false);
            }
            // output data from form directly
            // onSubmit(Object.fromEntries(new FormData(e.target).entries()));
        };
    }
    [form] = (0, useForm_1.useForm)(form, ref && ref.current, {
        onSubmit: onSubmitCallback,
        onValuesChange,
    });
    let styles = (0, tasty_1.extractStyles)(otherProps, tasty_1.CONTAINER_STYLES);
    if (labelWidth) {
        styles['@label-width'] = labelWidth;
    }
    let domRef = (0, utils_1.useDOMRef)(ref);
    let ctx = {
        labelPosition,
        labelStyles,
        orientation,
        necessityIndicator,
        validateTrigger,
        requiredMark,
        form,
        submitError: form.submitError,
        idPrefix: name,
    };
    if (firstRunRef.current && form) {
        if (defaultValues) {
            form.setInitialFieldsValue(defaultValues);
            form.resetFields(undefined, true);
            firstRunRef.current = false;
        }
    }
    (0, react_1.useEffect)(() => {
        if (defaultValues) {
            form?.setInitialFieldsValue(defaultValues);
        }
    }, [defaultValues]);
    return ((0, jsx_runtime_1.jsx)(FormElement, { ...(0, tasty_1.filterBaseProps)(otherProps, { propNames: formPropNames }), ref: domRef, noValidate: true, styles: styles, mods: { 'has-sider': labelPosition === 'side', horizontal: isHorizontal }, onSubmit: onSubmitCallback, children: (0, jsx_runtime_1.jsx)(exports.FormContext.Provider, { value: ctx, children: (0, jsx_runtime_1.jsx)(provider_1.Provider, { insideForm: true, isDisabled: isDisabled, isReadOnly: isReadOnly, isRequired: isRequired, validationState: validationState, children: children }, void 0) }, void 0) }, void 0));
}
/**
 * Forms allow users to enter data that can be submitted while providing alignment and styling for form fields.
 */
const _Form = (0, react_1.forwardRef)(Form);
exports.Form = _Form;

        