/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RadioButton = exports.Radio = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const utils_1 = require("@react-spectrum/utils");
const react_1 = require("react");
const interactions_1 = require("@react-aria/interactions");
const radio_1 = require("@react-aria/radio");
const tasty_1 = require("../../../tasty");
const interactions_2 = require("../../../utils/react/interactions");
const react_2 = require("../../../utils/react");
const provider_1 = require("../../../provider");
const Label_1 = require("../Label");
const HiddenInput_1 = require("../../HiddenInput");
const Form_1 = require("../Form");
const RadioGroup_1 = require("./RadioGroup");
const context_1 = require("./context");
const RadioWrapperElement = (0, tasty_1.tasty)({
    as: 'label',
    qa: 'RadioWrapper',
    styles: {
        position: 'relative',
        display: 'grid',
        placeItems: 'center start',
        gap: '1x',
        flow: 'column',
        preset: 'default',
        width: 'min-content',
        margin: {
            '': '1x right',
            '[data-type="button"]': '0',
        },
    },
});
const RadioButtonElement = (0, tasty_1.tasty)({
    styles: {
        radius: true,
        fill: {
            '': '#white',
            hovered: '#purple-text.04',
            disabled: '#dark.04',
        },
        color: {
            '': '#dark.85',
            invalid: '#danger-text',
            disabled: '#dark.40',
        },
        preset: 't3m',
        border: {
            '': true,
            checked: '#purple-text',
            'invalid & checked': '#danger-text',
            'disabled & checked': '#dark.40',
            disabled: '#border',
        },
        padding: '(.75x - 1bw) (1.5x - 1bw)',
        cursor: 'pointer',
        opacity: {
            '': 1,
            disabled: 0.5,
        },
        outline: {
            '': '#purple-03.0',
            focused: '#purple-03',
        },
        transition: 'theme',
    },
});
const RadioNormalElement = (0, tasty_1.tasty)({
    styles: {
        display: 'grid',
        placeItems: 'center',
        radius: 'round',
        fill: {
            '': '#white',
            disabled: '#dark.04',
        },
        color: {
            checked: '#purple-text',
            'invalid & checked': '#danger-text',
            'disabled | !checked': '#clear',
            'disabled & checked': '#dark.12',
        },
        border: {
            '': '#dark.30',
            checked: '#purple-text',
            invalid: '#danger-text.50',
            disabled: '#dark.12',
        },
        width: '2x',
        height: '2x',
        outline: {
            '': '#purple-03.0',
            focused: '#purple-03',
        },
        transition: 'theme',
        RadioCircle: {
            display: 'block',
            radius: 'round',
            width: '1x',
            height: '1x',
            fill: 'currentColor',
            transition: 'theme',
        },
    },
});
const RadioCircleElement = (0, jsx_runtime_1.jsx)("div", { "data-element": "RadioCircle" }, void 0);
const RadioLabelElement = (0, tasty_1.tasty)({
    qa: 'RadioLabel',
    styles: Label_1.INLINE_LABEL_STYLES,
});
function Radio(props, ref) {
    props = (0, provider_1.useProviderProps)(props);
    props = (0, Form_1.useFormProps)(props);
    props = (0, Form_1.useFieldProps)(props, { defaultValidationTrigger: 'onChange' });
    let { qa, isDisabled, validationState, children, label, autoFocus, labelStyles, labelProps, inputStyles, type = 'radio', 'aria-label': ariaLabel, ...otherProps } = props;
    let isButton = type === 'button';
    label = label || children;
    let styles = (0, tasty_1.extractStyles)(otherProps, tasty_1.OUTER_STYLES);
    const RadioElement = isButton ? RadioButtonElement : RadioNormalElement;
    labelStyles = {
        ...Label_1.INLINE_LABEL_STYLES,
        ...labelStyles,
    };
    let state = (0, context_1.useRadioProvider)();
    if (!state) {
        throw new Error('JengaUI: The Radio button is used outside the RadioGroup.');
    }
    let { isFocused, focusProps } = (0, interactions_2.useFocus)({ isDisabled }, true);
    let { hoverProps, isHovered } = (0, interactions_1.useHover)({ isDisabled });
    let inputRef = (0, react_1.useRef)(null);
    let domRef = (0, utils_1.useFocusableRef)(ref, inputRef);
    let { inputProps } = (0, radio_1.useRadio)({
        ...props,
        isDisabled,
    }, state, inputRef);
    return ((0, jsx_runtime_1.jsxs)(RadioWrapperElement, { styles: styles, ...hoverProps, ref: domRef, mods: {
            disabled: isDisabled,
            invalid: validationState === 'invalid',
            hovered: isHovered,
            button: isButton,
        }, "data-type": type, children: [(0, jsx_runtime_1.jsx)(HiddenInput_1.HiddenInput, { "data-qa": qa || 'Radio', "aria-label": ariaLabel, ...(0, react_2.mergeProps)(inputProps, focusProps), ref: inputRef, isButton: isButton }, void 0), (0, jsx_runtime_1.jsx)(RadioElement, { mods: {
                    checked: inputProps.checked,
                    invalid: validationState === 'invalid',
                    valid: validationState === 'valid',
                    disabled: isDisabled,
                    hovered: isHovered,
                    focused: isFocused,
                }, "data-type": type, styles: inputStyles, children: !isButton ? RadioCircleElement : children }, void 0), label && !isButton && ((0, jsx_runtime_1.jsx)(RadioLabelElement, { mods: {
                    invalid: validationState === 'invalid',
                    valid: validationState === 'valid',
                    disabled: isDisabled,
                }, ...(0, tasty_1.filterBaseProps)(labelProps), children: label }, void 0))] }, void 0));
}
function RadioButton(props, ref) {
    const Radio = _Radio;
    return (0, jsx_runtime_1.jsx)(Radio, { ...props, ref: ref, type: "button" }, void 0);
}
/**
 * Radio buttons allow users to select a single option from a list of mutually exclusive options.
 * All possible options are exposed up front for users to compare.
 */
const _Radio = (0, react_1.forwardRef)(Radio);
/**
 * Radio buttons allow users to select a single option from a list of mutually exclusive options.
 * All possible options are exposed up front for users to compare.
 */
const _RadioButton = (0, react_1.forwardRef)(RadioButton);
exports.RadioButton = _RadioButton;
const __Radio = Object.assign(_Radio, {
    Group: RadioGroup_1.RadioGroup,
    Button: _RadioButton,
});
exports.Radio = __Radio;

        