/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RadioGroup = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const utils_1 = require("@react-spectrum/utils");
const radio_1 = require("@react-aria/radio");
const radio_2 = require("@react-stately/radio");
const provider_1 = require("../../../provider");
const Form_1 = require("../Form");
const tasty_1 = require("../../../tasty");
const FieldWrapper_1 = require("../FieldWrapper");
const nullableValue_1 = require("../../../utils/react/nullableValue");
const context_1 = require("./context");
const RadioGroupElement = (0, tasty_1.tasty)({
    qa: 'RadioGroup',
    styles: {
        display: 'flex',
        placeItems: 'start',
        placeContent: 'start',
        flow: {
            '': 'column',
            horizontal: 'row wrap',
        },
        gap: '1x',
    },
});
function RadioGroup(props, ref) {
    props = (0, nullableValue_1.castNullableStringValue)(props);
    props = (0, provider_1.useProviderProps)(props);
    props = (0, Form_1.useFormProps)(props);
    props = (0, Form_1.useFieldProps)(props, { defaultValidationTrigger: 'onChange' });
    let { isDisabled, isRequired, necessityIndicator, label, extra, labelPosition = 'top', validationState, children, orientation = 'vertical', message, description, labelStyles, requiredMark = true, tooltip, isHidden, styles, groupStyles, insideForm, labelSuffix, ...otherProps } = props;
    let domRef = (0, utils_1.useDOMRef)(ref);
    styles = (0, tasty_1.extractStyles)(otherProps, tasty_1.OUTER_STYLES, styles);
    groupStyles = (0, tasty_1.extractStyles)(otherProps, tasty_1.BLOCK_STYLES, groupStyles);
    let state = (0, radio_2.useRadioGroupState)(props);
    let { radioGroupProps: fieldProps, labelProps } = (0, radio_1.useRadioGroup)(props, state);
    let radioGroup = ((0, jsx_runtime_1.jsx)(RadioGroupElement, { styles: groupStyles, mods: {
            horizontal: orientation === 'horizontal',
            'inside-form': insideForm,
            'side-label': labelPosition === 'side',
        }, children: (0, jsx_runtime_1.jsx)(Form_1.FormContext.Provider, { value: {
                isRequired,
                validationState,
                isDisabled,
            }, children: (0, jsx_runtime_1.jsx)(context_1.RadioContext.Provider, { value: state, children: children }, void 0) }, void 0) }, void 0));
    return ((0, jsx_runtime_1.jsx)(FieldWrapper_1.FieldWrapper, { ...{
            labelPosition,
            label,
            extra,
            styles,
            isRequired,
            labelStyles,
            necessityIndicator,
            labelProps,
            fieldProps,
            isDisabled,
            validationState,
            message,
            description,
            requiredMark,
            tooltip,
            isHidden,
            orientation,
            Component: radioGroup,
            ref: domRef,
            labelSuffix,
        } }, void 0));
}
/**
 * Radio groups allow users to select a single option from a list of mutually exclusive options.
 * All possible options are exposed up front for users to compare.
 */
const _RadioGroup = (0, react_1.forwardRef)(RadioGroup);
exports.RadioGroup = _RadioGroup;
_RadioGroup.jengaInputType = 'RadioGroup';

        