/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SliderBase = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const utils_1 = require("@react-spectrum/utils");
const slider_1 = require("@react-stately/slider");
const slider_2 = require("@react-aria/slider");
const i18n_1 = require("@react-aria/i18n");
const FieldWrapper_1 = require("../FieldWrapper");
const tasty_1 = require("../../../tasty");
const Form_1 = require("../Form");
const Text_1 = require("../../content/Text");
const elements_1 = require("./elements");
const LabelValueElement = (0, tasty_1.tasty)(Text_1.Text, {
    styles: {
        display: 'block',
        textAlign: 'right',
    },
});
function SliderBase(allProps, ref) {
    let props = (0, Form_1.useFormProps)(allProps);
    props = (0, Form_1.useFieldProps)(props, {
        defaultValidationTrigger: 'onChange',
        valuePropsMapper: ({ value, onChange }) => ({
            value: value != null ? value : undefined,
            onChange: onChange,
        }),
    });
    let { labelPosition, label, extra, styles, isRequired, validationState, message, description, requiredMark, labelSuffix, labelStyles, necessityIndicator, gradation, isDisabled, inputStyles, minValue = 0, maxValue = 100, inputWidth, formatOptions, getValueLabel, onChange, onChangeEnd, children, showValueLabel = true, orientation: formOrientation, ...otherProps } = props;
    let orientation = allProps.orientation || 'horizontal';
    // `Math.abs(Math.sign(a) - Math.sign(b)) === 2` is true if the values have a different sign.
    let alwaysDisplaySign = Math.abs(Math.sign(minValue) - Math.sign(maxValue)) === 2;
    if (alwaysDisplaySign) {
        if (formatOptions != null) {
            if (!('signDisplay' in formatOptions)) {
                formatOptions = {
                    ...formatOptions,
                    signDisplay: 'exceptZero',
                };
            }
        }
        else {
            formatOptions = { signDisplay: 'exceptZero' };
        }
    }
    const formatter = (0, i18n_1.useNumberFormatter)(formatOptions);
    const state = (0, slider_1.useSliderState)({
        ...props,
        orientation,
        numberFormatter: formatter,
        minValue,
        maxValue,
    });
    const trackRef = (0, react_1.useRef)(null);
    let { groupProps, trackProps, labelProps, outputProps } = (0, slider_2.useSlider)(props, state, trackRef);
    const inputRef = (0, react_1.useRef)(null);
    let domRef = (0, utils_1.useFocusableRef)(ref, inputRef);
    let displayValue = '';
    let maxLabelLength = 0;
    if (typeof getValueLabel === 'function') {
        displayValue = getValueLabel(state.values);
        switch (state.values.length) {
            case 1:
                maxLabelLength = Math.max(getValueLabel([minValue]).length, getValueLabel([maxValue]).length);
                break;
            case 2:
                // Try all possible combinations of min and max values.
                maxLabelLength = Math.max(getValueLabel([minValue, minValue]).length, getValueLabel([minValue, maxValue]).length, getValueLabel([maxValue, minValue]).length, getValueLabel([maxValue, maxValue]).length);
                break;
            default:
                throw new Error('Only sliders with 1 or 2 handles are supported!');
        }
    }
    else {
        maxLabelLength = Math.max([...formatter.format(minValue)].length, [...formatter.format(maxValue)].length);
        switch (state.values.length) {
            case 1:
                displayValue = state.getThumbValueLabel(0);
                break;
            case 2:
                // This should really use the NumberFormat#formatRange proposal...
                // https://github.com/tc39/ecma402/issues/393
                // https://github.com/tc39/proposal-intl-numberformat-v3#formatrange-ecma-402-393
                displayValue = `${state.getThumbValueLabel(0)} – ${state.getThumbValueLabel(1)}`;
                maxLabelLength =
                    3 +
                        2 *
                            Math.max(maxLabelLength, [...formatter.format(minValue)].length, [...formatter.format(maxValue)].length);
                break;
            default:
                throw new Error('Only sliders with 1 or 2 handles are supported!');
        }
    }
    extra =
        extra != null || !showValueLabel ? (extra) : ((0, jsx_runtime_1.jsx)(LabelValueElement, { ...outputProps, style: maxLabelLength
                ? {
                    width: `${maxLabelLength + 1}ch`,
                    minWidth: `${maxLabelLength + 1}ch`,
                }
                : undefined, children: displayValue }, void 0));
    const sliderField = ((0, jsx_runtime_1.jsx)(elements_1.SliderElement, { ref: domRef, ...groupProps, mods: {
            'side-label': labelPosition === 'side',
            horizontal: orientation === 'horizontal',
        }, children: (0, jsx_runtime_1.jsx)(elements_1.SliderControlsElement, { ...trackProps, ref: trackRef, mods: {
                horizontal: orientation === 'horizontal',
            }, children: children({
                trackRef,
                inputRef,
                state,
            }) }, void 0) }, void 0));
    styles = (0, tasty_1.extractStyles)(otherProps, tasty_1.OUTER_STYLES, styles);
    return ((0, jsx_runtime_1.jsx)(FieldWrapper_1.FieldWrapper, { ...{
            labelPosition,
            label,
            extra,
            styles,
            isRequired,
            labelStyles,
            necessityIndicator,
            labelProps,
            isDisabled,
            validationState,
            message,
            description,
            requiredMark,
            labelSuffix,
            Component: sliderField,
            ref: ref,
        } }, void 0));
}
const _SliderBase = (0, react_1.forwardRef)(SliderBase);
exports.SliderBase = _SliderBase;

        