/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Switch = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const utils_1 = require("@react-spectrum/utils");
const switch_1 = require("@react-aria/switch");
const interactions_1 = require("@react-aria/interactions");
const toggle_1 = require("@react-stately/toggle");
const react_2 = require("@jengaicons/react");
const provider_1 = require("../../../provider");
const tasty_1 = require("../../../tasty");
const interactions_2 = require("../../../utils/react/interactions");
const react_3 = require("../../../utils/react");
const HiddenInput_1 = require("../../HiddenInput");
const Label_1 = require("../Label");
const Text_1 = require("../../content/Text");
const FieldWrapper_1 = require("../FieldWrapper");
const nullableValue_1 = require("../../../utils/react/nullableValue");
const Form_1 = require("../Form");
const SwitchWrapperElement = (0, tasty_1.tasty)({
    qa: 'SwitchWrapper',
    styles: {
        display: 'flex',
        position: 'relative',
        placeItems: {
            '': 'center stretch',
            'side-label': 'baseline stretch',
        },
        gap: '1x',
    },
});
const SwitchLabelElement = (0, tasty_1.tasty)({
    as: 'label',
    qa: 'SwitchLabel',
    styles: {
        position: 'relative',
        display: 'flex',
        placeItems: 'center',
        gap: '1x',
        flow: 'row',
        preset: 'input',
        width: 'min-content',
        cursor: 'pointer',
        verticalAlign: 'baseline',
    },
});
const SwitchElement = (0, tasty_1.tasty)({
    qa: 'Switch',
    styles: {
        position: 'relative',
        display: 'grid',
        verticalAlign: 'baseline',
        placeItems: 'center',
        radius: 'round',
        fill: {
            '': '#op-surface',
            checked: '#op-surface-primary',
        },
        color: '#white',
        border: '#op-border',
        width: {
            '': '45px',
            '[data-size="small"]': '3.5x 3.5x',
        },
        height: {
            '': '25px',
            '[data-size="small"]': '2x 2x',
        },
        outline: {
            '': '#purple-03.0',
            focused: '#purple-03',
        },
        transition: 'theme',
        placeSelf: {
            '': null,
            'inside-form & side-label': 'start',
        },
        opacity: {
            '': 1,
            disabled: 0.5,
        },
        cursor: {
            '': 'pointer',
            disabled: 'not-allowed',
        },
        Thumb: {
            position: 'absolute',
            width: {
                '': '19px',
                '[data-size="small"]': '1.5x 1.5x',
            },
            height: {
                '': '19px',
                '[data-size="small"]': '1.5x 1.5x',
            },
            radius: 'round',
            fill: {
                '': '#op-surface-primary',
                checked: '#op-surface',
                disabled: '#white.5',
            },
            top: {
                '': '3px',
                '[data-size="small"]': '2px',
            },
            left: {
                '': '3px',
                '[data-size="small"]': '2px',
                checked: '2.8125x',
                'checked & [data-size="small"]': '1.725x',
            },
            transition: 'left, theme',
        },
    },
});
function Switch(props, ref) {
    props = (0, nullableValue_1.castNullableIsSelected)(props);
    props = (0, provider_1.useProviderProps)(props);
    props = (0, Form_1.useFormProps)(props);
    props = (0, Form_1.useFieldProps)(props, {
        defaultValidationTrigger: 'onChange',
        valuePropsMapper: ({ value, onChange }) => ({
            isSelected: value != null ? value : false,
            isIndeterminate: false,
            onChange: onChange,
        }),
    });
    let { qa, isDisabled = false, autoFocus, children, label, extra, labelProps, labelStyles, isLoading, insideForm, validationState, message, description, labelPosition, inputStyles, requiredMark = true, tooltip, labelSuffix, size = 'large', ...otherProps } = props;
    let styles = (0, tasty_1.extractStyles)(props, tasty_1.OUTER_STYLES);
    inputStyles = (0, tasty_1.extractStyles)(props, tasty_1.BLOCK_STYLES, inputStyles);
    labelStyles = (0, react_1.useMemo)(() => ({
        ...(insideForm ? Label_1.LABEL_STYLES : Label_1.INLINE_LABEL_STYLES),
        ...labelStyles,
    }), [insideForm, labelStyles]);
    let { isFocused, focusProps } = (0, interactions_2.useFocus)({ isDisabled }, true);
    let { hoverProps, isHovered } = (0, interactions_1.useHover)({ isDisabled });
    let inputRef = (0, react_1.useRef)(null);
    let domRef = (0, utils_1.useFocusableRef)(ref, inputRef);
    // eslint-disable-next-line react-hooks/rules-of-hooks
    let { inputProps } = (0, switch_1.useSwitch)(props, (0, toggle_1.useToggleState)(props), inputRef);
    const mods = {
        'inside-form': insideForm,
        'side-label': labelPosition === 'side',
        checked: inputProps.checked,
        disabled: isDisabled,
        hovered: isHovered,
        focused: isFocused,
    };
    const switchField = ((0, jsx_runtime_1.jsxs)(SwitchWrapperElement, { mods: mods, "data-size": size, children: [(0, jsx_runtime_1.jsx)(HiddenInput_1.HiddenInput, { "data-qa": "HiddenInput", ...(0, react_3.mergeProps)(inputProps, focusProps), ref: inputRef }, void 0), (0, jsx_runtime_1.jsx)(SwitchElement, { qa: qa || 'Switch', mods: mods, "data-size": size, styles: inputStyles, children: (0, jsx_runtime_1.jsx)("div", { "data-element": "Thumb", "aria-hidden": "true" }, void 0) }, void 0), children ? (0, jsx_runtime_1.jsx)(Text_1.Text, { nowrap: true, children: children }, void 0) : null] }, void 0));
    if (insideForm) {
        return ((0, jsx_runtime_1.jsx)(FieldWrapper_1.FieldWrapper, { ...{
                as: 'label',
                labelPosition,
                label,
                extra,
                styles,
                labelStyles,
                labelProps,
                isDisabled,
                validationState,
                message,
                children,
                description,
                requiredMark,
                tooltip,
                labelSuffix,
                Component: switchField,
                ref: domRef,
            } }, void 0));
    }
    return ((0, jsx_runtime_1.jsxs)(SwitchLabelElement, { styles: styles, mods: mods, ...hoverProps, ...(0, tasty_1.filterBaseProps)(otherProps), ref: domRef, children: [switchField, label ? ((0, jsx_runtime_1.jsxs)(tasty_1.Element, { styles: labelStyles, mods: {
                    disabled: isDisabled,
                }, ...(0, tasty_1.filterBaseProps)(labelProps), children: [label, isLoading ? ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [label ? (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: "\u00A0" }, void 0) : null, (0, jsx_runtime_1.jsx)(react_2.CircleNotch, {}, void 0)] }, void 0)) : null] }, void 0)) : null] }, void 0));
}
/**
 * Switches allow users to turn an individual option on or off.
 * They are usually used to activate or deactivate a specific setting.
 */
let _Switch = (0, react_1.forwardRef)(Switch);
exports.Switch = _Switch;
_Switch.jengaInputType = 'Checkbox';

        