/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextArea = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const utils_1 = require("@react-stately/utils");
const textfield_1 = require("@react-aria/textfield");
const TextInputBase_1 = require("../TextInput/TextInputBase");
const provider_1 = require("../../../provider");
const nullableValue_1 = require("../../../utils/react/nullableValue");
const react_2 = require("../../../utils/react");
const Form_1 = require("../Form");
const _internal_1 = require("../../../_internal");
function TextArea(props, ref) {
    props = (0, nullableValue_1.castNullableStringValue)(props);
    props = (0, provider_1.useProviderProps)(props);
    props = (0, Form_1.useFieldProps)(props, {
        defaultValidationTrigger: 'onBlur',
        valuePropsMapper: ({ value, onChange }) => ({
            onChange,
            value: value?.toString() ?? '',
        }),
    });
    let { autoSize = false, isDisabled = false, isReadOnly = false, isRequired = false, onChange, rows = 3, ...otherProps } = props;
    let [inputValue, setInputValue] = (0, utils_1.useControlledState)(props.value, props.defaultValue, () => { });
    let inputRef = (0, react_1.useRef)(null);
    let onHeightChange = (0, _internal_1.useEvent)(() => {
        if (autoSize && inputRef.current) {
            let input = inputRef.current;
            let prevAlignment = input.style.alignSelf;
            let computedStyle = getComputedStyle(input);
            input.style.alignSelf = 'start';
            input.style.height = 'auto';
            input.style.height = input.scrollHeight
                ? `calc(${input.scrollHeight}px + (2 * var(--border-width)))`
                : `${parseFloat(computedStyle.paddingTop) +
                    parseFloat(computedStyle.paddingBottom) +
                    parseFloat(computedStyle.lineHeight) * (rows || 3) +
                    2}px`;
            input.style.alignSelf = prevAlignment;
        }
    });
    (0, react_2.useLayoutEffect)(() => {
        if (inputRef.current) {
            onHeightChange();
        }
    }, [onHeightChange, inputValue, inputRef]);
    let { labelProps, inputProps } = (0, textfield_1.useTextField)({
        ...props,
        onChange: (0, react_2.chain)(onChange, setInputValue),
        inputElementType: 'textarea',
    }, inputRef);
    return ((0, jsx_runtime_1.jsx)(TextInputBase_1.TextInputBase, { ...otherProps, ref: ref, multiLine: true, inputRef: inputRef, labelProps: labelProps, inputProps: inputProps, isDisabled: isDisabled, isReadOnly: isReadOnly, isRequired: isRequired, rows: rows, styles: {
            Prefix: {
                alignSelf: 'start',
                padding: '1.25x 0.25x',
            },
            ...props.styles,
        } }, void 0));
}
/**
 * TextInputs are text inputs that allow users to input custom text entries
 * with a keyboard. Various decorations can be displayed around the field to
 * communicate the entry requirements.
 */
const _TextArea = (0, react_1.forwardRef)(TextArea);
exports.TextArea = _TextArea;
_TextArea.jengaInputType = 'Text';

        