/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextInputBase = exports.DEFAULT_INPUT_STYLES = exports.INPUT_WRAPPER_STYLES = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("@jengaicons/react");
const utils_1 = require("@react-spectrum/utils");
const react_2 = require("react");
const interactions_1 = require("@react-aria/interactions");
const Form_1 = require("../Form");
const provider_1 = require("../../../provider");
const tasty_1 = require("../../../tasty");
const interactions_2 = require("../../../utils/react/interactions");
const FieldWrapper_1 = require("../FieldWrapper");
const react_3 = require("../../../utils/react");
const ADD_STYLES = {
    display: 'grid',
    placeContent: 'stretch',
    placeItems: 'center',
    flow: 'column',
    gap: 0,
    cursor: 'inherit',
    opacity: {
        '': 1,
        disabled: '@disabled-opacity',
    },
};
exports.INPUT_WRAPPER_STYLES = {
    display: 'grid',
    position: 'relative',
    gridAreas: '"prefix input suffix"',
    gridColumns: 'auto 1fr auto',
    placeItems: 'stretch',
    fill: {
        '': '#op-surface',
    },
    border: {
        '': '#op-border',
        focused: true,
        valid: '#op-border-success',
        invalid: '#op-border-critical',
    },
    outline: {
        '': '#clear',
        focused: '#op-border-focus',
        'invalid & focused': '#op-border-critical',
        'valid & focused': '#op-border-success',
    },
    radius: '1x',
    cursor: { '': 'text', disabled: 'not-allowed' },
    color: {
        '': '#op-text',
        focused: '#op-text',
        invalid: '#op-text-critical',
    },
    zIndex: {
        '': 'initial',
        focused: 1,
    },
    boxSizing: 'border-box',
    transition: 'theme',
    opacity: {
        '': 1,
        disabled: 0.5,
    },
    Prefix: {
        ...ADD_STYLES,
        gridArea: 'prefix',
    },
    Suffix: {
        ...ADD_STYLES,
        gridArea: 'suffix',
    },
    State: {
        display: 'flex',
    },
    InputIcon: {
        display: 'grid',
        placeItems: 'center',
        width: 'min 4x',
        color: 'inherit',
        fontSize: '@icon-size',
    },
    ValidationIcon: {
        display: 'grid',
        placeItems: 'center',
        padding: '1x',
        width: {
            '': 'min 4x',
            suffix: 'min 3x',
        },
        fontSize: '@icon-size',
    },
};
const InputWrapperElement = (0, tasty_1.tasty)({
    styles: exports.INPUT_WRAPPER_STYLES,
});
const STYLE_LIST = [...tasty_1.POSITION_STYLES, ...tasty_1.DIMENSION_STYLES];
const INPUT_STYLE_PROPS_LIST = [...tasty_1.BLOCK_STYLES, 'resize'];
exports.DEFAULT_INPUT_STYLES = {
    display: 'block',
    gridArea: 'input',
    height: 'initial initial initial',
    color: 'inherit',
    fill: '#clear',
    border: 0,
    transition: 'theme',
    radius: true,
    padding: '@vertical-padding @right-padding @vertical-padding @left-padding',
    textAlign: 'left',
    reset: 'input',
    preset: 't3',
    flexGrow: 1,
    margin: 0,
    resize: 'none',
    boxSizing: 'border-box',
    userSelect: 'auto',
    '@vertical-padding': {
        '': '(1.25x - 1bw)',
        '[data-size="small"]': '(.75x - 1bw)',
    },
    '@left-padding': {
        '': '(1.5x - 1bw)',
        prefix: '0',
    },
    '@right-padding': {
        '': '(1.5x - 1bw)',
        suffix: '0',
    },
};
const InputElement = (0, tasty_1.tasty)({ qa: 'Input', styles: exports.DEFAULT_INPUT_STYLES });
function TextInputBase(props, ref) {
    props = (0, provider_1.useProviderProps)(props);
    props = (0, Form_1.useFormProps)(props);
    props = (0, Form_1.useFieldProps)(props, {
        defaultValidationTrigger: 'onBlur',
        valuePropsMapper: ({ value, onChange }) => ({
            value: typeof value === 'string' || typeof value === 'number'
                ? String(value)
                : '',
            onChange,
        }),
    });
    let { qa, label, extra, mods, labelPosition = 'top', labelStyles, isRequired, necessityIndicator, necessityLabel, validationState, message, description, prefix, isDisabled, multiLine, autoFocus, labelProps, inputProps, wrapperProps, inputRef, isLoading, loadingIndicator, value, inputStyles = {}, wrapperStylesProp = {}, suffix, suffixPosition = 'before', wrapperRef, requiredMark = true, tooltip, isHidden, rows = 1, size, icon, labelSuffix, maxLength, minLength, fullWidth = false, ...otherProps } = props;
    let styles = (0, tasty_1.extractStyles)(otherProps, STYLE_LIST);
    let type = otherProps.type;
    inputStyles = (0, tasty_1.extractStyles)(otherProps, INPUT_STYLE_PROPS_LIST, inputStyles);
    let ElementType = multiLine ? 'textarea' : 'input';
    let { isFocused, focusProps } = (0, interactions_2.useFocus)({ isDisabled });
    let { hoverProps, isHovered } = (0, interactions_1.useHover)({ isDisabled });
    let domRef = (0, react_2.useRef)(null);
    let defaultInputRef = (0, react_2.useRef)(null);
    inputRef = inputRef || defaultInputRef;
    // Expose imperative interface for ref
    (0, react_2.useImperativeHandle)(ref, () => ({
        ...(0, utils_1.createFocusableRef)(domRef, inputRef),
        select() {
            if (inputRef?.current) {
                inputRef.current.select();
            }
        },
        getInputElement() {
            return inputRef?.current;
        },
    }));
    let isInvalid = validationState === 'invalid';
    let validationIcon = isInvalid ? ((0, jsx_runtime_1.jsx)(react_1.Warning, { "data-element": "ValidationIcon", style: { color: 'var(--op-icon-critical)' } }, void 0)) : ((0, jsx_runtime_1.jsx)(react_1.Check, { "data-element": "ValidationIcon", style: { color: 'var(--op-icon-success)' } }, void 0));
    let validation = (0, react_2.cloneElement)(validationIcon);
    // Fix safari bug: https://github.com/philipwalton/flexbugs/issues/270
    if (!inputProps?.placeholder) {
        if (!inputProps) {
            inputProps = {};
        }
        inputProps.placeholder = ' ';
    }
    if (icon) {
        icon = (0, jsx_runtime_1.jsx)("div", { "data-element": "InputIcon", children: icon }, void 0);
        if (prefix) {
            prefix = ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [icon, prefix] }, void 0));
        }
        else {
            prefix = icon;
        }
    }
    const modifiers = (0, react_2.useMemo)(() => ({
        invalid: isInvalid,
        valid: validationState === 'valid',
        loadable: !!loadingIndicator,
        focused: isFocused,
        hovered: isHovered,
        disabled: isDisabled,
        multiline: multiLine,
        prefix: !!prefix,
        suffix: !!suffix,
        ...mods,
    }), [
        mods,
        isInvalid,
        validationState,
        loadingIndicator,
        isFocused,
        isDisabled,
        isHovered,
        multiLine,
        prefix,
        suffix,
    ]);
    const hasTextSecurity = inputRef?.current?.value && multiLine && type === 'password';
    const textSecurityStyles = hasTextSecurity
        ? {
            fontFamily: 'text-security-disc',
            WebkitTextSecurity: 'disc',
        }
        : {};
    const wrapperStyles = {
        ...wrapperStylesProp,
        width: {
            '': ['60%', '70%', '100%'],
            '[data-full-width="true"]': '100%',
        },
    };
    const textField = ((0, jsx_runtime_1.jsxs)(InputWrapperElement, { ref: wrapperRef, qa: qa || 'TextInput', mods: modifiers, "data-size": size, styles: wrapperStyles, "data-full-width": fullWidth, ...wrapperProps, children: [(0, jsx_runtime_1.jsx)(InputElement, { as: ElementType, ...(0, react_3.mergeProps)(inputProps, focusProps, hoverProps), ref: inputRef, rows: multiLine ? rows : undefined, mods: modifiers, style: textSecurityStyles, autoFocus: autoFocus, "data-size": size, styles: inputStyles, isDisabled: isDisabled, maxLength: maxLength, minLength: minLength }, void 0), prefix ? (0, jsx_runtime_1.jsx)("div", { "data-element": "Prefix", children: prefix }, void 0) : null, (validationState && !isLoading) || isLoading || suffix ? ((0, jsx_runtime_1.jsxs)("div", { "data-element": "Suffix", children: [suffixPosition === 'before' ? suffix : null, (validationState && !isLoading) || isLoading ? ((0, jsx_runtime_1.jsxs)("div", { "data-element": "State", children: [validationState && !isLoading ? ((0, jsx_runtime_1.jsx)("div", { style: { padding: '8px' }, children: validation }, void 0)) : null, isLoading && (0, jsx_runtime_1.jsx)(react_1.CircleNotch, { "data-element": "InputIcon" }, void 0)] }, void 0)) : null, suffixPosition === 'after' ? suffix : null] }, void 0)) : null] }, void 0));
    return ((0, jsx_runtime_1.jsx)(FieldWrapper_1.FieldWrapper, { ...{
            labelPosition,
            label,
            extra,
            styles,
            isRequired,
            labelStyles,
            necessityIndicator,
            necessityLabel,
            labelProps,
            isDisabled,
            validationState,
            message,
            description,
            requiredMark,
            tooltip,
            isHidden,
            labelSuffix,
            Component: textField,
            ref: domRef,
        } }, void 0));
}
const _TextInputBase = (0, react_2.forwardRef)(TextInputBase);
exports.TextInputBase = _TextInputBase;

        