/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LegacyTabs = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const styled_components_1 = __importDefault(require("styled-components"));
const Block_1 = require("../../Block");
const Space_1 = require("../../layout/Space");
const Flex_1 = require("../../layout/Flex");
const actions_1 = require("../../actions");
const tasty_1 = require("../../../tasty");
const Flow_1 = require("../../layout/Flow");
const react_2 = require("../../../utils/react");
const LegacyTabsContext = (0, react_1.createContext)({
    addTab() { },
    removeTab() { },
    setTab() { },
    changeTab() { },
});
const TabElement = (0, tasty_1.tasty)(actions_1.Button, {
    type: 'tab',
    styles: {
        color: {
            '': '#dark',
            'selected, hovered': '#purple-text',
            disabled: '#dark.50',
        },
        fill: '#purple.0',
        textAlign: 'center',
        fontWeight: 600,
        padding: '(1x - 1px) (1x - 1px)',
        radius: '1r 1r 0 0',
        border: 0,
    },
});
const StyledTabElement = (0, styled_components_1.default)(TabElement) `
  &::before {
    --outline-size: 0px;
    content: '';
    display: block;
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    box-shadow: inset 0 calc(-1 * var(--outline-size)) 0 var(--purple-color);
    pointer-events: none;
    transition: opacity linear 0.2s, box-shadow linear 0.2s;
  }
  &[data-is-selected]::before {
    --outline-size: 2px;
  }
  &:not([data-is-selected]):not([disabled])[data-is-hovered]::before {
    --outline-size: 1px;
  }
`;
const TabsPanelElement = (0, tasty_1.tasty)(Space_1.Space, {
    styles: {
        gap: '1x',
        flexShrink: 0,
    },
});
const StyledTabsPanelElement = (0, styled_components_1.default)(TabsPanelElement) `
  position: relative;
  overflow: auto hidden;
  top: 1px;
  white-space: nowrap;

  ::-webkit-scrollbar-track {
    background: var(--grey-light-color);
  }

  ::-webkit-scrollbar-thumb {
    border-radius: 1px;
    background: var(--dark-04-color);
    background-clip: padding-box;
  }

  ::-webkit-scrollbar-corner {
    background-color: transparent;
  }

  ::-webkit-scrollbar {
    width: 3px;
    height: 3px;
  }
`;
const TabsContainerElement = (0, tasty_1.tasty)(Flow_1.Flow, {
    styles: {
        flow: 'column',
        height: 'max 100%',
        width: 'max 100%',
    },
});
const StyledTabsContainerElement = (0, styled_components_1.default)(TabsContainerElement) `
  position: relative;

  &::before {
    content: '';
    display: block;
    opacity: 0;
    position: absolute;
    top: 0;
    left: 0;
    pointer-events: none;
    width: 32px;
    height: 37px;
    transition: all 0.15s linear;
    background-image: linear-gradient(
      to left,
      rgba(255, 255, 255, 0),
      rgba(255, 255, 255, 1)
    );
    z-index: 1;
  }

  &::after {
    content: '';
    display: block;
    opacity: 0;
    position: absolute;
    top: 0;
    right: 0;
    width: 32px;
    height: 37px;
    pointer-events: none;
    transition: all 0.15s linear;
    background-image: linear-gradient(
      to right,
      rgba(255, 255, 255, 0),
      rgba(255, 255, 255, 1)
    );
    z-index: 1;
  }

  &[data-is-left-fade]::before,
  &[data-is-right-fade]::after {
    opacity: 1;
  }
`;
function Tab({ isSelected, isHidden, onClose, ...props }) {
    return ((0, jsx_runtime_1.jsx)(StyledTabElement, { isSelected: isSelected, isHidden: isHidden, ...props }, void 0));
}
function LegacyTabs({ defaultActiveKey, activeKey: activeKeyProp, onTabClick, onTabClose, paneStyles, extra, children, ...props }) {
    const tabsRef = (0, react_1.useRef)(null);
    const [tabs, setTabs] = (0, react_1.useState)([]);
    const [activeKey, setActiveKey] = (0, react_1.useState)(activeKeyProp || defaultActiveKey);
    const [leftFade, setLeftFade] = (0, react_1.useState)(false);
    const [rightFade, setRightFade] = (0, react_1.useState)(false);
    function updateScroll() {
        const el = tabsRef && tabsRef.current;
        if (!el)
            return;
        setLeftFade(!!el.scrollLeft);
        setRightFade(el.scrollWidth !== el.offsetWidth &&
            !!(el.scrollWidth - el.offsetWidth - el.scrollLeft));
    }
    (0, react_2.useLayoutEffect)(updateScroll, [tabs]);
    function scrollCurrentIntoView() {
        const el = tabsRef && tabsRef.current;
        if (!el)
            return;
        const current = el.querySelector('button[disabled]');
        if (!current)
            return;
        current.scrollIntoView({ behavior: 'smooth', inline: 'end', block: 'end' });
    }
    (0, react_1.useEffect)(() => {
        function update() {
            updateScroll();
        }
        if (tabsRef && tabsRef.current) {
            tabsRef.current.addEventListener('scroll', update);
            tabsRef.current.addEventListener('mousewheel', update);
            window.addEventListener('resize', update);
        }
        return () => {
            if (tabsRef && tabsRef.current) {
                tabsRef.current.removeEventListener('scroll', update);
                tabsRef.current.removeEventListener('mousewheel', update);
            }
            window.removeEventListener('resize', update);
        };
    }, [tabsRef]);
    (0, react_1.useEffect)(scrollCurrentIntoView, [activeKey]);
    (0, react_1.useEffect)(() => {
        setActiveKey(activeKeyProp);
    }, [activeKeyProp]);
    function getTab(tabs, key) {
        return tabs.find((tab) => tab.id === key);
    }
    function setTab(key) {
        if (getTab(tabs, key)) {
            setActiveKey(key);
        }
    }
    function addTab(tab) {
        setTabs((tabs) => {
            if (!getTab(tabs, tab.id)) {
                return [...tabs, tab];
            }
            return tabs;
        });
    }
    function removeTab(tab) {
        setTabs((tabs) => {
            const _tabs = tabs.filter((_tab) => _tab.id !== tab.id);
            setActiveKey((prevActiveKey) => {
                if (prevActiveKey === tab.id) {
                    return _tabs[0] && _tabs[0].id;
                }
                return prevActiveKey;
            });
            return _tabs;
        });
    }
    function changeTab(tab) {
        setTabs((tabs) => {
            const existTab = tabs.find((_tab) => _tab.id === tab.id);
            if (existTab) {
                Object.assign(existTab, tab);
            }
            return [...tabs];
        });
    }
    function onPress(tab) {
        onTabClick && onTabClick(tab.id);
        setTab(tab.id);
    }
    return ((0, jsx_runtime_1.jsx)(StyledTabsContainerElement, { "data-is-left-fade": leftFade || null, "data-is-right-fade": rightFade || null, ...props, children: (0, jsx_runtime_1.jsxs)(LegacyTabsContext.Provider, { value: {
                addTab,
                setTab,
                removeTab,
                changeTab,
                currentTab: activeKey,
            }, children: [(0, jsx_runtime_1.jsxs)(Space_1.Space, { gap: ".5x", placeContent: "center space-between", children: [(0, jsx_runtime_1.jsx)(StyledTabsPanelElement, { ref: tabsRef, children: tabs.map((tab) => {
                                return ((0, jsx_runtime_1.jsx)(Tab, { "data-qa": tab.qa, isSelected: tab.id === activeKey || false, isDisabled: tab.isDisabled, isHidden: tab.isHidden, onPress: () => onPress(tab), children: tab.title }, tab.id));
                            }) }, void 0), extra] }, void 0), (0, jsx_runtime_1.jsx)(Flex_1.Flex, { flexGrow: 1, border: "top rgb(227, 227, 233)", ...(paneStyles || {}), children: children }, void 0)] }, void 0) }, void 0));
}
exports.LegacyTabs = LegacyTabs;
LegacyTabs.TabPane = function TabPane({ id, title, qa, isHidden, isDisabled, children, ...props }) {
    const { addTab, removeTab, changeTab, currentTab } = (0, react_1.useContext)(LegacyTabsContext);
    (0, react_1.useEffect)(() => {
        const tabData = {
            id,
            qa,
            title,
            isDisabled,
            isHidden,
        };
        addTab(tabData);
        return () => {
            removeTab(tabData);
        };
    }, [id]);
    (0, react_1.useEffect)(() => {
        changeTab({
            id,
            qa,
            title,
            isDisabled,
            isHidden,
        });
    }, [title, isDisabled, isHidden]);
    const isCurrent = id === currentTab;
    return ((0, jsx_runtime_1.jsx)(Block_1.Block, { style: { display: isCurrent ? 'block' : 'none' }, flexGrow: 1, ...props, children: children }, void 0));
};

        