/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Modal = void 0;
const react_1 = require("react");
const jsx_runtime_1 = require("react/jsx-runtime");
const react_2 = require("react");
const react_dom_1 = __importDefault(require("react-dom"));
const styled_components_1 = __importDefault(require("styled-components"));
const react_3 = require("@jengaicons/react");
const react_transition_group_1 = require("react-transition-group");
const Action_1 = require("../../actions/Action");
const Card_1 = require("../../content/Card/Card");
const Flow_1 = require("../../layout/Flow");
const Flex_1 = require("../../layout/Flex");
const Block_1 = require("../../Block");
const actions_1 = require("../../actions");
const Space_1 = require("../../layout/Space");
const Title_1 = require("../../content/Title");
const Overlay = styled_components_1.default.div `
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: rgba(0, 0, 0, 0.4);
  place-content: center;
  place-items: center;
  z-index: 1000;
  display: none;
  white-space: normal;

  .jenga-modal {
    --enter-transition-time: 250ms;
    --leave-transition-time: 160ms;
    --base-translate: ((50vh - 50%) / -3);
    transform: translate(0, calc(var(--base-translate)));
  }

  &.jenga-modal-transition-enter {
    opacity: 0;
    display: flex;

    & .jenga-modal {
      transform: translate(0, calc(-32px + var(--base-translate))) scale(0.5);
    }
  }

  &.jenga-modal-transition-enter-active {
    opacity: 1;
    transition: all var(--enter-transition-time) cubic-bezier(0, 0.5, 0, 1);

    & .jenga-modal {
      transform: translate(0, calc(var(--base-translate))) scale(1);
      transition: all var(--enter-transition-time) cubic-bezier(0.5, 0.5, 0, 1);
    }
  }

  &.jenga-modal-transition-enter-done {
    display: flex;
  }

  &.jenga-modal-transition-exit {
    opacity: 1;
    display: flex;

    & .jenga-modal {
      transform: translate(0, calc(var(--base-translate))) scale(1);
    }
  }

  &.jenga-modal-transition-exit-active {
    opacity: 0;
    transition: all var(--leave-transition-time) ease-in;

    & .jenga-modal {
      transform: translate(0, calc(-32px + var(--base-translate))) scale(0.5);
      transition: all var(--leave-transition-time) ease-in;
    }
  }

  &.jenga-modal-transition-exit-done {
    display: none;
  }
`;
/**
 * @deprecated Prefer using Dialog instead
 *
 * DEPRECATED Modal component
 * Designed after AntD Modal component and almost duplicate its API.
 * Use Dialog component instead
 */
function Modal(allProps) {
    let { title, isVisible, type, okType, isClosable, isLoading, children, okText, cancelText, width, onOk, onCancel, onClose, qa, isDisabled, ...props } = allProps;
    isClosable = !!isClosable;
    const [inProp, setInProp] = (0, react_2.useState)(false);
    const [localLoading, setLocalLoading] = (0, react_2.useState)(false);
    (0, react_2.useEffect)(() => {
        setInProp(isVisible || false);
    }, [isVisible]);
    function cancel() {
        if (onCancel) {
            onCancel();
        }
        else if (onClose) {
            onClose();
        }
    }
    function close() {
        if (!isVisible)
            return;
        if (onClose || onCancel) {
            if (isClosable) {
                // @ts-ignore
                (onClose || onCancel)();
            }
            else if (onCancel) {
                onCancel();
            }
        }
    }
    const onOverlayClick = (evt) => {
        if (!evt || !evt.target)
            return;
        if (evt.target.classList.contains('jenga-modal-overlay') && !isLoading) {
            close();
        }
    };
    (0, react_2.useEffect)(() => {
        function handleKeyDown(evt) {
            if (evt.key === 'Escape' && !isLoading) {
                close();
            }
        }
        window.addEventListener('keydown', handleKeyDown);
        return () => {
            window.removeEventListener('keydown', handleKeyDown);
        };
    }, []);
    const handleOk = (0, react_2.useCallback)((arg) => {
        setLocalLoading(true);
        (async () => {
            if (onOk) {
                try {
                    if ((await onOk(arg)) === false && (onClose || onCancel)) {
                        // @ts-ignore
                        (onClose || onCancel)();
                    }
                }
                catch (e) {
                }
                finally {
                    setLocalLoading(false);
                }
            }
        })();
    }, [onOk]);
    return ((0, jsx_runtime_1.jsx)(react_transition_group_1.CSSTransition, { in: inProp, timeout: 250, classNames: "jenga-modal-transition", children: (0, jsx_runtime_1.jsx)(Overlay, { className: "jenga-modal-overlay", onClick: onOverlayClick, children: (0, jsx_runtime_1.jsxs)(Card_1.Card, { "data-qa": qa || 'Modal', className: "jenga-modal", display: "flex", role: "region", color: "#dark.85", padding: "0", shadow: true, border: false, radius: "1.5r", width: `288px (100% - 32px) ${typeof width === 'number' ? `${width}px` : width || '360px'}`, style: { textAlign: 'left' }, ...props, children: [(0, jsx_runtime_1.jsxs)(Flex_1.Flex, { placeContent: "space-between", padding: "2x 3x", border: "bottom", children: [typeof title === 'object' ? (title) : ((0, jsx_runtime_1.jsx)(Title_1.Title, { ellipsis: true, level: 4, flexGrow: 1, children: title }, void 0)), isClosable ? ((0, jsx_runtime_1.jsx)(Action_1.Action, { qa: "ModalCloseButton", width: "3x", height: "3x", color: { '': '#dark.75', hovered: '#purple' }, outline: {
                                    '': '#purple-03.0',
                                    'focused & focus-visible': '#purple-03',
                                }, label: "Close", onPress: onClose || onCancel, children: (0, jsx_runtime_1.jsx)(react_3.X, { style: { fontSize: 16 } }, void 0) }, void 0)) : null] }, void 0), (0, jsx_runtime_1.jsxs)(Flow_1.Flow, { padding: "3x", gap: "3x", height: "max (100vh - 90px)", style: { overflow: 'auto' }, children: [typeof children === 'string' ? ((0, jsx_runtime_1.jsx)(Block_1.Block, { children: children }, void 0)) : (children), type !== 'info' && (onOk || onCancel) ? ((0, jsx_runtime_1.jsxs)(Space_1.Space, { gap: "1.5x", children: [(0, jsx_runtime_1.jsx)(actions_1.Button, { "data-qa": 'ConfirmButton', isDisabled: isDisabled, type: "primary", theme: okType === 'danger' ? 'danger' : undefined, isLoading: isLoading || localLoading, onPress: handleOk, children: okText || 'OK' }, void 0), (0, jsx_runtime_1.jsx)(actions_1.Button, { "data-qa": 'CancelButton', isDisabled: isLoading, onPress: cancel, children: cancelText || (okText === 'Yes' ? 'No' : 'Cancel') }, void 0)] }, void 0)) : null, type === 'info' ? ((0, jsx_runtime_1.jsx)(Space_1.Space, { children: (0, jsx_runtime_1.jsx)(actions_1.Button, { "data-qa": 'OkButton', isDisabled: isDisabled, type: okType === 'danger' ? 'danger' : 'primary', onPress: close, children: okText || 'OK' }, void 0) }, void 0)) : null] }, void 0)] }, void 0) }, void 0) }, void 0));
}
exports.Modal = Modal;
let ID = 0;
const modal = {
    root: null,
    items: [],
    init() {
        if (this.root)
            return;
        this.root = document.createElement('div');
        this.root.classList.add('jenga-modal-container');
        document.body.appendChild(this.root);
        this._render([]);
    },
    render() {
        this.init();
        this._render();
    },
    _render(items) {
        if (!items) {
            items = this.items;
        }
        react_dom_1.default.render(items.map((item) => {
            const { id, onOk, onCancel, onClose, content, ...options } = item;
            const wrapOnOk = async (arg) => {
                onOk && (await onOk(arg));
                this.resolve(item, arg);
            };
            const wrapOnCancel = () => {
                onCancel && onCancel();
                if (item.type === 'info') {
                    this.resolve(item);
                }
                else {
                    this.reject(item);
                }
            };
            const wrapOnClose = () => {
                onClose && onClose();
                if (item.type === 'info') {
                    this.resolve(item);
                }
                else {
                    this.reject(item);
                }
            };
            return ((0, react_1.createElement)(Modal, { ...options, key: id, onOk: wrapOnOk, onCancel: wrapOnCancel, onClose: wrapOnClose }, content));
        }), this.root);
    },
    open(item) {
        item.isVisible = false;
        item.id = ++ID;
        this.items.push(item);
        this.render();
        setTimeout(() => {
            item.isVisible = true;
            this.render();
        });
        return new Promise((resolve, reject) => {
            item.resolve = resolve;
            item.reject = reject;
        });
    },
    close(item) {
        item.isVisible = false;
        this.render();
        setTimeout(() => {
            this.items = this.items.filter((modal) => item.id !== modal.id);
            this.render();
        }, 1000);
    },
    resolve(item, arg) {
        item.resolve(arg);
        this.close(item);
    },
    reject(item, arg) {
        item.reject(arg);
        this.close(item);
    },
};
Modal.confirm = (options) => {
    return modal.open({ type: 'confirm', ...options });
};
Modal.info = (options) => {
    return modal.open({ type: 'info', ...options });
};

        