/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Base64Upload = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const styled_components_1 = __importDefault(require("styled-components"));
const actions_1 = require("../../actions");
const Block_1 = require("../../Block");
const Text_1 = require("../../content/Text");
const tasty_1 = require("../../../tasty");
const DEFAULT_STYLES = {
    display: 'inline-flex',
    padding: '.75x 1x',
    gap: '1x',
    flow: 'row',
    placeItems: 'center',
    fill: '#white',
    border: true,
    preset: 't3',
};
exports.Base64Upload = (0, styled_components_1.default)((0, react_1.forwardRef)(function Base64Upload(allProps, ref) {
    const { onInput, ...props } = allProps;
    const styles = (0, tasty_1.extractStyles)(props, tasty_1.POSITION_STYLES, DEFAULT_STYLES);
    const [file, setFile] = (0, react_1.useState)();
    const [error, setError] = (0, react_1.useState)('');
    function onInputFile(e) {
        if (!e.target)
            return;
        const localFile = e.target.files[0];
        const reader = new FileReader();
        setError('');
        if (!localFile)
            return;
        if (!localFile.name.endsWith('.json')) {
            setError('Incorrect format. JSON file is required');
            return;
        }
        reader.onload = function () {
            /**
             * @type {string}
             */
            const text = String(reader.result);
            let base64text;
            try {
                JSON.parse(text);
                base64text = btoa(text);
            }
            catch (e) {
                setError('Invalid JSON file');
                console.error(e);
                return;
            }
            onInput &&
                onInput({
                    encoded: base64text,
                    raw: JSON.parse(text),
                });
            setFile(localFile.name);
        };
        try {
            reader.readAsText(localFile);
        }
        catch (e) {
            setError('Invalid file');
        }
    }
    return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsxs)(actions_1.Button, { ...(0, tasty_1.filterBaseProps)(props, { eventProps: true }), ref: ref, styles: styles, children: [(0, jsx_runtime_1.jsx)(Block_1.Block, { radius: "round", fill: "#purple.10", color: "#dark-02", padding: ".5x 1x", children: "Choose file" }, void 0), (0, jsx_runtime_1.jsx)(Block_1.Block, { color: "#dark-04", children: file || 'No file selected' }, void 0), (0, jsx_runtime_1.jsx)("input", { type: "file", name: "base64", accept: ".json", onInput: onInputFile }, void 0)] }, void 0), error && (0, jsx_runtime_1.jsx)(Text_1.Text.Danger, { color: "danger", children: error }, void 0)] }, void 0));
})) `
  appearance: none;
  cursor: pointer;
  outline: none;

  & input {
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    opacity: 0;
    cursor: pointer;
    width: 100%;
    height: 100%;
  }

  && {
    border: var(--border-width) solid rgba(var(--dark-02-color-rgb), 0.1);
  }

  &&:not([data-is-hovered]) {
    background: rgba(var(--purple-color), 0);
  }

  &&[data-is-hovered] {
    background: rgba(var(--purple-color), 0.1);
  }
`;

        