/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Dialog = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const styled_components_1 = __importDefault(require("styled-components"));
const utils_1 = require("@react-spectrum/utils");
const overlays_1 = require("@react-aria/overlays");
const react_1 = require("react");
const dialog_1 = require("@react-aria/dialog");
const i18n_1 = require("@react-aria/i18n");
const react_2 = require("@jengaicons/react");
const react_focus_lock_1 = __importDefault(require("react-focus-lock"));
const tasty_1 = require("../../../tasty");
const react_3 = require("../../../utils/react");
const actions_1 = require("../../actions");
const OpenTransition_1 = require("../Modal/OpenTransition");
const context_1 = require("./context");
const STYLES_LIST = [...tasty_1.BASE_STYLES, ...tasty_1.DIMENSION_STYLES, ...tasty_1.BLOCK_STYLES];
const DialogElement = (0, tasty_1.tasty)({
    as: 'section',
    styles: {
        pointerEvents: 'auto',
        position: 'relative',
        display: 'flex',
        placeItems: 'stretch',
        placeContent: 'stretch',
        width: {
            '': '288px @dialog-size 90vw',
            '[data-type="fullscreen"]': '90vw 90vw',
            '[data-type="fullscreenTakeover"]': '100vw 100vw',
            '[data-type="panel"]': '100vw 100vw',
        },
        height: {
            '': 'max 90vh',
            '[data-type="fullscreenTakeover"] | [data-type="panel"]': 'max 100vh',
        },
        gap: 0,
        flow: 'column',
        radius: {
            '': '2r',
            '[data-type="tray"]': '2r top',
            '[data-type="fullscreenTakeover"] | [data-type="panel"]': '0r',
        },
        fill: '#white',
        shadow: {
            '': '0 20px 30px #shadow',
            '[data-type="popover"]': '0px 4px 16px #shadow',
        },
        transform: {
            '': false,
            '[data-type="modal"]': 'translate(0, ((50vh - 50%) / -3))',
        },
        placeSelf: 'stretch',
        '@dialog-heading-padding-v': {
            '': '2x',
            '[data-type="popover"]': '1x',
        },
        '@dialog-content-padding-v': {
            '': '3x',
            '[data-type="popover"]': '2x',
        },
        '@dialog-padding-h': {
            '': '3x',
            '[data-type="popover"]': '2x',
        },
        '@dialog-footer-v': {
            '': '2x',
            '[data-type="popover"]': '1x',
        },
        '@dialog-content-gap': '3x',
    },
});
const StyledFocusLock = (0, styled_components_1.default)(react_focus_lock_1.default) `
  display: contents;
`;
const CLOSE_BUTTON_STYLES = {
    display: 'flex',
    position: 'absolute',
    top: '1x',
    right: '1x',
    width: '5x',
    height: '5x',
    placeContent: 'center',
};
const sizeMap = {
    S: 'small',
    M: 'medium',
    L: 'large',
};
const sizePxMap = {
    small: 360,
    medium: 479,
    large: 798,
};
const intlMessages = {
    'en-US': {
        dismiss: 'Dismiss',
        alert: 'Alert',
    },
};
/**
 * Dialogs are windows containing contextual information, tasks, or workflows that appear over the user interface.
 * Depending on the kind of Dialog, further interactions may be blocked until the Dialog is acknowledged.
 */
exports.Dialog = (0, react_1.forwardRef)(function Dialog(props, ref) {
    const transitionContext = (0, OpenTransition_1.useOpenTransitionContext)();
    const isEntered = transitionContext?.transitionState === 'entered';
    return ((0, jsx_runtime_1.jsx)(StyledFocusLock, { returnFocus: true, disabled: !isEntered, children: (0, jsx_runtime_1.jsx)(DialogContent, { ...props, ref: ref }, "content") }, void 0));
});
const DialogContent = (0, react_1.forwardRef)(function DialogContent(props, ref) {
    let { type = 'modal', ...contextProps } = (0, context_1.useDialogContext)();
    let { qa, children, size = 'S', isDismissable = contextProps.isDismissable, onDismiss = contextProps.onClose, closeIcon, closeButtonStyles, ...otherProps } = props;
    size = sizeMap[size.toUpperCase()] || size;
    const styles = (0, tasty_1.extractStyles)(otherProps, STYLES_LIST);
    let formatMessage = (0, i18n_1.useMessageFormatter)(intlMessages);
    let domRef = (0, utils_1.useDOMRef)(ref);
    let { dialogProps, titleProps } = (0, dialog_1.useDialog)((0, react_3.mergeProps)(contextProps, props), domRef);
    // If rendered in a popover or tray there won't be a visible dismiss button,
    // so we render a hidden one for screen readers.
    let dismissButton;
    if (type === 'popover' || type === 'tray') {
        dismissButton = (0, jsx_runtime_1.jsx)(overlays_1.DismissButton, { onDismiss: onDismiss }, void 0);
    }
    // let hasHeader = useHasChild('[data-id="Header"]', domRef);
    // let hasFooter = useHasChild('[data-id="Footer"]', domRef);
    let slots = {
        heading: {
            level: 2,
            preset: 'h4',
            ...titleProps,
        },
        content: {
            styles: {
                flexGrow: 1,
                padding: '@dialog-content-padding-v @dialog-padding-h',
                gap: '@dialog-content-gap',
                height: {
                    '': 'max (100% - (2 * @dialog-content-padding-v))',
                    ':last-child': 'max (100% - @dialog-content-padding-v)',
                },
            },
        },
        header: {
            ellipsis: true,
            styles: {
                display: 'flex',
                flow: 'row',
                gap: '1x',
                placeItems: 'baseline stretch',
                placeContent: 'space-between',
                padding: `@dialog-heading-padding-v ${isDismissable ? '(@dialog-padding-h + 4x)' : '@dialog-padding-h'} @dialog-heading-padding-v @dialog-padding-h`,
                border: 'bottom',
            },
        },
        footer: {
            styles: {
                display: 'flex',
                gap: '1x',
                flow: 'row',
                placeItems: 'baseline stretch',
                placeContent: 'space-between',
                padding: '@dialog-footer-v @dialog-padding-h',
            },
        },
    };
    return ((0, jsx_runtime_1.jsxs)(DialogElement, { ref: domRef, "data-id": "Dialog", "data-qa": qa || 'Dialog', styles: styles, as: "section", ...dialogProps, mods: { dismissable: isDismissable }, style: { '--dialog-size': `${sizePxMap[size] || 288}px` }, "data-type": type, "data-size": size, children: [dismissButton, (0, jsx_runtime_1.jsxs)(react_3.SlotProvider, { slots: slots, children: [isDismissable && ((0, jsx_runtime_1.jsx)(actions_1.Button, { qa: "ModalCloseButton", type: "neutral", styles: CLOSE_BUTTON_STYLES, icon: closeIcon || (0, jsx_runtime_1.jsx)(react_2.X, {}, void 0), label: formatMessage('dismiss'), onPress: () => onDismiss && onDismiss() }, void 0)), children] }, void 0)] }, void 0));
});

        