/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DialogContainer = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const Modal_1 = require("../Modal/Modal");
const context_1 = require("./context");
/**
 * A DialogContainer accepts a single Dialog as a child, and manages to show and hide
 * it in a modal.
 * Useful in cases where there is no trigger element
 * or when the trigger unmounts while the dialog is open.
 */
function DialogContainer(props) {
    const { children, type = 'modal', onDismiss, isDismissable, isKeyboardDismissDisabled, isOpen, } = props;
    const childArray = react_1.Children.toArray(children);
    if (childArray.length > 1) {
        throw new Error('Only a single child can be passed to DialogContainer.');
    }
    const lastChild = (0, react_1.useRef)();
    const child = (0, react_1.isValidElement)(childArray[0]) ? childArray[0] : null;
    if (child) {
        lastChild.current = child;
    }
    const isActuallyOpened = typeof isOpen !== 'boolean' ? !!child : isOpen;
    const context = {
        type,
        onClose: onDismiss,
        isDismissable,
    };
    return ((0, jsx_runtime_1.jsx)(Modal_1.Modal, { isOpen: isActuallyOpened, type: type, isDismissable: isDismissable, isKeyboardDismissDisabled: isKeyboardDismissDisabled, onClose: isDismissable ? onDismiss : undefined, children: (0, jsx_runtime_1.jsx)(context_1.DialogContext.Provider, { value: context, children: child }, void 0) }, void 0));
}
exports.DialogContainer = DialogContainer;

        