/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DialogTrigger = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const overlays_1 = require("@react-stately/overlays");
const interactions_1 = require("@react-aria/interactions");
const utils_1 = require("@react-spectrum/utils");
const overlays_2 = require("@react-aria/overlays");
const Modal_1 = require("../Modal");
const context_1 = require("./context");
function DialogTrigger(props) {
    let { children, type = 'modal', mobileType = type === 'popover' ? 'modal' : type, hideArrow, targetRef, onDismiss, isDismissable = true, isKeyboardDismissDisabled, styles, mobileViewport = 700, hideOnClose, shouldCloseOnInteractOutside, ...positionProps } = props;
    if (!Array.isArray(children) || children.length > 2) {
        throw new Error('DialogTrigger must have exactly 2 children');
    }
    // if a function is passed as the second child, it won't appear in toArray
    let [trigger, content] = children;
    // On small devices, show a modal or tray instead of a popover.
    let isMobile = (0, utils_1.useMediaQuery)(`(max-width: ${mobileViewport}px)`);
    if (isMobile) {
        // handle cases where desktop popovers need a close button for the mobile modal view
        if (type !== 'modal' && mobileType === 'modal') {
            isDismissable = true;
        }
        type = mobileType;
    }
    let state = (0, overlays_1.useOverlayTriggerState)(props);
    let wasOpen = (0, react_1.useRef)(false);
    let isExiting = (0, react_1.useRef)(false);
    let onExiting = () => (isExiting.current = true);
    let onExited = () => (isExiting.current = false);
    wasOpen.current = state.isOpen;
    (0, react_1.useEffect)(() => {
        return () => {
            if ((wasOpen.current || isExiting.current) &&
                type !== 'popover' &&
                type !== 'tray') {
                console.warn('JengaUIKit: A DialogTrigger unmounted while open. This is likely due to being placed within a trigger that unmounts or inside a conditional. Consider using a DialogContainer instead.');
            }
        };
    }, []);
    function onClose(action) {
        if (isDismissable) {
            onDismiss && onDismiss(action);
            state.close();
        }
    }
    if (type === 'popover') {
        return ((0, jsx_runtime_1.jsx)(PopoverTrigger, { ...positionProps, hideOnClose: hideOnClose, state: state, targetRef: targetRef, trigger: trigger, content: content, isKeyboardDismissDisabled: isKeyboardDismissDisabled, hideArrow: hideArrow, shouldCloseOnInteractOutside: shouldCloseOnInteractOutside, onClose: onClose }, void 0));
    }
    let renderOverlay = () => {
        switch (type) {
            case 'panel':
            case 'fullscreen':
            case 'fullscreenTakeover':
            case 'modal':
                return ((0, jsx_runtime_1.jsx)(Modal_1.Modal, { hideOnClose: hideOnClose, isOpen: state.isOpen, isDismissable: isDismissable, type: type, isKeyboardDismissDisabled: isKeyboardDismissDisabled, styles: styles, shouldCloseOnInteractOutside: shouldCloseOnInteractOutside, onClose: onClose, onExiting: onExiting, onExited: onExited, children: typeof content === 'function' ? content(state.close) : content }, void 0));
            case 'tray':
                return ((0, jsx_runtime_1.jsx)(Modal_1.Tray, { hideOnClose: hideOnClose, isOpen: state.isOpen, isKeyboardDismissDisabled: isKeyboardDismissDisabled, styles: styles, onClose: onClose, children: typeof content === 'function' ? content(state.close) : content }, void 0));
        }
    };
    return ((0, jsx_runtime_1.jsx)(DialogTriggerBase, { type: type, state: state, isDismissable: isDismissable, trigger: trigger, overlay: renderOverlay(), onClose: onClose }, void 0));
}
/**
 * DialogTrigger serves as a wrapper around a Dialog and its associated trigger, linking the Dialog's
 * open state with the trigger's press state. Additionally, it allows you to customize the type and
 * positioning of the Dialog.
 */
let _DialogTrigger = DialogTrigger;
exports.DialogTrigger = _DialogTrigger;
function PopoverTrigger(allProps) {
    let { state, targetRef, trigger, content, hideArrow, onClose, isKeyboardDismissDisabled, hideOnClose, shouldCloseOnInteractOutside, ...props } = allProps;
    let triggerRef = (0, react_1.useRef)(null);
    let overlayRef = (0, react_1.useRef)(null);
    let { overlayProps: popoverProps, placement, arrowProps, updatePosition, } = (0, overlays_2.useOverlayPosition)({
        targetRef: targetRef || triggerRef,
        overlayRef: overlayRef,
        placement: props.placement,
        containerPadding: props.containerPadding,
        offset: props.offset || 8,
        crossOffset: props.crossOffset,
        shouldFlip: props.shouldFlip,
        isOpen: state.isOpen,
    });
    let { triggerProps, overlayProps } = (0, overlays_2.useOverlayTrigger)({ type: 'dialog' }, state, triggerRef);
    let triggerPropsWithRef = {
        ...triggerProps,
        ref: targetRef ? undefined : triggerRef,
    };
    let overlay = ((0, jsx_runtime_1.jsx)(Modal_1.Popover, { ref: overlayRef, hideOnClose: hideOnClose, isOpen: state.isOpen, style: popoverProps.style, placement: placement, arrowProps: arrowProps, isKeyboardDismissDisabled: isKeyboardDismissDisabled, hideArrow: hideArrow, updatePosition: updatePosition, shouldCloseOnInteractOutside: shouldCloseOnInteractOutside, onClose: onClose, children: typeof content === 'function' ? content(state.close) : content }, void 0));
    return ((0, jsx_runtime_1.jsx)(DialogTriggerBase, { type: "popover", state: state, triggerProps: triggerPropsWithRef, dialogProps: overlayProps, trigger: trigger, overlay: overlay, onClose: onClose }, void 0));
}
function DialogTriggerBase(props) {
    let { type, state, onClose, isDismissable, dialogProps = {}, triggerProps = {}, overlay, trigger, } = props;
    let context = {
        type,
        onClose,
        isDismissable,
        ...dialogProps,
    };
    return ((0, jsx_runtime_1.jsxs)(react_1.Fragment, { children: [(0, jsx_runtime_1.jsx)(interactions_1.PressResponder, { ...triggerProps, isPressed: state.isOpen &&
                    type !== 'modal' &&
                    type !== 'fullscreen' &&
                    type !== 'fullscreenTakeover', onPress: state.toggle, children: trigger }, void 0), (0, jsx_runtime_1.jsx)(context_1.DialogContext.Provider, { value: context, children: overlay }, void 0)] }, void 0));
}

        