/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Modal = exports.OVERLAY_WRAPPER_STYLES = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const utils_1 = require("@react-spectrum/utils");
const react_1 = require("react");
const overlays_1 = require("@react-aria/overlays");
const tasty_1 = require("../../../tasty");
const react_2 = require("../../../utils/react");
const Underlay_1 = require("./Underlay");
const Overlay_1 = require("./Overlay");
exports.OVERLAY_WRAPPER_STYLES = {
    position: 'fixed',
    display: 'grid',
    left: 0,
    top: 0,
    placeItems: {
        '': 'center',
        '[data-type="fullscreen"]': 'center',
        '[data-type="fullscreenTakeover"] | [data-type="panel"]': 'stretch',
    },
    boxSizing: 'border-box',
    width: '100vw',
    height: '100dvh',
    pointerEvents: 'none',
    zIndex: 2,
    transition: {
        '': 'visibility .5s steps(2, start)',
        open: 'visibility 0s linear',
    },
};
const ModalWrapperElement = (0, tasty_1.tasty)({
    qa: 'ModalWrapper',
    styles: exports.OVERLAY_WRAPPER_STYLES,
});
const ModalElement = (0, tasty_1.tasty)({
    styles: {
        display: {
            '': 'none',
            'entering | entered': 'grid',
            exiting: 'grid',
            exited: 'none',
        },
        zIndex: 2,
        height: {
            '': 'max 90dvh',
            '[data-type="fullscreenTakeover"] | [data-type="panel"]': '100dvh 100dvh',
            '[data-type="fullscreen"]': '90dvh 90dvh',
            '[data-type="fullscreenTakeover"]': '100dvh 100dvh',
        },
        width: {
            width: '288px 90vw',
        },
        pointerEvents: 'none',
        transition: 'opacity .25s linear, transform .25s ease-in-out',
        transform: {
            '': 'translate(0, 0) scale(1, 1)',
            '[data-type="modal"] & !open': 'translate(0, -3x) scale(1, 1)',
            '[data-type^="fullscreen"] & !open': 'translate(0, 0) scale(1.02, 1.02)',
        },
        opacity: {
            '': 0,
            open: 0.9999,
        },
    },
});
function Modal(props, ref) {
    let { qa, children, onClose, type, styles, ...otherProps } = props;
    let domRef = (0, utils_1.useDOMRef)(ref);
    let { overlayProps, underlayProps } = (0, overlays_1.useOverlay)({ ...props }, domRef);
    return ((0, jsx_runtime_1.jsxs)(Overlay_1.Overlay, { ...otherProps, children: [type !== 'fullscreenTakeover' && (0, jsx_runtime_1.jsx)(Underlay_1.Underlay, { ...underlayProps }, void 0), (0, jsx_runtime_1.jsx)(ModalWrapper, { ref: domRef, qa: qa, type: type, overlayProps: overlayProps, styles: styles, onClose: onClose, children: children }, void 0)] }, void 0));
}
let ModalWrapper = (0, react_1.forwardRef)(function ModalWrapper(props, ref) {
    let { qa, children, isOpen, type, placement, styles, overlayProps, transitionState, ...otherProps } = props;
    (0, overlays_1.usePreventScroll)({ isDisabled: transitionState !== 'entered' });
    let { modalProps } = (0, overlays_1.useModal)({ isDisabled: transitionState !== 'entered' });
    return ((0, jsx_runtime_1.jsx)(ModalWrapperElement, { "data-type": type, "data-placement": placement, children: (0, jsx_runtime_1.jsx)(ModalElement, { qa: qa || 'Modal', styles: styles, mods: {
                open: isOpen,
                entering: transitionState === 'entering',
                exiting: transitionState === 'exiting',
                exited: transitionState === 'exited',
                entered: transitionState === 'entered',
            }, "data-type": type, "data-placement": placement, ...(0, react_2.mergeProps)(otherProps, overlayProps, modalProps), ref: ref, children: children }, void 0) }, void 0));
});
let _Modal = (0, react_1.forwardRef)(Modal);
exports.Modal = _Modal;

        