/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NotificationView = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const interactions_1 = require("@react-aria/interactions");
const focus_1 = require("@react-aria/focus");
const tasty_1 = require("../../../../tasty");
const _internal_1 = require("../../../../_internal");
const react_2 = require("../../../../utils/react");
const useId_1 = require("../../../../utils/react/useId");
const NotificationIcon_1 = require("./NotificationIcon");
const NotificationHeader_1 = require("./NotificationHeader");
const NotificationDescription_1 = require("./NotificationDescription");
const NotificationFooter_1 = require("./NotificationFooter");
const NotificationCloseButton_1 = require("./NotificationCloseButton");
const NotificationProvider_1 = require("./NotificationProvider");
const NotificationContainer = (0, tasty_1.tasty)({
    styles: {
        boxSizing: 'border-box',
        position: 'relative',
        display: 'grid',
        width: '100%',
        padding: '0.5x 0.5x 1.5x 1.5x',
        gridAreas: `
      ".    . .           .      close"
      "icon . header      .      close"
      "icon . description .      close"
      ".    . footer      footer footer"
    `,
        gridColumns: 'min-content 1x minmax(0, auto) 1x minmax(0, min-content)',
        gridRows: '1x minmax(0, auto) minmax(0, auto) minmax(0, auto)',
        fill: '#white',
        boxShadow: {
            '': '0 0 0 4bw #purple-04.0 inset',
            focused: '0 0 0 4bw #purple-04 inset',
        },
    },
});
/**
 * @internal This component is unstable and is a subject to change.
 */
exports.NotificationView = (0, react_1.forwardRef)(function NotificationView(props, ref) {
    const { onClose, actions, header, icon, description, id, styles, type = 'attention', isDismissible = true, duration = null, attributes = {}, qa = 'notification', timer: propsTimer, onDismiss, } = props;
    const labelID = (0, useId_1.useId)();
    const descriptionID = (0, useId_1.useId)();
    const onCloseEvent = (0, _internal_1.useEvent)(() => {
        onClose?.();
    });
    const onDismissEvent = (0, _internal_1.useEvent)(() => {
        if (isDismissible) {
            onDismiss?.();
        }
    });
    const { hoverProps, isHovered } = (0, interactions_1.useHover)({});
    const { isFocusVisible, focusProps } = (0, focus_1.useFocusRing)({ within: true });
    (0, _internal_1.useTimer)({
        timer: propsTimer,
        delay: duration,
        callback: onDismissEvent,
        isDisabled: isFocusVisible || isHovered || !isDismissible,
    });
    return ((0, jsx_runtime_1.jsx)(react_2.ClearSlots, { children: (0, jsx_runtime_1.jsx)(NotificationProvider_1.NotificationProvider, { onClose: onClose, children: (0, jsx_runtime_1.jsxs)(NotificationContainer, { ...(0, react_2.mergeProps)(attributes, hoverProps, focusProps), ref: ref, styles: styles, "data-id": id, "data-qa": qa, "aria-labelledby": labelID, "aria-describedby": descriptionID, mods: { focused: isFocusVisible, 'is-dismissible': isDismissible }, children: [(0, jsx_runtime_1.jsx)(NotificationIcon_1.NotificationIcon, { icon: icon, type: type }, void 0), (0, jsx_runtime_1.jsx)(NotificationHeader_1.NotificationHeader, { header: header, id: labelID }, void 0), description && ((0, jsx_runtime_1.jsx)(NotificationDescription_1.NotificationDescription, { description: description, id: descriptionID }, void 0)), (0, jsx_runtime_1.jsx)(NotificationFooter_1.NotificationFooter, { hasDescription: !!description, actions: actions, onClose: onCloseEvent, onDismiss: onDismissEvent }, void 0), isDismissible && ((0, jsx_runtime_1.jsx)(NotificationCloseButton_1.NotificationCloseButton, { onPress: onDismissEvent }, void 0))] }, void 0) }, void 0) }, void 0));
});

        