/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useNotifications = void 0;
const react_1 = require("react");
const _internal_1 = require("../../../../_internal");
const DISMISS_EVENT_NAME = 'jenga:notification:dismiss';
function useNotifications(rootRef) {
    const idPrefix = (0, react_1.useMemo)(() => new Date().getTime(), []);
    const idRef = (0, react_1.useRef)(0);
    const listeners = (0, react_1.useRef)([]);
    const [notifications, setNotifications] = (0, react_1.useState)(new Map());
    const addToast = Object.assign((0, _internal_1.useEvent)((props) => {
        const nextID = idRef.current++;
        const { id = `${idPrefix}_${nextID}`, duration, isDismissible = true, ...rest } = props;
        setNotifications((toasts) => {
            const newToasts = new Map(toasts);
            newToasts.set(id, {
                id,
                isDismissible,
                duration: duration ?? (isDismissible ? 5000 : null),
                ...rest,
            });
            return newToasts;
        });
        return {
            id,
            remove: () => removeToast(id),
            update: (props) => updateToast(id, props),
        };
    }), {
        success: (props) => addToast({ type: 'success', ...props }),
        danger: (props) => addToast({ type: 'danger', ...props }),
        attention: (props) => addToast({ type: 'attention', ...props }),
    });
    const updateToast = (0, _internal_1.useEvent)((id, props) => {
        setNotifications((toasts) => {
            const currentToast = toasts.get(id);
            if (currentToast) {
                const newToasts = new Map(toasts);
                newToasts.set(id, {
                    ...currentToast,
                    ...props,
                });
                return newToasts;
            }
            return toasts;
        });
    });
    const removeToast = (0, _internal_1.useEvent)((id) => {
        setNotifications((toasts) => {
            if (toasts.has(id)) {
                const newToasts = new Map(toasts);
                newToasts.delete(id);
                return newToasts;
            }
            return toasts;
        });
    });
    const onDismissNotification = (0, _internal_1.useEvent)((id) => {
        const toast = notifications.get(id);
        if (toast == null) {
            return;
        }
        if (toast?.putNotificationInDropdownOnDismiss !== false) {
            rootRef?.current?.dispatchEvent(new CustomEvent(DISMISS_EVENT_NAME, { detail: toast }));
        }
    });
    const addOnDismissListener = (0, _internal_1.useEvent)((listener) => {
        const callback = (e) => listener(e.detail);
        const unsub = () => rootRef?.current?.removeEventListener(DISMISS_EVENT_NAME, callback);
        listeners.current.push(unsub);
        rootRef?.current?.addEventListener(DISMISS_EVENT_NAME, callback);
        return unsub;
    });
    (0, react_1.useEffect)(() => () => listeners.current.forEach((cb) => cb()), []);
    const api = (0, react_1.useMemo)(() => ({ notify: addToast, update: updateToast, remove: removeToast }), 
    // All deps are stable since we use `useEvent` hook
    // eslint-disable-next-line react-hooks/exhaustive-deps
    []);
    return {
        api,
        notifications: (0, react_1.useMemo)(() => [...notifications.values()], [notifications]),
        onDismissNotification,
        addOnDismissListener,
    };
}
exports.useNotifications = useNotifications;

        