/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NotificationsList = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const collections_1 = require("@react-stately/collections");
const tasty_1 = require("../../../../tasty");
const hooks_1 = require("../hooks");
const NotificationsListItem_1 = require("./NotificationsListItem");
const NotificationListContainer = (0, tasty_1.tasty)({
    styles: { boxSizing: 'border-box', width: '100%' },
});
/**
 * Provides ability to show notifications as a list.
 *
 * @example
 *   <NotificationsList>
 *     <NotificationsList.Item key="id_1" type="success" description="Edit and test your schema without affecting the production." />
 *     <NotificationsList.Item key="id_2" type="attention" description="Edit and test your schema without affecting the production." />
 *     <NotificationsList.Item key="id_3" type="danger" description="Edit and test your schema without affecting the production." />
 *   </NotificationsList>
 *
 * @example Removing a notification
 *   <NotificationsList onDismiss={(id) => removeNotification(id)}>
 *     <NotificationsList.Item key="id_1" type="success" description="Edit and test your schema without affecting the production." />
 *   </NotificationsList>
 */
function NotificationsList(props) {
    const { items, children, onDismiss } = props;
    const ref = (0, react_1.useRef)(null);
    const { state, listProps } = (0, hooks_1.useNotificationsList)({
        items,
        children,
        ref,
    });
    return ((0, jsx_runtime_1.jsx)(NotificationListContainer, { ref: ref, ...listProps, children: [...state.collection].map((item) => ((0, jsx_runtime_1.jsx)(NotificationsListItem_1.NotificationListItem, { item: item, state: state, onDismiss: onDismiss }, item.key))) }, void 0));
}
exports.NotificationsList = NotificationsList;
NotificationsList.Item = collections_1.Item;

        