/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tooltip = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const utils_1 = require("@react-spectrum/utils");
const tooltip_1 = require("@react-aria/tooltip");
const styled_components_1 = __importDefault(require("styled-components"));
const transitions_1 = require("../../../utils/transitions");
const tasty_1 = require("../../../tasty");
const react_2 = require("../../../utils/react");
const context_1 = require("./context");
const TooltipElement = (0, tasty_1.tasty)({
    styles: {
        display: 'block',
        fill: '#dark.85',
        color: '#white',
        width: 'initial 36x max-content',
        radius: true,
        padding: '.75x 1x',
        preset: 't3',
        backdropFilter: 'blur(.5x)',
        whiteSpace: 'pre-line',
        pointerEvents: {
            '': 'none',
            material: 'auto',
        },
    },
});
const TooltipTipElement = (0, tasty_1.tasty)({
    styles: {
        position: 'absolute',
        width: '1px',
        height: '1px',
        border: '.5x #clear',
        borderTop: '.5x solid #dark.85',
        borderBottom: '0',
        top: {
            '': 'initial',
            '[data-placement="left"] | [data-placement="right"]': '50%',
            '[data-placement="top"]': '100%',
        },
        left: {
            '': 'initial',
            '[data-placement="top"] | [data-placement="bottom"]': '50%',
            '[data-placement="left"]': '100%',
        },
        right: {
            '': 'initial',
            '[data-placement="right"]': '100%',
        },
        bottom: {
            '': 'initial',
            '[data-placement="bottom"]': '100%',
        },
        transform: {
            '': 'translate((-.375x - 1px), 0)',
            '[data-placement="bottom"]': 'translate((-.375x - 1px), 0) rotate(180deg)',
            '[data-placement="left"]': 'translate(-.375x, -.25x) rotate(270deg)',
            '[data-placement="right"]': 'translate(.375x, -.25x) rotate(90deg)',
        },
    },
});
const StyledTooltipElement = (0, styled_components_1.default)(TooltipElement) `
  ${(props) => {
    return (0, transitions_1.getOverlayTransitionCSS)({
        placement: props?.['data-position'],
        minOffset: props?.['data-min-offset'],
        minScale: props?.['data-min-scale'],
    });
}}
`;
function Tooltip(props, ref) {
    let { ref: overlayRef, arrowProps, state, overlayProps, minOffset, minScale, ...tooltipProviderProps } = (0, react_1.useContext)(context_1.TooltipContext);
    let defaultRef = (0, react_1.useRef)(null);
    const finalOverlayRef = overlayRef ?? defaultRef;
    props = (0, react_2.mergeProps)(props, tooltipProviderProps);
    let { placement = 'top', isOpen, tipStyles, showIcon, isMaterial, ...otherProps } = props;
    const styles = (0, tasty_1.extractStyles)(otherProps, tasty_1.CONTAINER_STYLES);
    let { tooltipProps } = (0, tooltip_1.useTooltip)(props, state);
    // Sync ref with overlayRef from context.
    (0, react_1.useImperativeHandle)(ref, () => (0, utils_1.createDOMRef)(finalOverlayRef));
    if (typeof minOffset === 'number') {
        minOffset = `${minOffset}px`;
    }
    if (typeof minScale === 'number') {
        minScale = String(minScale);
    }
    return ((0, jsx_runtime_1.jsxs)(StyledTooltipElement, { ...tooltipProps, ...overlayProps, ref: overlayRef, styles: styles, mods: {
            open: isOpen,
            material: isMaterial,
        }, "data-min-offset": minOffset, "data-min-scale": minScale, "data-placement": placement, children: [props.children, (0, jsx_runtime_1.jsx)(TooltipTipElement, { "data-placement": placement, styles: tipStyles, ...arrowProps }, void 0)] }, void 0));
}
/**
 * Display container for Tooltip content. Has a directional arrow dependent on its placement.
 */
let _Tooltip = (0, react_1.forwardRef)(Tooltip);
exports.Tooltip = _Tooltip;

        