/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TooltipTrigger = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const focus_1 = require("@react-aria/focus");
const react_1 = require("react");
const overlays_1 = require("@react-aria/overlays");
const tooltip_1 = require("@react-aria/tooltip");
const tooltip_2 = require("@react-stately/tooltip");
const OverlayWrapper_1 = require("../OverlayWrapper");
const ActiveZone_1 = require("../../content/ActiveZone/ActiveZone");
const Block_1 = require("../../Block");
const context_1 = require("./context");
const DEFAULT_OFFSET = 8; // Offset needed to reach 4px/5px (med/large) distance between tooltip and trigger button
const DEFAULT_CROSS_OFFSET = 0;
function TooltipTrigger(props) {
    let { children, activeWrap, crossOffset = DEFAULT_CROSS_OFFSET, isDisabled, isMaterial, offset = DEFAULT_OFFSET, trigger: triggerAction, delay = 250, isOpen, onOpenChange, defaultOpen, } = props;
    let [trigger, tooltip] = react_1.Children.toArray(children);
    let state = (0, tooltip_2.useTooltipTriggerState)({ delay, ...props });
    let tooltipTriggerRef = (0, react_1.useRef)(null);
    let overlayRef = (0, react_1.useRef)(null);
    let { triggerProps, tooltipProps } = (0, tooltip_1.useTooltipTrigger)({
        isDisabled,
        trigger: triggerAction,
        delay,
        isOpen,
        onOpenChange,
        defaultOpen,
    }, state, tooltipTriggerRef);
    let { overlayProps, arrowProps, placement } = (0, overlays_1.useOverlayPosition)({
        placement: props.placement || 'top',
        targetRef: tooltipTriggerRef,
        overlayRef,
        offset,
        crossOffset,
        isOpen: state.isOpen,
    });
    if (!activeWrap && typeof trigger === 'string') {
        console.warn('JengaUIKit: Tooltips are only supported on elements that are both focusable and hoverable. To solve this issue you can: 1) Use active element as a trigger (`Button`, `Link`, etc); 2) Use `activeWrap` attribute to automatically wrap the content; 3) Use `ActiveZone` component to manually wrap the content.');
        return (0, jsx_runtime_1.jsx)(Block_1.Block, { children: trigger }, void 0);
    }
    function onClick(e) {
        e?.currentTarget?.parentNode.click();
    }
    return ((0, jsx_runtime_1.jsxs)(focus_1.FocusableProvider, { ...triggerProps, ref: tooltipTriggerRef, children: [activeWrap ? ((0, jsx_runtime_1.jsx)(ActiveZone_1.ActiveZone, { onClick: onClick, children: trigger }, void 0)) : (trigger), (0, jsx_runtime_1.jsx)(context_1.TooltipContext.Provider, { value: {
                    state,
                    placement,
                    ref: overlayRef,
                    overlayProps,
                    arrowProps,
                    minOffset: 'var(--gap)',
                    minScale: '1',
                    isMaterial,
                    ...tooltipProps,
                }, children: (0, jsx_runtime_1.jsx)(OverlayWrapper_1.OverlayWrapper, { isOpen: state.isOpen, placement: props.placement || 'top', children: tooltip }, void 0) }, void 0)] }, void 0));
}
/**
 * TooltipTrigger wraps around a trigger element and a Tooltip. It handles opening and closing
 * the Tooltip when the user hovers over or focuses the trigger, and positioning the Tooltip
 * relative to the trigger.
 */
let _TooltipTrigger = TooltipTrigger;
exports.TooltipTrigger = _TooltipTrigger;

        