/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ComboBox = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("@jengaicons/react");
const react_2 = require("react");
const combobox_1 = require("@react-stately/combobox");
const combobox_2 = require("@react-aria/combobox");
const button_1 = require("@react-aria/button");
const interactions_1 = require("@react-aria/interactions");
const i18n_1 = require("@react-aria/i18n");
const collections_1 = require("@react-stately/collections");
const overlays_1 = require("@react-aria/overlays");
const forms_1 = require("../../forms");
const provider_1 = require("../../../provider");
const tasty_1 = require("../../../tasty");
const interactions_2 = require("../../../utils/react/interactions");
const react_3 = require("../../../utils/react");
const FieldWrapper_1 = require("../../forms/FieldWrapper");
const Select_1 = require("../Select/Select");
const TextInputBase_1 = require("../../forms/TextInput/TextInputBase");
const OverlayWrapper_1 = require("../../overlays/OverlayWrapper");
const ComboBoxWrapperElement = (0, tasty_1.tasty)({
    styles: TextInputBase_1.INPUT_WRAPPER_STYLES,
});
const InputElement = (0, tasty_1.tasty)({
    as: 'input',
    styles: { ...TextInputBase_1.DEFAULT_INPUT_STYLES, width: ['60%', '70%', '100%'] },
});
const TriggerElement = (0, tasty_1.tasty)({
    as: 'button',
    styles: {
        display: 'grid',
        placeItems: 'center',
        placeContent: 'center',
        placeSelf: 'stretch',
        radius: 'right',
        width: '4x',
        color: {
            '': '#dark.75',
            hovered: '#dark.75',
            pressed: '#purple',
            '[disabled]': '#dark.30',
        },
        border: 0,
        reset: 'button',
        margin: 0,
        fill: {
            '': '#dark.0',
            hovered: '#dark.04',
            pressed: '#purple.10',
            disabled: '#clear',
        },
        cursor: 'pointer',
    },
});
exports.ComboBox = (0, react_2.forwardRef)(function ComboBox(props, ref) {
    props = (0, provider_1.useProviderProps)(props);
    props = (0, forms_1.useFormProps)(props);
    props = (0, forms_1.useFieldProps)(props, {
        valuePropsMapper: ({ value, onChange }) => ({
            inputValue: value != null ? value : '',
            onInputChange: (val) => onChange(val, !props.allowsCustomValue),
            onSelectionChange: onChange,
        }),
    });
    let { qa, label, extra, labelPosition = 'top', labelStyles, isRequired, necessityIndicator, validationState, icon, prefix, isDisabled, multiLine, autoFocus, wrapperRef, inputRef, triggerRef, popoverRef, listBoxRef, isLoading, loadingIndicator, overlayOffset = 8, inputStyles, optionStyles, triggerStyles, suffix, listBoxStyles, overlayStyles, hideTrigger, message, description, size, autoComplete = 'off', direction = 'bottom', shouldFlip = true, requiredMark = true, menuTrigger = 'input', suffixPosition = 'before', loadingState, filter, styles, labelSuffix, ...otherProps } = props;
    let isAsync = loadingState != null;
    let { contains } = (0, i18n_1.useFilter)({ sensitivity: 'base' });
    const comboboxProps = {
        ...otherProps,
        inputValue: props.inputValue,
        defaultInputValue: props.defaultInputValue,
        defaultItems: props.defaultItems,
        defaultSelectedKey: props.defaultSelectedKey,
        children: props.children,
        items: props.items,
        selectedKey: props.selectedKey,
        label: props.label,
        isDisabled: props.isDisabled,
        validationState: props.validationState,
        placeholder: props.placeholder,
        description: props.description,
        autoFocus: props.autoFocus,
        isRequired: props.isRequired,
        allowsCustomValue: props.allowsCustomValue,
        menuTrigger,
        disabledKeys: props.disabledKeys,
        name: props.name,
        onInputChange: props.onInputChange,
        errorMessage: props.errorMessage,
        isReadOnly: props.isReadOnly,
        onBlur: props.onBlur,
        onFocus: props.onFocus,
        onSelectionChange: props.onSelectionChange,
        onFocusChange: props.onFocusChange,
        onKeyDown: props.onKeyDown,
        onKeyUp: props.onKeyUp,
        onOpenChange: props.onOpenChange,
        defaultFilter: filter || contains,
        allowsEmptyCollection: isAsync,
    };
    let state = (0, combobox_1.useComboBoxState)({
        ...comboboxProps,
        defaultFilter: filter || contains,
        allowsEmptyCollection: isAsync,
    });
    const outerStyles = (0, tasty_1.extractStyles)(otherProps, tasty_1.OUTER_STYLES, styles);
    inputStyles = (0, tasty_1.extractStyles)(otherProps, tasty_1.BLOCK_STYLES, inputStyles);
    ref = (0, react_3.useCombinedRefs)(ref);
    wrapperRef = (0, react_3.useCombinedRefs)(wrapperRef);
    inputRef = (0, react_3.useCombinedRefs)(inputRef);
    triggerRef = (0, react_3.useCombinedRefs)(triggerRef);
    popoverRef = (0, react_3.useCombinedRefs)(popoverRef);
    listBoxRef = (0, react_3.useCombinedRefs)(listBoxRef);
    let { overlayProps, placement, updatePosition } = (0, overlays_1.useOverlayPosition)({
        targetRef: triggerRef,
        overlayRef: popoverRef,
        scrollRef: listBoxRef,
        placement: `${direction} end`,
        shouldFlip: shouldFlip,
        isOpen: state.isOpen,
        onClose: state.close,
        offset: overlayOffset,
    });
    let { labelProps, inputProps, listBoxProps, buttonProps: triggerProps, } = (0, combobox_2.useComboBox)({
        ...comboboxProps,
        inputRef,
        buttonRef: triggerRef,
        listBoxRef,
        popoverRef,
        menuTrigger,
    }, state);
    let { isFocused, focusProps } = (0, interactions_2.useFocus)({ isDisabled });
    let { hoverProps, isHovered } = (0, interactions_1.useHover)({ isDisabled });
    // Get props for the button based on the trigger props from useComboBox
    let { buttonProps, isPressed: isTriggerPressed } = (0, button_1.useButton)(triggerProps, triggerRef);
    let { hoverProps: triggerHoverProps, isHovered: isTriggerHovered } = (0, interactions_1.useHover)({ isDisabled });
    let { focusProps: triggerFocusProps, isFocused: isTriggerFocused } = (0, interactions_2.useFocus)({ isDisabled }, true);
    (0, react_3.useLayoutEffect)(() => {
        if (state.isOpen) {
            updatePosition();
        }
    }, [updatePosition, state.isOpen, state.collection.size]);
    let isInvalid = validationState === 'invalid';
    let validationIcon = isInvalid ? ((0, jsx_runtime_1.jsx)(react_1.Warning, { "data-element": "ValidationIcon", style: { color: 'var(--danger-color)' } }, void 0)) : ((0, jsx_runtime_1.jsx)(react_1.Check, { "data-element": "ValidationIcon", style: { color: 'var(--success-color)' } }, void 0));
    let validation = (0, react_2.cloneElement)(validationIcon);
    let comboBoxWidth = wrapperRef?.current?.offsetWidth;
    if (icon) {
        icon = (0, jsx_runtime_1.jsx)("div", { "data-element": "InputIcon", children: icon }, void 0);
        if (prefix) {
            prefix = ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [icon, prefix] }, void 0));
        }
        else {
            prefix = icon;
        }
    }
    let mods = (0, react_2.useMemo)(() => ({
        invalid: isInvalid,
        valid: validationState === 'valid',
        disabled: isDisabled,
        hovered: isHovered,
        focused: isFocused,
        loading: isLoading,
        prefix: !!prefix,
        suffix: true,
    }), [
        isInvalid,
        validationState,
        isDisabled,
        isHovered,
        isFocused,
        isLoading,
        prefix,
    ]);
    let comboBoxField = ((0, jsx_runtime_1.jsxs)(ComboBoxWrapperElement, { ref: wrapperRef, qa: qa || 'ComboBox', ...(0, react_3.modAttrs)(mods), styles: outerStyles, style: {
            zIndex: isFocused ? 1 : 'initial',
        }, "data-size": size, children: [(0, jsx_runtime_1.jsx)(InputElement, { qa: "Input", ...(0, react_3.mergeProps)(inputProps, hoverProps, focusProps), ref: inputRef, autoComplete: autoComplete, styles: inputStyles, ...(0, react_3.modAttrs)(mods), "data-size": size }, void 0), prefix ? (0, jsx_runtime_1.jsx)("div", { "data-element": "Prefix", children: prefix }, void 0) : null, (0, jsx_runtime_1.jsxs)("div", { "data-element": "Suffix", children: [suffixPosition === 'before' ? suffix : null, validationState || isLoading ? ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [validationState && !isLoading ? validation : null, isLoading ? (0, jsx_runtime_1.jsx)(react_1.CircleNotch, {}, void 0) : null] }, void 0)) : null, suffixPosition === 'after' ? suffix : null, !hideTrigger ? ((0, jsx_runtime_1.jsx)(TriggerElement, { qa: "ComboBoxTrigger", ...(0, react_3.mergeProps)(buttonProps, triggerFocusProps, triggerHoverProps), ...(0, react_3.modAttrs)({
                            pressed: isTriggerPressed,
                            focused: isTriggerFocused,
                            hovered: isTriggerHovered,
                            disabled: isDisabled,
                            loading: isLoading,
                        }), ref: triggerRef, "data-size": size, isDisabled: isDisabled, styles: triggerStyles, children: (0, jsx_runtime_1.jsx)(react_1.CaretDownFill, {}, void 0) }, void 0)) : null] }, void 0), (0, jsx_runtime_1.jsx)(OverlayWrapper_1.OverlayWrapper, { isOpen: state.isOpen && !isDisabled, children: (0, jsx_runtime_1.jsx)(Select_1.ListBoxPopup, { ...listBoxProps, shouldUseVirtualFocus: true, listBoxRef: listBoxRef, popoverRef: popoverRef, overlayProps: overlayProps, placement: placement, state: state, listBoxStyles: listBoxStyles, overlayStyles: overlayStyles, optionStyles: optionStyles, minWidth: comboBoxWidth }, void 0) }, void 0)] }, void 0));
    return ((0, jsx_runtime_1.jsx)(FieldWrapper_1.FieldWrapper, { ...{
            labelPosition,
            label,
            extra,
            styles,
            isRequired,
            labelStyles,
            necessityIndicator,
            labelProps,
            isDisabled,
            validationState,
            message,
            description,
            requiredMark,
            labelSuffix,
            Component: comboBoxField,
            ref: ref,
        } }, void 0));
});
exports.ComboBox.Item = collections_1.Item;
Object.defineProperty(exports.ComboBox, 'jengaInputType', {
    value: 'ComboBox',
    enumerable: false,
    configurable: false,
});

        