/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MenuItem = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const interactions_1 = require("@react-aria/interactions");
const focus_1 = require("@react-aria/focus");
const menu_1 = require("@react-aria/menu");
const react_2 = require("../../../utils/react");
const context_1 = require("./context");
const styled_1 = require("./styled");
const MenuButton_1 = require("./MenuButton");
/** @private */
function MenuItem(props) {
    const { item, state, styles, selectionIcon, isVirtualized, onAction } = props;
    const { onClose, closeOnSelect } = (0, context_1.useMenuContext)();
    const { rendered, key, props: itemProps } = item;
    const isSelectable = state.selectionManager.selectionMode !== 'none';
    const isDisabledKey = state.disabledKeys.has(key);
    const ref = (0, react_1.useRef)(null);
    const { hoverProps, isHovered } = (0, interactions_1.useHover)({ isDisabled: isDisabledKey });
    const { menuItemProps, labelProps, descriptionProps, keyboardShortcutProps, isFocused, isSelected, isPressed, isDisabled, } = (0, menu_1.useMenuItem)({
        isSelected: state.selectionManager.isSelected(key),
        isDisabled: isDisabledKey,
        'aria-label': item['aria-label'],
        key,
        onClose,
        closeOnSelect,
        isVirtualized,
        onAction,
    }, state, ref);
    const buttonProps = {
        qa: itemProps.qa ? itemProps.qa : `MenuButton-${key}`,
        mods: {
            ...itemProps.mods,
            hovered: isHovered,
            focused: isFocused,
            pressed: isPressed,
        },
    };
    const contents = ((0, jsx_runtime_1.jsx)(MenuButton_1.MenuButton, { ...(0, react_2.mergeProps)(itemProps, buttonProps), styles: styles, selectionIcon: selectionIcon, isSelectable: isSelectable, isSelected: isSelected, isDisabled: isDisabled, children: rendered }, void 0));
    return ((0, jsx_runtime_1.jsx)(focus_1.FocusRing, { children: (0, jsx_runtime_1.jsx)(styled_1.StyledMenuItem, { ...(0, react_2.mergeProps)(menuItemProps, hoverProps), ref: ref, "data-qa": itemProps.qa ? `MenuItem-${itemProps.qa}` : `MenuItem-${key}`, mods: {
                disabled: isDisabled,
                selected: isSelected,
                selectable: isSelectable,
                hovered: isHovered,
                focused: isFocused,
            }, children: (0, jsx_runtime_1.jsx)(react_2.ClearSlots, { children: (0, jsx_runtime_1.jsx)(react_2.SlotProvider, { slots: {
                        text: { className: 'itemLabel', ...labelProps },
                        end: { className: 'end', ...descriptionProps },
                        icon: { className: 'icon', size: 'S' },
                        description: { className: 'description', ...descriptionProps },
                        keyboard: { className: 'keyboard', ...keyboardShortcutProps },
                    }, children: contents }, void 0) }, void 0) }, void 0) }, void 0));
}
exports.MenuItem = MenuItem;

        