/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Select = exports.ListBoxPopup = void 0;
const react_1 = require("react");
const jsx_runtime_1 = require("react/jsx-runtime");
const react_2 = require("@jengaicons/react");
const react_3 = require("react");
const select_1 = require("@react-stately/select");
const select_2 = require("@react-aria/select");
const listbox_1 = require("@react-aria/listbox");
const button_1 = require("@react-aria/button");
const focus_1 = require("@react-aria/focus");
const overlays_1 = require("@react-aria/overlays");
const interactions_1 = require("@react-aria/interactions");
const collections_1 = require("@react-stately/collections");
const styled_components_1 = __importDefault(require("styled-components"));
const forms_1 = require("../../forms");
const provider_1 = require("../../../provider");
const tasty_1 = require("../../../tasty");
const interactions_2 = require("../../../utils/react/interactions");
const FieldWrapper_1 = require("../../forms/FieldWrapper");
const OverlayWrapper_1 = require("../../overlays/OverlayWrapper");
const transitions_1 = require("../../../utils/transitions");
const react_4 = require("../../../utils/react");
const TextInputBase_1 = require("../../forms/TextInput/TextInputBase");
const actions_1 = require("../../actions");
const SelectWrapperElement = (0, tasty_1.tasty)({
    styles: {
        display: 'grid',
        position: 'relative',
        radius: '2r',
        fill: {
            '': '#op-surface',
        },
        cursor: { '': 'pointer', disabled: 'not-allowed' },
        color: {
            '': '#op-text',
            invalid: '#op-text-critical',
        },
        Value: {
            ...TextInputBase_1.DEFAULT_INPUT_STYLES,
            fontSize: '14px',
            color: { '': 'inherit', placeholder: '#op-text-placeholder' },
            textAlign: 'left',
            fill: '#clear',
            textOverflow: 'ellipsis',
            overflow: {
                '': 'initial',
                ellipsis: 'hidden',
            },
        },
        CaretIcon: {
            display: 'grid',
            placeItems: 'center',
            width: 'min 4x',
            cursor: 'pointer',
            fontSize: 'inherit',
        },
        ButtonIcon: {
            display: 'grid',
            placeItems: 'center',
            width: 'min 4x',
            color: 'inherit',
            fontSize: '@icon-size',
        },
        width: ['60%', '70%', '100%'],
    },
});
const SelectElement = (0, tasty_1.tasty)({
    as: 'button',
    qa: 'Button',
    styles: {
        ...TextInputBase_1.INPUT_WRAPPER_STYLES,
        ...actions_1.DEFAULT_BUTTON_STYLES,
        cursor: 'pointer',
        padding: '0',
        gap: '0',
        minWidth: '100%',
        width: '100%',
        border: {
            '': '#op-border',
            valid: '#op-border-success',
            invalid: '#op-border-critical',
        },
        fill: {
            '': '#clear',
            '[data-type="primary"]': '#clear',
            '[data-type="secondary"]': '#clear',
            '[data-type="secondary"] & hovered': '#dark.04',
            '[data-type="secondary"] & pressed': '#dark.05',
            '([data-type="clear"] | [data-type="outline"])': '#purple.0',
            '([data-type="clear"] | [data-type="outline"]) & hovered': '#purple.16',
            '([data-type="clear"] | [data-type="outline"]) & pressed': '#purple.10',
            '([data-type="clear"] | [data-type="outline"]) & [disabled]': '#purple.0',
            // special
            '[data-theme="special"] & [data-type="secondary"]': '#white.12',
            '[data-theme="special"] & [data-type="clear"]': '#white',
            '[data-theme="special"] & [data-type="clear"] & hovered': '#white.94',
            '[data-theme="special"] & [data-type="clear"] & pressed': '#white',
            '[data-theme="special"] & [disabled]': '#white.12',
            '[data-theme="special"] & [data-type="clear"] & [disabled]': '#white.0',
        },
        color: {
            '': '#op-text',
            '[data-type="secondary"]': '#dark.75',
            '[data-type="secondary"] & hovered': '#dark.75',
            '[data-type="clear"]': '#purple-text',
            '[data-type="secondary"] & pressed': '#purple',
            // special
            '[data-theme="special"]': '#white',
            '[data-theme="special"] & [data-type="clear"]': '#purple',
            // other
            '[data-theme="special"] & [disabled]': '#white.30',
        },
    },
});
const ListBoxElement = (0, tasty_1.tasty)({
    as: 'ul',
    styles: {
        display: 'flex',
        gap: '.5x',
        flow: 'column',
        margin: '0',
        padding: '.5x',
        listStyle: 'none',
        radius: true,
        fill: '#white',
        shadow: '0px 4px 16px #shadow',
        height: 'initial 30x',
        overflow: 'hidden auto',
        styledScrollbar: true,
    },
});
const OptionElement = (0, tasty_1.tasty)({
    as: 'li',
    styles: {
        display: 'block',
        padding: '(1x - 1px) (1.5x - 1px)',
        cursor: 'pointer',
        radius: true,
        fill: {
            '': '#op-surface',
            'hovered | focused': '#op-surface-hovered',
            'pressed | selected': '#op-surface-active',
            disabled: '#dark.0',
        },
        color: {
            '': '#op-text',
            // 'hovered | focused': '#dark.75',
            // 'pressed | selected': '#purple',
            disabled: '#dark.3',
        },
        transition: 'theme',
        fontSize: '14px',
    },
});
const OverlayElement = (0, tasty_1.tasty)({
    styles: {
        position: 'absolute',
        width: 'min @overlay-min-width',
    },
});
const StyledOverlayElement = (0, styled_components_1.default)(OverlayElement) `
  ${(props) => {
    return (0, transitions_1.getOverlayTransitionCSS)({ placement: props?.['data-position'] });
}}
`;
function Select(props, ref) {
    props = (0, provider_1.useProviderProps)(props);
    props = (0, forms_1.useFormProps)(props);
    props = (0, forms_1.useFieldProps)(props, {
        defaultValidationTrigger: 'onChange',
        valuePropsMapper: ({ value, onChange }) => ({
            selectedKey: value ?? null,
            onSelectionChange: onChange,
        }),
    });
    let { qa, label, extra, icon, labelPosition = 'top', labelStyles, isRequired, necessityIndicator, validationState, prefix, isDisabled, autoFocus, inputProps, triggerRef, popoverRef, listBoxRef, isLoading, loadingIndicator, overlayOffset = 8, inputStyles, optionStyles, suffix, listBoxStyles, overlayStyles, message, description, direction = 'bottom', shouldFlip = true, requiredMark = true, placeholder, tooltip, size, styles, theme = 'default', labelSuffix, ellipsis, suffixPosition = 'before', ...otherProps } = props;
    let state = (0, select_1.useSelectState)(props);
    const outerStyles = (0, tasty_1.extractStyles)(otherProps, tasty_1.OUTER_STYLES, styles);
    inputStyles = (0, tasty_1.extractStyles)(otherProps, tasty_1.BLOCK_STYLES, inputStyles);
    ref = (0, react_4.useCombinedRefs)(ref);
    triggerRef = (0, react_4.useCombinedRefs)(triggerRef);
    popoverRef = (0, react_4.useCombinedRefs)(popoverRef);
    listBoxRef = (0, react_4.useCombinedRefs)(listBoxRef);
    let { labelProps, triggerProps, valueProps, menuProps } = (0, select_2.useSelect)(props, state, triggerRef);
    let { overlayProps, placement } = (0, overlays_1.useOverlayPosition)({
        targetRef: triggerRef,
        overlayRef: popoverRef,
        scrollRef: listBoxRef,
        placement: `${direction} end`,
        shouldFlip: shouldFlip,
        isOpen: state.isOpen,
        onClose: state.close,
        offset: overlayOffset,
    });
    let { isFocused, focusProps } = (0, interactions_2.useFocus)({ isDisabled }, true);
    let { hoverProps, isHovered } = (0, interactions_1.useHover)({ isDisabled });
    // Get props for the button based on the trigger props from useSelect
    let { buttonProps } = (0, button_1.useButton)(triggerProps, triggerRef);
    let isInvalid = validationState === 'invalid';
    let validationIcon = isInvalid ? ((0, jsx_runtime_1.jsx)(react_2.Warning, { "data-element": "ValidationIcon", style: { color: 'var(--danger-color)' } }, void 0)) : ((0, jsx_runtime_1.jsx)(react_2.Check, { "data-element": "ValidationIcon", style: { color: 'var(--success-color)' } }, void 0));
    let validation = (0, react_3.cloneElement)(validationIcon);
    let triggerWidth = triggerRef?.current?.offsetWidth;
    if (icon) {
        icon = (0, jsx_runtime_1.jsx)("div", { "data-element": "ButtonIcon", children: icon }, void 0);
        if (prefix) {
            prefix = ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [icon, prefix] }, void 0));
        }
        else {
            prefix = icon;
        }
    }
    const showPlaceholder = !!placeholder?.trim() && !state.selectedItem;
    const modifiers = (0, react_3.useMemo)(() => ({
        ellipsis,
        invalid: isInvalid,
        valid: validationState === 'valid',
        disabled: isDisabled,
        loading: isLoading,
        hovered: isHovered,
        focused: isFocused,
        placeholder: showPlaceholder,
        prefix: !!prefix,
        suffix: true,
    }), [
        ellipsis,
        validationState,
        isDisabled,
        isLoading,
        isHovered,
        isFocused,
        showPlaceholder,
        prefix,
    ]);
    let selectField = ((0, jsx_runtime_1.jsxs)(SelectWrapperElement, { qa: qa || 'Select', mods: modifiers, styles: outerStyles, "data-type": 'primary', "data-theme": theme, children: [(0, jsx_runtime_1.jsx)(select_2.HiddenSelect, { state: state, triggerRef: triggerRef, label: props.label, name: props.name }, void 0), (0, jsx_runtime_1.jsxs)(SelectElement, { ...(0, react_4.mergeProps)(buttonProps, hoverProps, focusProps), ref: triggerRef, styles: inputStyles, "data-theme": theme, "data-size": size, "data-type": 'primary', mods: modifiers, children: [prefix ? (0, jsx_runtime_1.jsx)("div", { "data-element": "Prefix", children: prefix }, void 0) : null, (0, jsx_runtime_1.jsx)("span", { "data-element": "Value", ...valueProps, children: state.selectedItem
                            ? state.selectedItem.rendered
                            : placeholder || (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: "\u00A0" }, void 0) }, void 0), (0, jsx_runtime_1.jsxs)("div", { "data-element": "Suffix", children: [suffixPosition === 'before' ? suffix : null, validationState && !isLoading ? validation : null, isLoading && (0, jsx_runtime_1.jsx)(react_2.CircleNotch, {}, void 0), suffixPosition === 'after' ? suffix : null, (0, jsx_runtime_1.jsx)("div", { "data-element": "CaretIcon", children: (0, jsx_runtime_1.jsx)(react_2.CaretDownFill, {}, void 0) }, void 0)] }, void 0)] }, void 0), (0, jsx_runtime_1.jsx)(OverlayWrapper_1.OverlayWrapper, { isOpen: state.isOpen && !isDisabled, children: (0, jsx_runtime_1.jsx)(ListBoxPopup, { ...menuProps, popoverRef: popoverRef, listBoxRef: listBoxRef, overlayProps: overlayProps, placement: placement, state: state, listBoxStyles: listBoxStyles, overlayStyles: overlayStyles, optionStyles: optionStyles, minWidth: triggerWidth }, void 0) }, void 0)] }, void 0));
    return ((0, jsx_runtime_1.jsx)(FieldWrapper_1.FieldWrapper, { ...{
            labelPosition,
            label,
            extra,
            styles,
            isRequired,
            labelStyles,
            necessityIndicator,
            labelProps,
            isDisabled,
            validationState,
            message,
            description,
            requiredMark,
            tooltip,
            labelSuffix,
            Component: selectField,
            ref: ref,
        } }, void 0));
}
function ListBoxPopup({ state, popoverRef, listBoxRef, listBoxStyles, overlayStyles, optionStyles, overlayProps: parentOverlayProps, shouldUseVirtualFocus = false, placement, minWidth, ...otherProps }) {
    // Get props for the listbox
    let { listBoxProps } = (0, listbox_1.useListBox)({
        autoFocus: state.focusStrategy || true,
        shouldUseVirtualFocus,
        ...otherProps,
    }, state, listBoxRef);
    // Handle events that should cause the popup to close,
    // e.g. blur, clicking outside, or pressing the escape key.
    let { overlayProps } = (0, overlays_1.useOverlay)({
        onClose: () => state.close(),
        shouldCloseOnBlur: true,
        isOpen: state.isOpen,
        isDismissable: true,
    }, popoverRef);
    // Wrap in <FocusScope> so that focus is restored back to the
    // trigger when the popup is closed. In addition, add hidden
    // <DismissButton> components at the start and end of the list
    // to allow screen reader users to dismiss the popup easily.
    return ((0, jsx_runtime_1.jsx)(StyledOverlayElement, { ...overlayProps, ...parentOverlayProps, ref: popoverRef, styles: overlayStyles, style: {
            '--overlay-min-width': minWidth ? `${minWidth}px` : 'initial',
            ...parentOverlayProps?.style,
        }, "data-position": placement, children: (0, jsx_runtime_1.jsxs)(focus_1.FocusScope, { restoreFocus: true, children: [(0, jsx_runtime_1.jsx)(overlays_1.DismissButton, { onDismiss: () => state.close() }, void 0), (0, jsx_runtime_1.jsx)(ListBoxElement, { styles: listBoxStyles, ...(0, react_4.mergeProps)(listBoxProps, otherProps), ref: listBoxRef, children: Array.from(state.collection).map((item) => ((0, jsx_runtime_1.jsx)(Option, { item: item, state: state, styles: optionStyles, shouldUseVirtualFocus: shouldUseVirtualFocus }, item.key))) }, void 0), (0, jsx_runtime_1.jsx)(overlays_1.DismissButton, { onDismiss: () => state.close() }, void 0)] }, void 0) }, void 0));
}
exports.ListBoxPopup = ListBoxPopup;
function Option({ item, state, styles, shouldUseVirtualFocus }) {
    let ref = (0, react_3.useRef)(null);
    let isDisabled = state.disabledKeys.has(item.key);
    let isSelected = state.selectionManager.isSelected(item.key);
    let isVirtualFocused = state.selectionManager.focusedKey === item.key;
    let { optionProps } = (0, listbox_1.useOption)({
        key: item.key,
        isDisabled,
        isSelected,
        shouldSelectOnPressUp: true,
        shouldFocusOnHover: true,
        shouldUseVirtualFocus,
    }, state, ref);
    // Handle focus events so we can apply highlighted
    // style to the focused option
    let [isFocused, setFocused] = (0, react_3.useState)(false);
    let { focusProps } = (0, interactions_1.useFocus)({ onFocusChange: setFocused });
    return ((0, react_1.createElement)(OptionElement, { ...(0, react_4.mergeProps)(optionProps, focusProps), ref: ref, key: item.key, mods: {
            selected: isSelected,
            focused: shouldUseVirtualFocus ? isVirtualFocused : isFocused,
            disabled: isDisabled,
        }, "data-theme": isSelected ? 'special' : undefined, styles: styles }, item.rendered));
}
const _Select = (0, react_3.forwardRef)(Select);
_Select.jengaInputType = 'Select';
const __Select = Object.assign(_Select, { Item: collections_1.Item });
exports.Select = __Select;

        