/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createStyle = void 0;
const styles_1 = require("../utils/styles");
const string_1 = require("../utils/string");
const CACHE = {};
function createStyle(styleName, cssStyle, converter) {
    const key = `${styleName}.${cssStyle ?? ''}`;
    if (!CACHE[key]) {
        const styleHandler = (styleMap) => {
            let styleValue = styleMap[styleName];
            if (styleValue == null || styleValue === false)
                return;
            const finalCssStyle = cssStyle || (0, string_1.toSnakeCase)(styleName).replace(/^@/, '--');
            // convert non-string values
            if (converter && typeof styleValue !== 'string') {
                styleValue = converter(styleValue);
                if (!styleValue)
                    return;
            }
            if (typeof styleValue === 'string' &&
                finalCssStyle.startsWith('--') &&
                finalCssStyle.endsWith('-color')) {
                styleValue = styleValue.trim();
                const rgba = (0, styles_1.strToRgb)(styleValue);
                const { color, name } = (0, styles_1.parseColor)(styleValue);
                if (name && rgba) {
                    return {
                        [finalCssStyle]: `var(--${name}-color, ${rgba})`,
                        [`${finalCssStyle}-rgb`]: `var(--${name}-color-rgb, ${(0, styles_1.getRgbValuesFromRgbaString)(rgba).join(', ')})`,
                    };
                }
                else if (name) {
                    if (color) {
                        return {
                            [finalCssStyle]: color,
                            [`${finalCssStyle}-rgb`]: `var(--${name}-color-rgb)`,
                        };
                    }
                    return {
                        [finalCssStyle]: `var(--${name}-color)`,
                        [`${finalCssStyle}-rgb`]: `var(--${name}-color-rgb)`,
                    };
                }
                else if (rgba) {
                    return {
                        [finalCssStyle]: rgba,
                        [`${finalCssStyle}-rgb`]: (0, styles_1.getRgbValuesFromRgbaString)(rgba).join(', '),
                    };
                }
                return {
                    [finalCssStyle]: color,
                };
            }
            const { value } = (0, styles_1.parseStyle)(styleValue, 1);
            return { [finalCssStyle]: value };
        };
        styleHandler.__lookupStyles = [styleName];
        CACHE[key] = (0, styles_1.styleHandlerCacheWrapper)(styleHandler);
    }
    return CACHE[key];
}
exports.createStyle = createStyle;

        