/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.predefine = exports.defineStyleAlias = exports.defineCustomStyle = exports.STYLE_HANDLER_MAP = void 0;
const styles_1 = require("../utils/styles");
const gap_1 = require("./gap");
const fill_1 = require("./fill");
const flow_1 = require("./flow");
const reset_1 = require("./reset");
const color_1 = require("./color");
const width_1 = require("./width");
const height_1 = require("./height");
const radius_1 = require("./radius");
const border_1 = require("./border");
const shadow_1 = require("./shadow");
const padding_1 = require("./padding");
const paddingBlock_1 = require("./paddingBlock");
const paddingInline_1 = require("./paddingInline");
const preset_1 = require("./preset");
const fontStyle_1 = require("./fontStyle");
const margin_1 = require("./margin");
const marginBlock_1 = require("./marginBlock");
const marginInline_1 = require("./marginInline");
const font_1 = require("./font");
const outline_1 = require("./outline");
const transition_1 = require("./transition");
const groupRadius_1 = require("./groupRadius");
const boxShadow_combinator_1 = require("./boxShadow.combinator");
const styledScrollbar_1 = require("./styledScrollbar");
const display_1 = require("./display");
const align_1 = require("./align");
const justify_1 = require("./justify");
const createStyle_1 = require("./createStyle");
const numberConverter = (val) => {
    if (typeof val === 'number') {
        return `${val}px`;
    }
    return val;
};
const columnsConverter = (val) => {
    if (typeof val === 'number') {
        return 'minmax(1px, 1fr) '.repeat(val).trim();
    }
    return;
};
const rowsConverter = (val) => {
    if (typeof val === 'number') {
        return 'auto '.repeat(val).trim();
    }
    return;
};
exports.STYLE_HANDLER_MAP = {};
function defineCustomStyle(names, handler) {
    let handlerWithLookup;
    if (typeof names === 'function') {
        handlerWithLookup = names;
        names = handlerWithLookup.__lookupStyles;
    }
    else if (handler) {
        handlerWithLookup = Object.assign(handler, { __lookupStyles: names });
    }
    else {
        console.warn('JengaUIKit: incorrect custom style definition: ', names);
        return;
    }
    handlerWithLookup = (0, styles_1.styleHandlerCacheWrapper)(handlerWithLookup);
    if (Array.isArray(names)) {
        // just to pass type checking
        names.forEach((name) => {
            if (!exports.STYLE_HANDLER_MAP[name]) {
                exports.STYLE_HANDLER_MAP[name] = [];
            }
            exports.STYLE_HANDLER_MAP[name].push(handlerWithLookup);
        });
    }
}
exports.defineCustomStyle = defineCustomStyle;
function defineStyleAlias(styleName, cssStyleName, converter) {
    const styleHandler = (0, createStyle_1.createStyle)(styleName, cssStyleName, converter);
    if (!exports.STYLE_HANDLER_MAP[styleName]) {
        exports.STYLE_HANDLER_MAP[styleName] = [];
    }
    exports.STYLE_HANDLER_MAP[styleName].push(styleHandler);
}
exports.defineStyleAlias = defineStyleAlias;
function predefine() {
    // Manually define styles that are used in other custom styles.
    // Otherwise, they won't be handled as expected.
    defineStyleAlias('fontSize');
    defineStyleAlias('lineHeight');
    defineStyleAlias('fontWeight');
    defineStyleAlias('fontStyle');
    defineStyleAlias('letterSpacing');
    defineStyleAlias('textTransform');
    defineStyleAlias('fontFamily');
    defineStyleAlias('paddingTop');
    defineStyleAlias('paddingRight');
    defineStyleAlias('paddingBottom');
    defineStyleAlias('paddingLeft');
    defineStyleAlias('marginTop');
    defineStyleAlias('marginRight');
    defineStyleAlias('marginBottom');
    defineStyleAlias('marginLeft');
    // Coordinates
    defineStyleAlias('top', 'top', numberConverter);
    defineStyleAlias('right', 'right', numberConverter);
    defineStyleAlias('bottom', 'bottom', numberConverter);
    defineStyleAlias('left', 'left', numberConverter);
    // Style aliases
    defineStyleAlias('gridAreas', 'grid-template-areas');
    defineStyleAlias('gridColumns', 'grid-template-columns', columnsConverter);
    defineStyleAlias('gridRows', 'grid-template-rows', rowsConverter);
    defineStyleAlias('gridTemplate', 'grid-template', (val) => {
        if (typeof val !== 'string')
            return;
        return val
            .split('/')
            .map((s, i) => (i ? columnsConverter : rowsConverter)(s))
            .join('/');
    });
    [
        display_1.displayStyle,
        transition_1.transitionStyle,
        reset_1.resetStyle,
        fill_1.fillStyle,
        width_1.widthStyle,
        margin_1.marginStyle,
        marginBlock_1.marginBlockStyle,
        marginInline_1.marginInlineStyle,
        gap_1.gapStyle,
        flow_1.flowStyle,
        color_1.colorStyle,
        height_1.heightStyle,
        radius_1.radiusStyle,
        border_1.borderStyle,
        shadow_1.shadowStyle,
        padding_1.paddingStyle,
        paddingBlock_1.paddingBlockStyle,
        paddingInline_1.paddingInlineStyle,
        align_1.alignStyle,
        justify_1.justifyStyle,
        preset_1.presetStyle,
        boxShadow_combinator_1.boxShadowCombinator,
        outline_1.outlineStyle,
        font_1.fontStyle,
        fontStyle_1.fontStyleStyle,
        groupRadius_1.groupRadiusAttr,
        styledScrollbar_1.styledScrollbarStyle,
    ]
        // @ts-ignore
        .forEach((handler) => defineCustomStyle(handler));
    return { STYLE_HANDLER_MAP: exports.STYLE_HANDLER_MAP, defineCustomStyle, defineStyleAlias };
}
exports.predefine = predefine;

        