/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Element = exports.tasty = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const styled_components_1 = __importStar(require("styled-components"));
const react_1 = require("react");
const react_is_1 = require("react-is");
const BreakpointsProvider_1 = require("./providers/BreakpointsProvider");
const modAttrs_1 = require("./utils/modAttrs");
const renderStyles_1 = require("./utils/renderStyles");
const responsive_1 = require("./utils/responsive");
const list_1 = require("./styles/list");
const cache_wrapper_1 = require("./utils/cache-wrapper");
const mergeStyles_1 = require("./utils/mergeStyles");
const getDisplayName_1 = require("./utils/getDisplayName");
// Implementation
function tasty(Component, options) {
    if (typeof Component === 'string') {
        let selector = Component;
        let styles = options;
        let Element = (0, styled_components_1.createGlobalStyle) `${(css) => css}`;
        const _StyleDeclarationComponent = ({ breakpoints, }) => {
            let contextBreakpoints = (0, react_1.useContext)(BreakpointsProvider_1.BreakpointsContext);
            breakpoints = breakpoints ?? contextBreakpoints;
            let css = (0, react_1.useMemo)(() => styles
                ? `\n{}${selector}{${(0, renderStyles_1.renderStyles)(styles, (0, responsive_1.pointsToZones)(breakpoints || contextBreakpoints))}}`
                : '', [breakpoints.join(',')]);
            return (0, jsx_runtime_1.jsx)(Element, { css: css }, void 0);
        };
        _StyleDeclarationComponent.displayName = `TastyStyleDeclaration(${Component})`;
        return _StyleDeclarationComponent;
    }
    if ((0, react_is_1.isValidElementType)(Component)) {
        let { as: extendTag, element: extendElement, ...defaultProps } = options ?? {};
        let propsWithStyles = ['styles'].concat(Object.keys(defaultProps).filter((prop) => prop.endsWith('Styles')));
        let _WrappedComponent = (0, react_1.forwardRef)((props, ref) => {
            const { as, element, ...restProps } = props;
            const propsWithStylesValues = propsWithStyles.map((prop) => props[prop]);
            const mergedStylesMap = (0, react_1.useMemo)(() => {
                return propsWithStyles.reduce((map, prop) => {
                    if (restProps[prop] != null && defaultProps[prop] != null) {
                        map[prop] = (0, mergeStyles_1.mergeStyles)(defaultProps[prop], restProps[prop]);
                    }
                    else {
                        map[prop] = restProps[prop] || defaultProps[prop];
                    }
                    return map;
                }, {});
            }, propsWithStylesValues);
            return ((0, jsx_runtime_1.jsx)(Component, { ref: ref, ...defaultProps, ...restProps, ...mergedStylesMap, as: as ?? extendTag, element: element || extendElement }, void 0));
        });
        _WrappedComponent.displayName = `TastyWrappedComponent(${(0, getDisplayName_1.getDisplayName)(Component, defaultProps.qa ?? extendTag ?? 'Anonymous')})`;
        return _WrappedComponent;
    }
    const tastyOptions = Component;
    let { as: originalAs = 'div', element: defaultElement, styles: defaultStyles, styleProps, variants, ...defaultProps } = tastyOptions;
    let _TastyComponent;
    if (variants) {
        /**
         * Create a tasty component for each variant.
         * Then return a component that receives a `variant` and chooses the right component.
         */
        const variantComponents = Object.keys(variants).reduce((map, variant) => {
            const variantStyles = variants?.[variant];
            map[variant] = tasty({
                as: originalAs,
                styles: (0, mergeStyles_1.mergeStyles)(defaultStyles, variantStyles),
                styleProps,
                ...defaultProps,
            });
            return map;
        }, {});
        if (!variantComponents['default']) {
            variantComponents['default'] = tasty({
                as: originalAs,
                styles: defaultStyles,
                styleProps,
                ...defaultProps,
            });
        }
        // eslint-disable-next-line react/display-name
        _TastyComponent = (0, react_1.forwardRef)((allProps, ref) => {
            const { variant, ...restProps } = allProps;
            const Component = (variantComponents[variant] ||
                variantComponents['default']);
            return (0, jsx_runtime_1.jsx)(Component, { ...restProps, ref: ref }, void 0);
        });
    }
    else {
        let Element = styled_components_1.default[originalAs](({ css }) => css);
        /**
         * An additional optimization that allows to avoid rendering styles across various instances
         * of the same element if no custom styles are provided via `styles` prop or direct style props.
         */
        const renderDefaultStyles = (0, cache_wrapper_1.cacheWrapper)((breakpoints) => {
            return (0, renderStyles_1.renderStyles)(defaultStyles || {}, (0, responsive_1.pointsToZones)(breakpoints));
        });
        let { qa: defaultQa, qaVal: defaultQaVal, ...otherDefaultProps } = defaultProps ?? {};
        // eslint-disable-next-line react/display-name
        _TastyComponent = (0, react_1.forwardRef)((allProps, ref) => {
            let { as, styles, variant, breakpoints, mods, element, qa, qaVal, ...otherProps } = allProps;
            let propStyles = (styleProps
                ? styleProps.concat(list_1.BASE_STYLES)
                : list_1.BASE_STYLES).reduce((map, prop) => {
                if (prop in otherProps) {
                    map[prop] = otherProps[prop];
                    delete otherProps[prop];
                }
                return map;
            }, {});
            if (Object.keys(propStyles).length === 0) {
                propStyles = null;
            }
            if (!styles || (styles && Object.keys(styles).length === 0)) {
                styles = undefined;
            }
            const propStylesCacheKey = JSON.stringify(propStyles);
            const stylesCacheKey = (0, react_1.useMemo)(() => {
                return JSON.stringify(styles);
            }, [styles]);
            const useDefaultStyles = !propStyles && !styles;
            const styleCacheKey = (0, react_1.useMemo)(() => {
                return `${styles ? JSON.stringify(styles) : ''}.${propStyles ? JSON.stringify(propStyles) : ''}`;
            }, [propStylesCacheKey, stylesCacheKey]);
            let allStyles = (0, react_1.useMemo)(() => useDefaultStyles
                ? defaultStyles
                : (0, mergeStyles_1.mergeStyles)(defaultStyles, styles, propStyles), [styleCacheKey]);
            let contextBreakpoints = (0, react_1.useContext)(BreakpointsProvider_1.BreakpointsContext);
            breakpoints = breakpoints ?? contextBreakpoints;
            let renderedStyles = (0, react_1.useMemo)(() => {
                return useDefaultStyles
                    ? renderDefaultStyles(breakpoints)
                    : (0, renderStyles_1.renderStyles)(allStyles, (0, responsive_1.pointsToZones)(breakpoints));
            }, [allStyles, breakpoints]);
            if (mods) {
                Object.assign(otherProps, (0, modAttrs_1.modAttrs)(mods));
            }
            return ((0, jsx_runtime_1.jsx)(Element, { as: as ?? originalAs, "data-element": element || defaultElement, "data-qa": qa || defaultQa, "data-qaval": qaVal || defaultQaVal, ...otherDefaultProps, ...otherProps, ref: ref, css: renderedStyles }, void 0));
        });
    }
    _TastyComponent.displayName = `TastyComponent(${defaultProps.qa || originalAs})`;
    return _TastyComponent;
}
exports.tasty = tasty;
const Element = tasty({});
exports.Element = Element;

        