/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
/* eslint-disable */
// @ts-nocheck
// Convert complex js object to dot notation js object
// url: https://github.com/vardars/dotize
// author: vardars
Object.defineProperty(exports, "__esModule", { value: true });
exports.dotize = void 0;
exports.dotize = {
    valTypes: {
        none: 'NONE',
        primitive: 'PRIM',
        object: 'OBJECT',
        array: 'ARRAY',
    },
    getValType: function (val) {
        if (!val || typeof val != 'object' || Array.isArray(val))
            return exports.dotize.valTypes.primitive;
        if (typeof val == 'object')
            return exports.dotize.valTypes.object;
    },
    getPathType: function (arrPath) {
        let arrPathTypes = [];
        for (let path in arrPath) {
            let pathVal = arrPath[path];
            if (!pathVal)
                arrPathTypes.push(exports.dotize.valTypes.none);
            else if (exports.dotize.isNumber(pathVal))
                arrPathTypes.push(exports.dotize.valTypes.array);
            else
                arrPathTypes.push(exports.dotize.valTypes.object);
        }
        return arrPathTypes;
    },
    isUndefined: function (obj) {
        return typeof obj == 'undefined';
    },
    isNumber: function (f) {
        return !isNaN(parseInt(f));
    },
    isEmptyObj: function (obj) {
        for (let prop in obj) {
            if (Object.hasOwnProperty.call(obj, prop))
                return false;
        }
        return JSON.stringify(obj) === JSON.stringify({});
    },
    isNotObject: function (obj) {
        return !obj || typeof obj != 'object';
    },
    isEmptyArray: function (arr) {
        return Array.isArray(arr) && arr.length == 0;
    },
    isNotArray: function (arr) {
        return Array.isArray(arr) == false;
    },
    removeEmptyArrayItem: function (arr) {
        return arr.filter(function (el) {
            return el != null && el != '';
        });
    },
    getFieldName: function (field, prefix, isRoot, isArrayItem, isArray) {
        if (isArray)
            return ((prefix ? prefix : '') +
                (exports.dotize.isNumber(field)
                    ? '[' + field + ']'
                    : (isRoot && !prefix ? '' : '.') + field));
        else if (isArrayItem)
            return (prefix ? prefix : '') + '[' + field + ']';
        else
            return (prefix ? prefix + '.' : '') + field;
    },
    startsWith: function (val, valToSearch) {
        return val.indexOf(valToSearch) == 0;
    },
    convert: function (obj, prefix = '') {
        let newObj = {};
        // primitives
        if (exports.dotize.isNotObject(obj)) {
            if (prefix) {
                newObj[prefix] = obj;
                return newObj;
            }
            else {
                return obj;
            }
        }
        return (function recurse(o, p, isRoot) {
            let isArrayItem = Array.isArray(o);
            for (let f in o) {
                let currentProp = o[f];
                if (currentProp &&
                    typeof currentProp === 'object' &&
                    !Array.isArray(currentProp)) {
                    if (isArrayItem && exports.dotize.isEmptyObj(currentProp) == false) {
                        newObj = recurse(currentProp, exports.dotize.getFieldName(f, p, isRoot, true)); // array item object
                    }
                    else if (exports.dotize.isEmptyObj(currentProp) == false) {
                        newObj = recurse(currentProp, exports.dotize.getFieldName(f, p, isRoot)); // object
                    }
                    else if (exports.dotize.isEmptyObj(currentProp)) {
                        newObj[exports.dotize.getFieldName(f, p, isRoot, isArrayItem)] =
                            currentProp;
                    }
                }
                else {
                    if (isArrayItem || exports.dotize.isNumber(f)) {
                        newObj[exports.dotize.getFieldName(f, p, isRoot, true)] = currentProp; // array item primitive
                    }
                    else {
                        newObj[exports.dotize.getFieldName(f, p, isRoot)] = currentProp; // primitive
                    }
                }
            }
            return newObj;
        })(obj, prefix, true);
    },
    backward: function (obj, prefix) {
        let newObj = {};
        let arStartRegex = /\[(\d+)\]/g;
        // primitives
        if (exports.dotize.isNotObject(obj) && exports.dotize.isNotArray(obj)) {
            if (prefix) {
                return obj[prefix];
            }
            else {
                return obj;
            }
        }
        for (let tProp in obj) {
            let tPropVal = obj[tProp];
            if (prefix) {
                let prefixRegex = new RegExp('^' + prefix);
                tProp = tProp.replace(prefixRegex, '');
            }
            tProp = tProp.replace(arStartRegex, '.$1');
            if (exports.dotize.startsWith(tProp, '.'))
                tProp = tProp.replace(/^\./, '');
            var arrPath = tProp.split('.');
            var arrPathTypes = exports.dotize.getPathType(arrPath);
            // has array on root
            if (!exports.dotize.isUndefined(arrPathTypes) &&
                arrPathTypes[0] == exports.dotize.valTypes.array &&
                Array.isArray(newObj) == false) {
                newObj = [];
            }
            (function recurse(rPropVal, rObj, rPropValPrev, rObjPrev) {
                let currentPath = arrPath.shift();
                let currentPathType = arrPathTypes.shift();
                if (typeof currentPath == 'undefined' || currentPath == '') {
                    newObj = rPropVal;
                    return;
                }
                let isArray = currentPathType == exports.dotize.valTypes.array;
                if (exports.dotize.isNumber(currentPath))
                    currentPath = parseInt(currentPath);
                // has multiple levels
                if (arrPath.length > 0) {
                    // is not assigned before
                    if (typeof rObj[currentPath] == 'undefined') {
                        if (isArray) {
                            rObj[currentPath] = [];
                        }
                        else {
                            rObj[currentPath] = {};
                        }
                    }
                    recurse(rPropVal, rObj[currentPath], currentPath, rObj);
                    return;
                }
                if (currentPathType == exports.dotize.valTypes.array &&
                    rPropValPrev &&
                    rObjPrev) {
                    if (Array.isArray(rObjPrev[rPropValPrev]) == false)
                        rObjPrev[rPropValPrev] = [];
                    rObjPrev[rPropValPrev].push(rPropVal);
                }
                else {
                    rObj[currentPath] = rPropVal;
                }
            })(tPropVal, newObj);
        }
        return newObj;
    },
};

        