/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.mergeProps = void 0;
const clsx_1 = __importDefault(require("clsx"));
const tasty_1 = require("../../tasty");
const chain_1 = require("./chain");
const useId_1 = require("./useId");
/**
 * Merges multiple props objects together. Event handlers are chained,
 * classNames are combined, and ids are deduplicated - different ids
 * will trigger a side-effect and re-render components hooked up with `useId`.
 * For all other props, the last prop object overrides all previous ones.
 * @param args - Multiple sets of props to merge together.
 */
function mergeProps(...args) {
    let result = {};
    for (let props of args) {
        for (let key in result) {
            // Chain events
            if (/^on[A-Z]/.test(key) &&
                typeof result[key] === 'function' &&
                props &&
                typeof props[key] === 'function') {
                result[key] = (0, chain_1.chain)(result[key], props[key]);
                // Merge classnames, sometimes classNames are empty string which eval to false, so we just need to do a type check
            }
            else if (key === 'className' &&
                typeof result.className === 'string' &&
                props &&
                typeof props.className === 'string') {
                result[key] = (0, clsx_1.default)(result.className, props.className);
            }
            else if ((key === 'styles' || key.endsWith('Styles')) &&
                typeof result.styles === 'object' &&
                props &&
                typeof props.styles === 'object') {
                result[key] = (0, tasty_1.mergeStyles)(result[key], props[key]);
            }
            else if (key === 'mods' && result.mods && props?.mods) {
                result.mods = { ...result.mods, ...props?.mods };
            }
            else if (key === 'id' && result.id && props?.id) {
                result.id = (0, useId_1.mergeIds)(result.id, props?.id);
                // Override others
            }
            else {
                result[key] =
                    props && props[key] !== undefined ? props[key] : result[key];
            }
        }
        // Add props from b that are not in a
        for (let key in props) {
            if (result[key] === undefined) {
                result[key] = props[key];
            }
        }
    }
    return result;
}
exports.mergeProps = mergeProps;

        