/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSlotId = exports.mergeIds = exports.useId = void 0;
const react_1 = require("react");
const ssr_1 = require("@react-aria/ssr");
const useLayoutEffect_1 = require("./useLayoutEffect");
let idsUpdaterMap = new Map();
/**
 * If a default is not provided, generate an id.
 * @param defaultId - Default component id.
 */
function useId(defaultId) {
    let isRendering = (0, react_1.useRef)(true);
    isRendering.current = true;
    let [value, setValue] = (0, react_1.useState)(defaultId);
    let nextId = (0, react_1.useRef)(null);
    // don't memo this, we want it new each render so that the Effects always run
    // eslint-disable-next-line react-hooks/exhaustive-deps
    let updateValue = (val) => {
        if (!isRendering.current) {
            setValue(val);
        }
        else {
            nextId.current = val;
        }
    };
    (0, useLayoutEffect_1.useLayoutEffect)(() => {
        isRendering.current = false;
    });
    (0, react_1.useEffect)(() => {
        let newId = nextId.current;
        if (newId) {
            setValue(newId);
            nextId.current = null;
        }
    }, [setValue, updateValue]);
    let res = (0, ssr_1.useSSRSafeId)(value);
    idsUpdaterMap.set(res, updateValue);
    return res;
}
exports.useId = useId;
/**
 * Merges two ids.
 * Different ids will trigger a side-effect and re-render components hooked up with `useId`.
 */
function mergeIds(idA, idB) {
    if (idA === idB) {
        return idA;
    }
    let setIdA = idsUpdaterMap.get(idA);
    if (setIdA) {
        setIdA(idB);
        return idB;
    }
    let setIdB = idsUpdaterMap.get(idB);
    if (setIdB) {
        setIdB(idA);
        return idA;
    }
    return idB;
}
exports.mergeIds = mergeIds;
/**
 * Used to generate an id, and after render, check if that id is rendered so we know
 * if we can use it in places such as labelledby.
 */
function useSlotId() {
    let [id, setId] = (0, react_1.useState)(useId());
    (0, useLayoutEffect_1.useLayoutEffect)(() => {
        if (id) {
            let setCurr = idsUpdaterMap.get(id);
            if (setCurr && !document.getElementById(id)) {
                setId(null);
            }
        }
    }, [id]);
    return id;
}
exports.useSlotId = useSlotId;

        