/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useViewportSize = void 0;
const react_1 = require("react");
let visualViewport = typeof window !== 'undefined' && window.visualViewport;
function useViewportSize(params = {}) {
    const { isDisabled } = params;
    let [size, setSize] = (0, react_1.useState)(() => getViewportSize());
    (0, react_1.useEffect)(() => {
        if (isDisabled) {
            return;
        }
        // Use visualViewport api to track available height even on iOS virtual keyboard opening
        let onResize = () => {
            setSize((size) => {
                let newSize = getViewportSize();
                if (newSize.width === size.width && newSize.height === size.height) {
                    return size;
                }
                return newSize;
            });
        };
        if (!visualViewport) {
            window.addEventListener('resize', onResize);
        }
        else {
            visualViewport.addEventListener('resize', onResize);
        }
        return () => {
            if (!visualViewport) {
                window.removeEventListener('resize', onResize);
            }
            else {
                visualViewport.removeEventListener('resize', onResize);
            }
        };
    }, [isDisabled]);
    return size;
}
exports.useViewportSize = useViewportSize;
function getViewportSize() {
    return {
        width: (visualViewport && visualViewport.width) ||
            (typeof window !== 'undefined' ? window.innerWidth : 0),
        height: (visualViewport && visualViewport.height) ||
            (typeof window !== 'undefined' ? window.innerHeight : 0),
    };
}

        