/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { forwardRef, useMemo } from 'react';
import { CheckCircleFill, XCircleFill, InfoFill, WarningFill, } from '@jengaicons/react';
import { Title } from '../Title';
import { CONTAINER_STYLES, extractStyles, filterBaseProps, tasty, } from '../../../tasty';
import { wrapNodeIfPlain } from '../../../utils/react';
const Container = tasty({
    qa: 'Result_Container',
    as: 'section',
    styles: {
        display: 'flex',
        flow: 'column',
        placeItems: 'center',
        gap: '3x',
        padding: '6x 4x',
        textAlign: 'center',
        Content: {
            display: 'block',
        },
        Title: {
            display: 'flex',
            flow: 'column',
            placeItems: 'inherit',
            gap: '1x',
        },
    },
});
const IconWrapper = tasty({
    styles: {
        fontSize: '10x',
    },
});
const statusIconMap = {
    success: {
        color: '#success',
        component: CheckCircleFill,
    },
    error: {
        color: '#danger',
        component: XCircleFill,
    },
    info: {
        color: '#purple',
        component: InfoFill,
    },
    warning: {
        color: '#note',
        component: WarningFill,
    },
    404: {
        color: '#purple',
        component: () => {
            // TODO: Needs to be implemented in the future
            return null;
        },
    },
    403: {
        color: '#purple',
        component: () => {
            // TODO: Needs to be implemented in the future
            return null;
        },
    },
    500: {
        color: '#purple',
        component: () => {
            // TODO: Needs to be implemented in the future
            return null;
        },
    },
};
function Result(props, ref) {
    let { children, icon, status, subTitle, subtitle, title, ...otherProps } = props;
    subtitle = subtitle ?? subTitle;
    if (icon && status) {
        console.warn('Don\'t use "icon" and "status" together, it can lead to possible errors.');
    }
    const iconNode = useMemo(() => {
        if (icon) {
            return icon;
        }
        const { color, component: Component } = status && statusIconMap.hasOwnProperty(status)
            ? statusIconMap[status]
            : statusIconMap.info;
        return (_jsx(IconWrapper, { "data-element": "IconWrapper", styles: { color }, children: _jsx(Component, { "data-element": "Icon" }, void 0) }, void 0));
    }, [icon, status]);
    const styles = extractStyles(otherProps, CONTAINER_STYLES);
    return (_jsxs(Container, { ...filterBaseProps(otherProps, { eventProps: true }), ref: ref, styles: styles, children: [iconNode, (title || subtitle) && (_jsxs("div", { "data-element": "Title", children: [wrapNodeIfPlain(title, () => (_jsx(Title, { level: 2, preset: "h4", children: title }, void 0))), wrapNodeIfPlain(subtitle, () => (_jsx(Title, { level: 3, preset: "t2m", children: subtitle }, void 0)))] }, void 0)), children && _jsx("div", { "data-element": "Content", children: children }, void 0)] }, void 0));
}
const _Result = forwardRef(Result);
export { _Result as Result };

        