/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { forwardRef } from 'react';
import { X } from '@jengaicons/react';
import THEMES from '../../../data/themes';
import { CONTAINER_STYLES, extractStyles, filterBaseProps, tasty, } from '../../../tasty';
import { Action } from '../../actions';
import { Suffix } from '../../layout/Suffix';
const TagElement = tasty({
    qa: 'Tag',
    role: 'status',
    styles: {
        position: 'relative',
        display: 'inline-flex',
        gap: '1x',
        placeContent: 'center start',
        placeItems: 'center start',
        radius: '1r',
        preset: 'tag',
        width: '16px max-content max-content',
        height: 'min-content',
        textAlign: 'left',
        whiteSpace: 'nowrap',
        padding: {
            '': '0 (1x - 1bw)',
            closable: '0 (2.5x - 1bw) 0 (1x - 1bw)',
        },
        fill: {
            '': '#dark.04',
            ...Object.keys(THEMES).reduce((map, type) => {
                map[`[data-type="${type}"]`] = THEMES[type].fill;
                return map;
            }, {}),
        },
        color: {
            '': '#dark.65',
            ...Object.keys(THEMES).reduce((map, type) => {
                map[`[data-type="${type}"]`] = THEMES[type].color;
                return map;
            }, {}),
        },
        border: {
            '': true,
            ...Object.keys(THEMES).reduce((map, type) => {
                map[`[data-type="${type}"]`] = THEMES[type].border;
                return map;
            }, {}),
        },
        Icon: {
            fontSize: '@icon-size',
        },
        Content: {
            display: 'block',
            width: 'max 100%',
            textOverflow: 'ellipsis',
            overflow: 'hidden',
            pointerEvents: 'none',
        },
    },
});
const CloseAction = tasty(Action, {
    label: 'Close',
    styles: {
        display: 'grid',
        placeItems: 'center',
        color: true,
        placeSelf: 'center',
        opacity: {
            '': 0.85,
            'pressed | hovered': 1,
        },
        transition: 'opacity',
        padding: '0 .5x',
    },
});
function Tag(allProps, ref) {
    let { type, icon, isClosable, onClose, closeButtonStyles, children, ...props } = allProps;
    const styles = extractStyles(props, CONTAINER_STYLES);
    return (_jsxs(TagElement, { ...filterBaseProps(props, { eventProps: true }), ref: ref, styles: styles, "data-type": type, mods: { closable: isClosable }, children: [icon ? _jsx("div", { "data-element": "TagIcon", children: icon }, void 0) : null, _jsx("div", { "data-element": "Content", children: children }, void 0), isClosable ? (_jsx(Suffix, { outerGap: "0", children: _jsx(CloseAction, { styles: closeButtonStyles, onPress: onClose, children: _jsx(X, { style: {
                            fontSize: 'var(--font-size, inherit)',
                        } }, void 0) }, void 0) }, void 0)) : undefined] }, void 0));
}
const _Tag = forwardRef(Tag);
export { _Tag as Tag };

        