/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx } from "react/jsx-runtime";
import { forwardRef } from 'react';
import { BASE_STYLES, COLOR_STYLES, extractStyles, filterBaseProps, tasty, TEXT_STYLES, } from '../../tasty';
import { useSlotProps } from '../../utils/react';
const STYLE_LIST = [...BASE_STYLES, ...TEXT_STYLES, ...COLOR_STYLES];
export const TEXT_PROP_MAP = {
    transform: 'textTransform',
    weight: 'fontWeight',
    italic: 'fontStyle',
};
const TextElement = tasty({
    qa: 'Text',
    as: 'span',
    styles: {
        display: {
            '': 'inline',
            ellipsis: 'block',
        },
        margin: '0',
        whiteSpace: {
            '': 'inherit',
            'nowrap | ellipsis': 'nowrap',
        },
        textOverflow: {
            '': false,
            ellipsis: 'ellipsis',
        },
        overflow: {
            '': false,
            ellipsis: 'hidden',
        },
        width: {
            '': false,
            ellipsis: 'max 100%',
        },
    },
});
const _Text = forwardRef(function Text(allProps, ref) {
    allProps = useSlotProps(allProps, 'text');
    const { as, qa, block, styleName, ellipsis, nowrap, ...props } = allProps;
    const styles = extractStyles(props, STYLE_LIST, {}, TEXT_PROP_MAP);
    return (_jsx(TextElement, { as: as || 'span', qa: qa || 'Text', styleName: styleName, mods: {
            nowrap,
            ellipsis,
        }, block: !!(block || ellipsis), ...filterBaseProps(props, { eventProps: true }), ref: ref, styles: styles }, void 0));
});
const Text = Object.assign(_Text, {
    Minor: forwardRef(function MinorText(props, ref) {
        return _jsx(_Text, { ref: ref, color: "#minor", ...props }, void 0);
    }),
    Danger: forwardRef(function DangerText(props, ref) {
        return _jsx(_Text, { ref: ref, role: "alert", color: "#danger-text", ...props }, void 0);
    }),
    Success: forwardRef(function SuccessText(props, ref) {
        return _jsx(_Text, { ref: ref, color: "#success-text", ...props }, void 0);
    }),
    Strong: forwardRef(function StrongText(props, ref) {
        return (_jsx(_Text, { ref: ref, as: "strong", preset: "strong", color: "#dark", ...props }, void 0));
    }),
    Emphasis: forwardRef(function EmphasisText(props, ref) {
        return _jsx(_Text, { ref: ref, as: "em", preset: "em", ...props }, void 0);
    }),
    Selection: forwardRef(function SelectionText(props, ref) {
        return _jsx(_Text, { ref: ref, color: "#dark", fill: "#note.30", ...props }, void 0);
    }),
});
export { Text };

        