/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx } from "react/jsx-runtime";
import { forwardRef } from 'react';
import { CONTAINER_STYLES, extractStyles, filterBaseProps, tasty, TEXT_STYLES, } from '../../tasty';
import { useSlotProps } from '../../utils/react';
import { TEXT_PROP_MAP } from './Text';
const STYLE_LIST = [...TEXT_STYLES, ...CONTAINER_STYLES];
const TitleElement = tasty({
    qa: 'Title',
    as: 'h1',
    styles: {
        gridArea: 'heading',
        display: 'block',
        color: '#dark',
        preset: {
            '': 'h6m',
            '[data-level="1"]': 'h1',
            '[data-level="2"]': 'h2',
            '[data-level="3"]': 'h3',
            '[data-level="4"]': 'h4',
            '[data-level="5"]': 'h5',
            '[data-level="6"]': 'h6',
        },
        margin: '0',
        whiteSpace: {
            '': 'inherit',
            'nowrap | ellipsis': 'nowrap',
        },
        textOverflow: {
            '': false,
            ellipsis: 'ellipsis',
        },
        overflow: {
            '': false,
            ellipsis: 'hidden',
        },
        width: {
            '': false,
            ellipsis: 'max 100%',
        },
    },
});
const _Title = forwardRef(function Title({ qa, as, styleName, inline, nowrap, ellipsis, level, ...props }, ref) {
    const propsWithSlots = useSlotProps(props, 'heading');
    const tag = `h${level || 1}`;
    const styles = extractStyles(propsWithSlots, STYLE_LIST, {}, TEXT_PROP_MAP);
    return (_jsx(TitleElement, { qa: qa || 'Title', as: as || tag, styleName: styleName, "data-level": level || 1, mods: {
            nowrap,
            ellipsis,
        }, inline: inline, ...filterBaseProps(propsWithSlots, { eventProps: true }), ref: ref, styles: styles }, void 0));
});
const Title = Object.assign(_Title, {
    Danger: forwardRef(function DangerTitle(props, ref) {
        return _jsx(Title, { ref: ref, color: "#danger-text", ...props }, void 0);
    }),
    Success: forwardRef(function SuccessTitle(props, ref) {
        return _jsx(Title, { ref: ref, color: "#success-text", ...props }, void 0);
    }),
});
export { Title };

        