/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx } from "react/jsx-runtime";
import { forwardRef } from 'react';
import { useDOMRef } from '@react-spectrum/utils';
import { useCheckboxGroup } from '@react-aria/checkbox';
import { useCheckboxGroupState } from '@react-stately/checkbox';
import { useProviderProps } from '../../../provider';
import { CONTAINER_STYLES, extractStyles, tasty, } from '../../../tasty';
import { extractFieldWrapperProps, FieldWrapper } from '../FieldWrapper';
import { castNullableArrayValue, } from '../../../utils/react/nullableValue';
import { useFieldProps, FormContext, useFormProps } from '../Form';
import { CheckboxGroupContext } from './context';
const CheckGroupElement = tasty({
    qa: 'CheckboxGroup',
    styles: {
        display: 'flex',
        placeItems: 'start',
        placeContent: 'start',
        flow: {
            '': 'column',
            horizontal: 'row wrap',
        },
        gap: {
            '': '1x',
            horizontal: '1x 2x',
        },
    },
});
function CheckboxGroup(props, ref) {
    props = castNullableArrayValue(props);
    props = useProviderProps(props);
    props = useFormProps(props);
    props = useFieldProps(props, {
        defaultValidationTrigger: 'onChange',
        valuePropsMapper: ({ value, onChange }) => ({
            value: value != null ? value : [],
            onChange: onChange,
        }),
    });
    let { isDisabled, isRequired, necessityIndicator, necessityLabel, label, extra, validationState, children, orientation = 'vertical', message, description, labelStyles, tooltip, labelSuffix, inputStyles, ...otherProps } = props;
    let domRef = useDOMRef(ref);
    let styles = extractStyles(otherProps, CONTAINER_STYLES);
    let { fieldWrapperProps } = extractFieldWrapperProps(props);
    let state = useCheckboxGroupState(props);
    let { groupProps, labelProps } = useCheckboxGroup(props, state);
    let radioGroup = (_jsx(CheckGroupElement, { styles: inputStyles, mods: {
            horizontal: orientation === 'horizontal',
        }, children: _jsx(FormContext.Provider, { value: {
                isDisabled,
                validationState,
            }, children: _jsx(CheckboxGroupContext.Provider, { value: state, children: children }, void 0) }, void 0) }, void 0));
    return (_jsx(FieldWrapper, { ...fieldWrapperProps, ref: domRef, Component: radioGroup, fieldProps: groupProps, labelProps: labelProps, styles: styles }, void 0));
}
/**
 * Checkbox groups allow users to select a single option from a list of mutually exclusive options.
 * All possible options are exposed up front for users to compare.
 */
const _CheckboxGroup = forwardRef(CheckboxGroup);
_CheckboxGroup.jengaInputType = 'CheckboxGroup';
export { _CheckboxGroup as CheckboxGroup };

        