/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { forwardRef } from 'react';
import { Info } from '@jengaicons/react';
import { Paragraph } from '../../content/Paragraph';
import { tasty } from '../../../tasty';
import { TooltipProvider } from '../../overlays/Tooltip/TooltipProvider';
import { Text } from '../../content/Text';
import { wrapNodeIfPlain } from '../../../utils/react';
import { Space } from '../../layout/Space';
import { Flex } from '../../layout/Flex';
import { Label } from '../Label';
const FieldElement = tasty({
    qa: 'Field',
    styles: {
        display: 'grid',
        gridColumns: {
            '': 'minmax(0, 1fr)',
            'has-sider': '@(full-label-width, auto) minmax(0, 1fr)',
        },
        gap: 0,
        placeItems: 'baseline stretch',
        '@full-label-width': '(@label-width + 1x)',
        LabelArea: {
            display: 'block',
            width: {
                '': 'initial',
                'has-sider': '@label-width',
            },
            margin: {
                '': '1x bottom',
                'has-sider': '1x right',
                ':empty': '0',
            },
        },
        InputArea: {
            display: 'block',
            flow: 'column',
            gridColumn: {
                '': 'initial',
                'has-sider': 2,
            },
        },
    },
});
if (process.env.NODE_ENV === 'development') {
    FieldElement.displayName = 'FieldWrapperElement';
}
const MessageElement = tasty({
    qa: 'Field_Message',
    styles: {
        preset: 't3',
        color: {
            '': '#dark.75',
            invalid: '#danger-text',
            valid: '#success-text',
            disabled: '#dark.40',
        },
        textAlign: 'left',
        userSelect: 'none',
    },
});
/**
 * A wrapper for form fields to provide additional decoration for inputs.
 * @internal Do not use this component directly.
 */
export const FieldWrapper = forwardRef(function FieldWrapper(props, ref) {
    const { as, labelPosition = 'top', label, extra, styles, isRequired, isDisabled, labelStyles, necessityIndicator, labelProps, fieldProps, message, messageStyles, description, Component, validationState, requiredMark = true, tooltip, isHidden, labelSuffix, } = props;
    const labelComponent = label ? (_jsx(Label, { as: as === 'label' ? 'div' : 'label', styles: labelStyles, labelPosition: labelPosition, isRequired: requiredMark ? isRequired : false, isDisabled: isDisabled, necessityIndicator: necessityIndicator, validationState: validationState, "aria-label": label, ...labelProps, children: _jsxs(Flex, { placeContent: "baseline space-between", width: "100%", children: [_jsxs(Space, { placeItems: "center", gap: "0.25x", children: [_jsx("div", { children: label }, void 0), tooltip ? (_jsx(TooltipProvider, { activeWrap: true, title: tooltip, width: "initial max-content 40x", children: _jsx(Info, { style: {
                                    color: 'var(--primary-color)',
                                    margin: '0 4px',
                                } }, void 0) }, void 0)) : null, _jsx("div", { children: labelSuffix }, void 0)] }, void 0), extra && _jsx(Text, { preset: "t3", children: extra }, void 0)] }, void 0) }, void 0)) : null;
    let descriptionComponent = description ? (_jsx("div", { "data-element": "Description", children: wrapNodeIfPlain(description, () => (_jsx(Paragraph, { children: description }, void 0))) }, void 0)) : null;
    const mods = {
        'has-sider': labelPosition === 'side',
        'has-description': !!description,
        invalid: validationState === 'invalid',
        valid: validationState === 'valid',
    };
    return (_jsxs(FieldElement, { ref: ref, as: as ?? 'div', mods: mods, isHidden: isHidden, styles: { width: '100%', ...styles }, ...fieldProps, children: [labelComponent || descriptionComponent ? (_jsxs("div", { "data-element": "LabelArea", children: [labelComponent, descriptionComponent] }, void 0)) : null, _jsxs("div", { "data-element": "InputArea", children: [Component, message && !isDisabled && (_jsx(MessageElement, { mods: mods, styles: messageStyles, role: validationState === 'invalid' ? 'alert' : undefined, children: message }, void 0))] }, void 0)] }, void 0));
});

        