/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx } from "react/jsx-runtime";
/* eslint-disable @typescript-eslint/no-explicit-any */
import { Children, cloneElement, createContext, useContext, useMemo, } from 'react';
import { mergeProps } from '../../../utils/react';
import { FieldWrapper } from '../FieldWrapper';
import { warn } from '../../../utils/warnings';
import { useFormProps } from './Form';
import { useField } from './use-field';
function getDefaultValidateTrigger(type) {
    type = type || '';
    return type === 'Number' || type.includes('Text') ? 'onBlur' : 'onChange';
}
function getValueProps(type, value, onChange, allowsCustomValue) {
    type = type || '';
    if (type === 'Number') {
        return {
            value: value != null ? value : null,
            onChange: onChange,
        };
    }
    else if (type === 'Text') {
        return {
            value: typeof value === 'string' || typeof value === 'number'
                ? String(value)
                : '',
            onChange: onChange,
        };
    }
    else if (type === 'Checkbox') {
        return {
            isSelected: value != null ? value : false,
            isIndeterminate: false,
            onChange: onChange,
        };
    }
    else if (type === 'CheckboxGroup') {
        return {
            value: value != null ? value : [],
            onChange: onChange,
        };
    }
    else if (type === 'RangeSlider') {
        return {
            value: value != null ? value : undefined,
            onChange: onChange,
        };
    }
    else if (type === 'ComboBox') {
        return {
            inputValue: value != null ? value : '',
            onInputChange: (val) => onChange(val, !allowsCustomValue),
            onSelectionChange: onChange,
        };
    }
    else if (type === 'Select') {
        return {
            selectedKey: value != null ? value : null,
            onSelectionChange: onChange,
        };
    }
    return {
        value: value != null ? value : null,
        onChange,
    };
}
export function Field(props) {
    const allProps = useFormProps(props);
    let { type: inputType, children, form, label, extra, validationState, necessityLabel, necessityIndicator, message, description, tooltip, isHidden, isDisabled, isLoading, styles, labelPosition = 'top', labelStyles, labelSuffix, } = allProps;
    if (typeof children === 'function') {
        children = children(form);
    }
    let child = children == null ? null : Children.only(children);
    inputType = inputType ?? child?.type?.jengaInputType ?? 'Text';
    const __props = useField(allProps, {
        defaultValidationTrigger: getDefaultValidateTrigger(inputType),
    });
    const { field, isRequired, name, id } = __props;
    if (!child)
        return null;
    if (__props.nonInput) {
        return (_jsx(LegacyFieldProvider, { children: _jsx(FieldWrapper, { isHidden: isHidden, isDisabled: isDisabled, validationState: validationState, necessityIndicator: necessityIndicator, necessityLabel: necessityLabel, isRequired: isRequired, label: label, extra: extra, tooltip: tooltip, message: message, description: description, Component: child, styles: styles, labelPosition: labelPosition, labelStyles: labelStyles, labelSuffix: labelSuffix }, void 0) }, void 0));
    }
    if (!form) {
        warn('Form Field requires declared form instance if field name is specified');
        return null;
    }
    if (!__props.field) {
        return (_jsx(LegacyFieldProvider, { children: cloneElement(child, mergeProps(child.props, {
                ...getValueProps(inputType),
                label: name,
                name,
                id,
            })) }, void 0));
    }
    const newProps = {
        id,
        name,
        onBlur: __props.onBlur,
    };
    if (necessityIndicator != null) {
        newProps.necessityIndicator = necessityIndicator;
    }
    if (necessityLabel) {
        newProps.necessityLabel = necessityLabel;
    }
    if (validationState) {
        newProps.validationState = validationState;
    }
    if (isRequired) {
        newProps.isRequired = isRequired;
    }
    if (label) {
        newProps.label = label;
    }
    if (extra) {
        newProps.extra = extra;
    }
    if (tooltip) {
        newProps.tooltip = tooltip;
    }
    if (message) {
        newProps.message = message;
    }
    if (isHidden != null) {
        newProps.isHidden = isHidden;
    }
    if (isDisabled != null) {
        newProps.isDisabled = isDisabled;
    }
    if (isLoading != null) {
        newProps.isLoading = isLoading;
    }
    if (field?.errors?.length) {
        if (!validationState) {
            newProps.validationState = 'invalid';
        }
        if (!message) {
            newProps.message = field.errors[0];
        }
    }
    Object.assign(newProps, getValueProps(inputType, __props.field?.inputValue, __props.onChange, child.props.allowsCustomValue));
    const { onChange, onSelectionChange, ...childProps } = child.props;
    // onChange event passed to the child should be executed after Form onChange logic
    return (_jsx(LegacyFieldProvider, { children: cloneElement(child, mergeProps(childProps, newProps, onChange ? { onChange: __props.onChange } : {}, onSelectionChange ? { onSelectionChange: __props.onChange } : {})) }, void 0));
}
const LegacyFieldContext = createContext({
    insideLegacyField: false,
});
function LegacyFieldProvider(props) {
    const value = useMemo(() => ({ insideLegacyField: true }), []);
    return (_jsx(LegacyFieldContext.Provider, { value: value, children: props.children }, void 0));
}
export function useInsideLegacyField() {
    const { insideLegacyField } = useContext(LegacyFieldContext);
    return insideLegacyField;
}

        