/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx } from "react/jsx-runtime";
import { useDOMRef } from '@react-spectrum/utils';
import { createContext, forwardRef, useContext, useEffect, useRef, } from 'react';
import { Provider, useProviderProps } from '../../../provider';
import { CONTAINER_STYLES, extractStyles, filterBaseProps, tasty, } from '../../../tasty';
import { useCombinedRefs } from '../../../utils/react';
import { timeout } from '../../../utils/promise';
import { useForm } from './useForm';
export const FormContext = createContext({});
const FormElement = tasty({
    as: 'form',
    qa: 'Form',
    styles: {
        display: {
            '': 'block',
            horizontal: 'flex',
        },
        flow: {
            '': 'column',
            horizontal: 'row',
        },
        placeItems: {
            '': 'initial',
            horizontal: 'center',
        },
        gap: '2x',
        '@label-width': '25x',
    },
});
export function useFormProps(props) {
    const ctx = useContext(FormContext);
    return { ...ctx, ...props };
}
const formPropNames = new Set([
    'action',
    'autoComplete',
    'encType',
    'method',
    'target',
]);
function Form(props, ref) {
    props = useProviderProps(props);
    let { qa, name, children, labelPosition, orientation, isRequired, necessityIndicator, isDisabled, isReadOnly, validationState, labelStyles, validateTrigger, defaultValues, onValuesChange, requiredMark = true, form, labelWidth, onSubmit, onSubmitFailed, ...otherProps } = props;
    const firstRunRef = useRef(true);
    const isHorizontal = orientation === 'horizontal';
    if (!orientation) {
        orientation = 'vertical';
    }
    if (!labelPosition) {
        labelPosition = isHorizontal ? 'side' : 'top';
    }
    if (!labelWidth) {
        labelWidth = isHorizontal ? 'auto' : undefined;
    }
    ref = useCombinedRefs(ref);
    let onSubmitCallback;
    if ((onSubmit || onSubmitFailed) && !otherProps.action) {
        onSubmitCallback = async (e) => {
            if (e && e?.preventDefault) {
                e && e?.preventDefault && e?.preventDefault();
                e && e?.stopPropagation && e?.stopPropagation();
                if (e.nativeEvent) {
                    const evt = e.nativeEvent;
                    if (evt.submitter &&
                        evt.submitter.getAttribute('type') !== 'submit') {
                        return;
                    }
                }
            }
            if (!form || form.isSubmitting)
                return;
            form.submitError = null;
            form.setSubmitting(true);
            try {
                try {
                    await form.validateFields();
                }
                catch (e) {
                    form?.setSubmitting(false);
                    return;
                }
                await timeout();
                await onSubmit?.(form.getFormData());
            }
            catch (e) {
                await timeout();
                // errors are shown
                form.submitError = e;
                // transfer errors to the callback
                onSubmitFailed?.(e);
                if (e instanceof Error) {
                    throw e;
                }
            }
            finally {
                form?.setSubmitting(false);
            }
            // output data from form directly
            // onSubmit(Object.fromEntries(new FormData(e.target).entries()));
        };
    }
    [form] = useForm(form, ref && ref.current, {
        onSubmit: onSubmitCallback,
        onValuesChange,
    });
    let styles = extractStyles(otherProps, CONTAINER_STYLES);
    if (labelWidth) {
        styles['@label-width'] = labelWidth;
    }
    let domRef = useDOMRef(ref);
    let ctx = {
        labelPosition,
        labelStyles,
        orientation,
        necessityIndicator,
        validateTrigger,
        requiredMark,
        form,
        submitError: form.submitError,
        idPrefix: name,
    };
    if (firstRunRef.current && form) {
        if (defaultValues) {
            form.setInitialFieldsValue(defaultValues);
            form.resetFields(undefined, true);
            firstRunRef.current = false;
        }
    }
    useEffect(() => {
        if (defaultValues) {
            form?.setInitialFieldsValue(defaultValues);
        }
    }, [defaultValues]);
    return (_jsx(FormElement, { ...filterBaseProps(otherProps, { propNames: formPropNames }), ref: domRef, noValidate: true, styles: styles, mods: { 'has-sider': labelPosition === 'side', horizontal: isHorizontal }, onSubmit: onSubmitCallback, children: _jsx(FormContext.Provider, { value: ctx, children: _jsx(Provider, { insideForm: true, isDisabled: isDisabled, isReadOnly: isReadOnly, isRequired: isRequired, validationState: validationState, children: children }, void 0) }, void 0) }, void 0));
}
/**
 * Forms allow users to enter data that can be submitted while providing alignment and styling for form fields.
 */
const _Form = forwardRef(Form);
export { _Form as Form };

        