/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { useEffect, useMemo, useState } from 'react';
import { useEvent, useIsFirstRender } from '../../../../_internal';
import { useFormProps } from '../Form';
const ID_MAP = {};
function createId(name) {
    if (!name)
        return;
    if (!ID_MAP[name]) {
        ID_MAP[name] = [];
    }
    let i = 0;
    let id;
    do {
        id = i ? `${name}_${i}` : name;
        i++;
    } while (ID_MAP[name].includes(id));
    ID_MAP[name].push(id);
    return id;
}
function removeId(name, id) {
    if (!ID_MAP[name])
        return;
    ID_MAP[name] = ID_MAP[name].filter((_id) => _id !== id);
}
export function useField(props, params) {
    props = useFormProps(props);
    let { defaultValue, id, idPrefix, name, form, rules, validateTrigger = params.defaultValidationTrigger, validationState, shouldUpdate, } = props;
    const nonInput = !name;
    const fieldName = name != null ? (Array.isArray(name) ? name.join('.') : name) : '';
    const isFirstRender = useIsFirstRender();
    let [fieldId, setFieldId] = useState(id || (idPrefix ? `${idPrefix}_${fieldName}` : fieldName));
    useEffect(() => {
        let newId;
        if (!id && !nonInput) {
            newId = createId(fieldId);
            setFieldId(newId);
        }
        return () => {
            if (!id) {
                removeId(idPrefix ? `${idPrefix}_${fieldName}` : fieldName, newId);
            }
            if (fieldName && form) {
                form.removeField(fieldName);
            }
        };
    }, []);
    let field = form?.getFieldInstance(fieldName);
    if (field) {
        field.rules = rules;
    }
    let isRequired = rules && !!rules.find((rule) => rule.required);
    useEffect(() => {
        if (!form)
            return;
        if (field) {
            form.forceReRender();
        }
        else {
            form.createField(fieldName);
        }
    }, [field]);
    if (form) {
        if (isFirstRender) {
            if (!field) {
                field = form.createField(fieldName, true);
            }
            if (field?.value == null) {
                form.setFieldValue(fieldName, defaultValue, false, true);
                field = form?.getFieldInstance(fieldName);
            }
        }
        if (!field?.touched && defaultValue != null) {
            form.setFieldValue(fieldName, defaultValue, false, true);
        }
    }
    const onChangeHandler = useEvent((val, dontTouch) => {
        if (!form)
            return;
        const field = form.getFieldInstance(fieldName);
        if (shouldUpdate) {
            const fieldsValue = form.getFieldsValue();
            // check if we should update the value of the field
            const shouldNotBeUpdated = typeof shouldUpdate === 'boolean'
                ? !shouldUpdate
                : !shouldUpdate(fieldsValue, {
                    ...fieldsValue,
                    [fieldName]: val,
                });
            if (shouldNotBeUpdated) {
                return;
            }
        }
        form.setFieldValue(fieldName, val, !dontTouch, false, dontTouch);
        if (!dontTouch &&
            (validateTrigger === 'onChange' ||
                (field && field.errors && field.errors.length))) {
            form.validateField(fieldName).catch(() => { }); // do nothing on fail
        }
    });
    const onBlurHandler = useEvent(() => {
        if (validateTrigger === 'onBlur') {
            // We need a timeout so the change event can be done.
            setTimeout(() => {
                form?.validateField(fieldName).catch(() => { }); // do nothing on fail
            });
        }
    });
    return useMemo(() => ({
        id: fieldId,
        name: fieldName,
        value: field?.inputValue,
        validateTrigger,
        form,
        field,
        nonInput,
        validationState: validationState ?? (field?.errors?.length ? 'invalid' : undefined),
        ...(isRequired && { isRequired }),
        ...(field?.errors?.length && { message: field.errors[0] }),
        onBlur: onBlurHandler,
        onChange: onChangeHandler,
    }), [
        form,
        field,
        field?.inputValue,
        fieldId,
        fieldName,
        isRequired,
        onBlurHandler,
        onChangeHandler,
        validateTrigger,
        validationState,
        nonInput,
    ]);
}

        