/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { useRef, useState } from 'react';
import { dotize } from '../../../tasty';
import { applyRules } from './validation';
function setValue(obj, path, value) {
    let a = path.split('.');
    let o = obj;
    while (a.length - 1) {
        let n = a.shift();
        if (!(n in o))
            o[n] = {};
        o = o[n];
    }
    o[a[0]] = value;
}
function isEqual(v1, v2) {
    return JSON.stringify(v1) === JSON.stringify(v2);
}
export class JengaFormInstance {
    constructor(forceReRender = () => { }) {
        this.forceReRender = () => { };
        this.initialFields = {};
        this.fields = {};
        this.ref = {};
        this.isSubmitting = false;
        this.submitError = null;
        this.onValuesChange = () => { };
        this.onSubmit = () => { };
        this.setFieldsValue = (newData, touched, skipRender, createFields = false, inputOnly = false) => {
            let flag = false;
            Object.keys(newData).forEach((name) => {
                let field = this.fields[name];
                if (!field && createFields) {
                    this.createField(name, skipRender);
                    field = this.fields[name];
                }
                if (!field || isEqual(field.value, newData[name])) {
                    if (field && touched === false) {
                        field.errors = [];
                    }
                    return;
                }
                flag = true;
                if (!inputOnly) {
                    field.value = newData[name];
                }
                field.inputValue = newData[name];
                if (touched === true) {
                    field.touched = touched;
                }
                else if (touched === false) {
                    field.touched = false;
                    field.errors = [];
                }
            });
            if (flag && !skipRender) {
                if (touched && !inputOnly) {
                    this.onValuesChange && this.onValuesChange(this.getFormData());
                    this.submitError = null;
                }
                this.forceReRender();
            }
        };
        this.forceReRender = forceReRender;
        this.getFieldValue = this.getFieldValue.bind(this);
        this.getFieldsValue = this.getFieldsValue.bind(this);
        this.setFieldValue = this.setFieldValue.bind(this);
        this.getFieldError = this.getFieldError.bind(this);
        this.getFieldInstance = this.getFieldInstance.bind(this);
        this.setInitialFieldsValue = this.setInitialFieldsValue.bind(this);
        this.resetFields = this.resetFields.bind(this);
        this.validateField = this.validateField.bind(this);
        this.validateFields = this.validateFields.bind(this);
        this.isFieldValid = this.isFieldValid.bind(this);
        this.createField = this.createField.bind(this);
        this.isFieldInvalid = this.isFieldInvalid.bind(this);
        this.isFieldTouched = this.isFieldTouched.bind(this);
        this.setFields = this.setFields.bind(this);
    }
    async submit() {
        return this.onSubmit?.(this.getFormData());
    }
    getFieldValue(name) {
        return this.fields[name]?.value;
    }
    getFieldsValue() {
        return Object.values(this.fields).reduce((map, field) => {
            map[field.name] = field.value;
            return map;
        }, {});
    }
    /**
     * Similar to getFieldsValue() but respects '.' notation and creates nested objects.
     */
    getFormData() {
        const fieldsValue = this.getFieldsValue();
        return Object.keys(fieldsValue).reduce((map, field) => {
            setValue(map, field, fieldsValue[field]);
            if (field.includes('.')) {
                delete map[field];
            }
            return map;
        }, {});
    }
    setFieldValue(name, value, touched = false, skipRender = false, inputOnly = false) {
        const field = this.fields[name];
        if (!field || isEqual(value, inputOnly ? field.inputValue : field.value)) {
            return;
        }
        if (!inputOnly) {
            field.value = value;
        }
        field.inputValue = value;
        if (touched) {
            field.touched = touched;
        }
        if (!skipRender) {
            field.errors = [];
        }
        if (touched && !inputOnly) {
            this.onValuesChange && this.onValuesChange(this.getFormData());
            this.submitError = null;
        }
        if (!skipRender) {
            this.forceReRender();
        }
    }
    getFieldInstance(name) {
        return this.fields[name];
    }
    setInitialFieldsValue(values) {
        this.initialFields = dotize.convert(values) ?? {};
    }
    resetFields(names, skipRender) {
        const fieldsValue = this.getFieldsValue();
        const fieldNames = Object.keys({ ...fieldsValue, ...this.initialFields });
        const filteredFieldNames = names
            ? fieldNames.filter((name) => names.includes(name))
            : fieldNames;
        const values = filteredFieldNames.reduce((map, name) => {
            if (name in this.initialFields) {
                map[name] = this.initialFields[name];
            }
            else {
                map[name] = undefined;
            }
            return map;
        }, {});
        this.setFieldsValue(values, false, skipRender, true);
    }
    async validateField(name) {
        const field = this.getFieldInstance(name);
        if (!field || !field.rules)
            return Promise.resolve();
        return applyRules(field.value, field.rules, this)
            .then(() => {
            if (!field.errors || field.errors.length) {
                field.errors = [];
                this.forceReRender();
            }
        })
            .catch((err) => {
            field.errors = [err];
            this.forceReRender();
            return Promise.reject([err]);
        });
    }
    validateFields(names) {
        const fieldsList = names || Object.keys(this.fields);
        const errorList = [];
        return Promise.allSettled(fieldsList.map((name) => {
            return this.validateField(name).catch((errors) => {
                errorList.push({ name, errors });
                return Promise.reject();
            });
        })).then(() => {
            if (errorList.length) {
                return Promise.reject(errorList);
            }
            return this.getFormData();
        });
    }
    isFieldValid(name) {
        const field = this.getFieldInstance(name);
        if (!field)
            return true;
        return !field.errors.length;
    }
    isFieldInvalid(name) {
        const field = this.getFieldInstance(name);
        if (!field)
            return false;
        return !!field.errors.length;
    }
    isFieldTouched(name) {
        const field = this.getFieldInstance(name);
        if (!field)
            return false;
        return !!field.touched;
    }
    getFieldError(name) {
        const field = this.getFieldInstance(name);
        if (!field)
            return [];
        return field.errors || [];
    }
    createField(name, skipRender) {
        if (!this.fields[name]) {
            this.fields[name] = this._createField(name);
        }
        if (!skipRender) {
            this.forceReRender();
        }
        return this.fields[name];
    }
    removeField(name, skipRender) {
        if (this.fields[name]) {
            delete this.fields[name];
        }
        if (!skipRender) {
            this.forceReRender();
        }
    }
    setFields(newFields) {
        newFields.forEach(({ name, value, errors }) => {
            this.fields[name] = this._createField(name, {
                value,
                errors,
            });
        });
        this.forceReRender();
    }
    setSubmitting(isSubmitting) {
        if (this.isSubmitting === isSubmitting)
            return;
        this.isSubmitting = isSubmitting;
        this.forceReRender();
    }
    _createField(name, data) {
        let obj = {
            name,
            validating: false,
            touched: false,
            errors: [],
            ...data,
        };
        if (obj) {
            // condition is here to avoid typing issues
            obj.inputValue = obj.value;
        }
        return obj;
    }
}
export function useForm(form, ref, options = {}) {
    const { onSubmit, onValuesChange } = options;
    const formRef = useRef();
    const [, forceUpdate] = useState({});
    if (!formRef.current) {
        if (form) {
            formRef.current = form;
        }
        else {
            // Create a new FormInstance if not provided
            const forceReRender = () => {
                forceUpdate({});
            };
            form = formRef.current = new JengaFormInstance(forceReRender);
        }
        form.ref = ref;
    }
    if (onSubmit) {
        formRef.current.onSubmit = onSubmit;
    }
    if (onValuesChange) {
        formRef.current.onValuesChange = onValuesChange;
    }
    return [formRef.current];
}

        