/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { useDOMRef } from '@react-spectrum/utils';
import { forwardRef } from 'react';
import { useProviderProps } from '../../provider';
import { CONTAINER_STYLES, extractStyles, filterBaseProps, tasty, } from '../../tasty';
const REQUIRED_ICON = (_jsx("svg", { xmlns: "http://www.w3.org/2000/svg", version: "1.1", x: "0px", y: "0px", viewBox: "0 0 100 125", style: {
        // @ts-ignore
        enableBackground: 'new 0 0 100 100',
        width: '.8em',
        height: '.8em',
        transform: 'rotate(-5deg)',
    }, children: _jsx("switch", { children: _jsx("g", { children: _jsx("polygon", { fill: "currentColor", points: "97.5,47.5 90.5,26.1 61.3,35.6 61.3,4.8 38.7,4.8 38.7,35.6 9.5,26.1 2.5,47.5 31.8,57 13.7,82 31.9,95.2     50,70.3 68.1,95.2 86.3,82 68.2,57" }, void 0) }, void 0) }, void 0) }, void 0));
const INTL_MESSAGES = {
    '(required)': '(required)',
    '(optional)': '(optional)',
};
export const INLINE_LABEL_STYLES = {
    preset: 't3',
    color: {
        '': '#dark.85',
        invalid: '#danger-text',
    },
    whiteSpace: 'nowrap',
};
export const LABEL_STYLES = {
    display: 'block',
    fontSize: '14px',
    fontWeight: 'normal',
    color: {
        '': '#op-text',
        invalid: '#op-text-critical',
    },
    whiteSpace: 'nowrap',
    width: {
        '': 'initial',
        side: '@(label-width, initial)',
    },
};
const LabelElement = tasty({
    as: 'label',
    qa: 'Label',
    styles: LABEL_STYLES,
});
function Label(props, ref) {
    props = useProviderProps(props);
    let { as, qa, children, labelPosition = 'top', isRequired, necessityIndicator = isRequired != null ? 'icon' : null, includeNecessityIndicatorInAccessibilityName = false, htmlFor, isDisabled, validationState, for: labelFor, onClick, ...otherProps } = props;
    let domRef = useDOMRef(ref);
    const styles = extractStyles(otherProps, CONTAINER_STYLES);
    let formatMessage = (message) => INTL_MESSAGES[message];
    let necessityLabel = isRequired
        ? formatMessage('(required)')
        : formatMessage('(optional)');
    let icon = (_jsx("span", { "aria-label": includeNecessityIndicatorInAccessibilityName
            ? formatMessage('(required)')
            : undefined, children: REQUIRED_ICON }, void 0));
    return (_jsx(LabelElement, { ...filterBaseProps(otherProps), ref: domRef, styles: styles, htmlFor: labelFor || htmlFor, mods: {
            side: labelPosition === 'side',
            disabled: isDisabled,
            invalid: validationState === 'invalid',
            valid: validationState === 'valid',
        }, onClick: onClick, children: typeof children !== 'string' ? (children) : (_jsxs(_Fragment, { children: [children, (necessityIndicator === 'label' ||
                    (necessityIndicator === 'icon' && isRequired)) &&
                    ' \u200b', necessityIndicator === 'label' && (_jsx("span", { "aria-hidden": !includeNecessityIndicatorInAccessibilityName
                        ? isRequired
                        : undefined, children: necessityLabel }, void 0)), necessityIndicator === 'icon' && isRequired && icon] }, void 0)) }, void 0));
}
let _Label = forwardRef(Label);
export { _Label as Label };

        