/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { forwardRef, useCallback, useRef, useState } from 'react';
import { useTextField } from '@react-aria/textfield';
import { EyeSlash, Eye } from '@jengaicons/react';
import { TextInputBase, } from '../TextInput/TextInputBase';
import { useProviderProps } from '../../../provider';
import { Button } from '../../actions';
import { castNullableStringValue, } from '../../../utils/react/nullableValue';
import { useFieldProps } from '../Form';
function PasswordInput(props, ref) {
    props = castNullableStringValue(props);
    props = useProviderProps(props);
    props = useFieldProps(props, {
        defaultValidationTrigger: 'onBlur',
        valuePropsMapper: ({ value, onChange }) => ({
            value: value?.toString() ?? '',
            onChange,
        }),
    });
    let [type, setType] = useState('password');
    let inputRef = useRef(null);
    let { labelProps, inputProps } = useTextField({
        ...props,
        type,
    }, inputRef);
    const { suffix, multiLine, ...rest } = props;
    const toggleType = useCallback(() => {
        setType((type) => (type === 'password' ? 'text' : 'password'));
    }, []);
    const wrappedSuffix = (_jsxs(_Fragment, { children: [suffix, _jsx(Button, { excludeFromTabOrder: true, type: "outline", styles: {
                    border: '0',
                    borderLeft: '1px solid #op-border',
                    zIndex: 1,
                    borderTopLeftRadius: '0',
                    borderBottomLeftRadius: '0',
                }, htmlType: "button", placeSelf: "stretch", height: "auto", width: "4.5x", label: "Toggle masking", icon: type === 'password' ? _jsx(EyeSlash, {}, void 0) : _jsx(Eye, {}, void 0), onPress: toggleType }, void 0)] }, void 0));
    return (_jsx(TextInputBase, { ref: ref, labelProps: labelProps, inputProps: inputProps, inputRef: inputRef, inputStyles: { paddingRight: '4x' }, type: type, suffixPosition: "after", overflow: "hidden", suffix: wrappedSuffix, multiLine: multiLine, ...rest }, void 0));
}
/**
 * PasswordInputs are password inputs that allow users to input passwords or code entries
 * with a keyboard. Various decorations can be displayed around the field to
 * communicate the entry requirements.
 */
const _PasswordInput = forwardRef(PasswordInput);
_PasswordInput.jengaInputType = 'Text';
export { _PasswordInput as PasswordInput };

        