/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useFocusableRef } from '@react-spectrum/utils';
import { forwardRef, useRef } from 'react';
import { useHover } from '@react-aria/interactions';
import { useRadio } from '@react-aria/radio';
import { extractStyles, filterBaseProps, OUTER_STYLES, tasty, } from '../../../tasty';
import { useFocus } from '../../../utils/react/interactions';
import { mergeProps } from '../../../utils/react';
import { useProviderProps } from '../../../provider';
import { INLINE_LABEL_STYLES } from '../Label';
import { HiddenInput } from '../../HiddenInput';
import { useFieldProps, useFormProps } from '../Form';
import { RadioGroup } from './RadioGroup';
import { useRadioProvider } from './context';
const RadioWrapperElement = tasty({
    as: 'label',
    qa: 'RadioWrapper',
    styles: {
        position: 'relative',
        display: 'grid',
        placeItems: 'center start',
        gap: '1x',
        flow: 'column',
        preset: 'default',
        width: 'min-content',
        margin: {
            '': '1x right',
            '[data-type="button"]': '0',
        },
    },
});
const RadioButtonElement = tasty({
    styles: {
        radius: true,
        fill: {
            '': '#white',
            hovered: '#purple-text.04',
            disabled: '#dark.04',
        },
        color: {
            '': '#dark.85',
            invalid: '#danger-text',
            disabled: '#dark.40',
        },
        preset: 't3m',
        border: {
            '': true,
            checked: '#purple-text',
            'invalid & checked': '#danger-text',
            'disabled & checked': '#dark.40',
            disabled: '#border',
        },
        padding: '(.75x - 1bw) (1.5x - 1bw)',
        cursor: 'pointer',
        opacity: {
            '': 1,
            disabled: 0.5,
        },
        outline: {
            '': '#purple-03.0',
            focused: '#purple-03',
        },
        transition: 'theme',
    },
});
const RadioNormalElement = tasty({
    styles: {
        display: 'grid',
        placeItems: 'center',
        radius: 'round',
        fill: {
            '': '#white',
            disabled: '#dark.04',
        },
        color: {
            checked: '#purple-text',
            'invalid & checked': '#danger-text',
            'disabled | !checked': '#clear',
            'disabled & checked': '#dark.12',
        },
        border: {
            '': '#dark.30',
            checked: '#purple-text',
            invalid: '#danger-text.50',
            disabled: '#dark.12',
        },
        width: '2x',
        height: '2x',
        outline: {
            '': '#purple-03.0',
            focused: '#purple-03',
        },
        transition: 'theme',
        RadioCircle: {
            display: 'block',
            radius: 'round',
            width: '1x',
            height: '1x',
            fill: 'currentColor',
            transition: 'theme',
        },
    },
});
const RadioCircleElement = _jsx("div", { "data-element": "RadioCircle" }, void 0);
const RadioLabelElement = tasty({
    qa: 'RadioLabel',
    styles: INLINE_LABEL_STYLES,
});
function Radio(props, ref) {
    props = useProviderProps(props);
    props = useFormProps(props);
    props = useFieldProps(props, { defaultValidationTrigger: 'onChange' });
    let { qa, isDisabled, validationState, children, label, autoFocus, labelStyles, labelProps, inputStyles, type = 'radio', 'aria-label': ariaLabel, ...otherProps } = props;
    let isButton = type === 'button';
    label = label || children;
    let styles = extractStyles(otherProps, OUTER_STYLES);
    const RadioElement = isButton ? RadioButtonElement : RadioNormalElement;
    labelStyles = {
        ...INLINE_LABEL_STYLES,
        ...labelStyles,
    };
    let state = useRadioProvider();
    if (!state) {
        throw new Error('JengaUI: The Radio button is used outside the RadioGroup.');
    }
    let { isFocused, focusProps } = useFocus({ isDisabled }, true);
    let { hoverProps, isHovered } = useHover({ isDisabled });
    let inputRef = useRef(null);
    let domRef = useFocusableRef(ref, inputRef);
    let { inputProps } = useRadio({
        ...props,
        isDisabled,
    }, state, inputRef);
    return (_jsxs(RadioWrapperElement, { styles: styles, ...hoverProps, ref: domRef, mods: {
            disabled: isDisabled,
            invalid: validationState === 'invalid',
            hovered: isHovered,
            button: isButton,
        }, "data-type": type, children: [_jsx(HiddenInput, { "data-qa": qa || 'Radio', "aria-label": ariaLabel, ...mergeProps(inputProps, focusProps), ref: inputRef, isButton: isButton }, void 0), _jsx(RadioElement, { mods: {
                    checked: inputProps.checked,
                    invalid: validationState === 'invalid',
                    valid: validationState === 'valid',
                    disabled: isDisabled,
                    hovered: isHovered,
                    focused: isFocused,
                }, "data-type": type, styles: inputStyles, children: !isButton ? RadioCircleElement : children }, void 0), label && !isButton && (_jsx(RadioLabelElement, { mods: {
                    invalid: validationState === 'invalid',
                    valid: validationState === 'valid',
                    disabled: isDisabled,
                }, ...filterBaseProps(labelProps), children: label }, void 0))] }, void 0));
}
function RadioButton(props, ref) {
    const Radio = _Radio;
    return _jsx(Radio, { ...props, ref: ref, type: "button" }, void 0);
}
/**
 * Radio buttons allow users to select a single option from a list of mutually exclusive options.
 * All possible options are exposed up front for users to compare.
 */
const _Radio = forwardRef(Radio);
/**
 * Radio buttons allow users to select a single option from a list of mutually exclusive options.
 * All possible options are exposed up front for users to compare.
 */
const _RadioButton = forwardRef(RadioButton);
const __Radio = Object.assign(_Radio, {
    Group: RadioGroup,
    Button: _RadioButton,
});
export { __Radio as Radio };
export { _RadioButton as RadioButton };

        