/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx } from "react/jsx-runtime";
import { forwardRef } from 'react';
import { useDOMRef } from '@react-spectrum/utils';
import { useRadioGroup } from '@react-aria/radio';
import { useRadioGroupState } from '@react-stately/radio';
import { useProviderProps } from '../../../provider';
import { FormContext, useFieldProps, useFormProps } from '../Form';
import { BLOCK_STYLES, extractStyles, OUTER_STYLES, tasty, } from '../../../tasty';
import { FieldWrapper } from '../FieldWrapper';
import { castNullableStringValue, } from '../../../utils/react/nullableValue';
import { RadioContext } from './context';
const RadioGroupElement = tasty({
    qa: 'RadioGroup',
    styles: {
        display: 'flex',
        placeItems: 'start',
        placeContent: 'start',
        flow: {
            '': 'column',
            horizontal: 'row wrap',
        },
        gap: '1x',
    },
});
function RadioGroup(props, ref) {
    props = castNullableStringValue(props);
    props = useProviderProps(props);
    props = useFormProps(props);
    props = useFieldProps(props, { defaultValidationTrigger: 'onChange' });
    let { isDisabled, isRequired, necessityIndicator, label, extra, labelPosition = 'top', validationState, children, orientation = 'vertical', message, description, labelStyles, requiredMark = true, tooltip, isHidden, styles, groupStyles, insideForm, labelSuffix, ...otherProps } = props;
    let domRef = useDOMRef(ref);
    styles = extractStyles(otherProps, OUTER_STYLES, styles);
    groupStyles = extractStyles(otherProps, BLOCK_STYLES, groupStyles);
    let state = useRadioGroupState(props);
    let { radioGroupProps: fieldProps, labelProps } = useRadioGroup(props, state);
    let radioGroup = (_jsx(RadioGroupElement, { styles: groupStyles, mods: {
            horizontal: orientation === 'horizontal',
            'inside-form': insideForm,
            'side-label': labelPosition === 'side',
        }, children: _jsx(FormContext.Provider, { value: {
                isRequired,
                validationState,
                isDisabled,
            }, children: _jsx(RadioContext.Provider, { value: state, children: children }, void 0) }, void 0) }, void 0));
    return (_jsx(FieldWrapper, { ...{
            labelPosition,
            label,
            extra,
            styles,
            isRequired,
            labelStyles,
            necessityIndicator,
            labelProps,
            fieldProps,
            isDisabled,
            validationState,
            message,
            description,
            requiredMark,
            tooltip,
            isHidden,
            orientation,
            Component: radioGroup,
            ref: domRef,
            labelSuffix,
        } }, void 0));
}
/**
 * Radio groups allow users to select a single option from a list of mutually exclusive options.
 * All possible options are exposed up front for users to compare.
 */
const _RadioGroup = forwardRef(RadioGroup);
_RadioGroup.jengaInputType = 'RadioGroup';
export { _RadioGroup as RadioGroup };

        