/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx } from "react/jsx-runtime";
import { forwardRef, useRef } from 'react';
import { useControlledState } from '@react-stately/utils';
import { useTextField } from '@react-aria/textfield';
import { TextInputBase, } from '../TextInput/TextInputBase';
import { useProviderProps } from '../../../provider';
import { castNullableStringValue, } from '../../../utils/react/nullableValue';
import { chain, useLayoutEffect } from '../../../utils/react';
import { useFieldProps } from '../Form';
import { useEvent } from '../../../_internal';
function TextArea(props, ref) {
    props = castNullableStringValue(props);
    props = useProviderProps(props);
    props = useFieldProps(props, {
        defaultValidationTrigger: 'onBlur',
        valuePropsMapper: ({ value, onChange }) => ({
            onChange,
            value: value?.toString() ?? '',
        }),
    });
    let { autoSize = false, isDisabled = false, isReadOnly = false, isRequired = false, onChange, rows = 3, ...otherProps } = props;
    let [inputValue, setInputValue] = useControlledState(props.value, props.defaultValue, () => { });
    let inputRef = useRef(null);
    let onHeightChange = useEvent(() => {
        if (autoSize && inputRef.current) {
            let input = inputRef.current;
            let prevAlignment = input.style.alignSelf;
            let computedStyle = getComputedStyle(input);
            input.style.alignSelf = 'start';
            input.style.height = 'auto';
            input.style.height = input.scrollHeight
                ? `calc(${input.scrollHeight}px + (2 * var(--border-width)))`
                : `${parseFloat(computedStyle.paddingTop) +
                    parseFloat(computedStyle.paddingBottom) +
                    parseFloat(computedStyle.lineHeight) * (rows || 3) +
                    2}px`;
            input.style.alignSelf = prevAlignment;
        }
    });
    useLayoutEffect(() => {
        if (inputRef.current) {
            onHeightChange();
        }
    }, [onHeightChange, inputValue, inputRef]);
    let { labelProps, inputProps } = useTextField({
        ...props,
        onChange: chain(onChange, setInputValue),
        inputElementType: 'textarea',
    }, inputRef);
    return (_jsx(TextInputBase, { ...otherProps, ref: ref, multiLine: true, inputRef: inputRef, labelProps: labelProps, inputProps: inputProps, isDisabled: isDisabled, isReadOnly: isReadOnly, isRequired: isRequired, rows: rows, styles: {
            Prefix: {
                alignSelf: 'start',
                padding: '1.25x 0.25x',
            },
            ...props.styles,
        } }, void 0));
}
/**
 * TextInputs are text inputs that allow users to input custom text entries
 * with a keyboard. Various decorations can be displayed around the field to
 * communicate the entry requirements.
 */
const _TextArea = forwardRef(TextArea);
_TextArea.jengaInputType = 'Text';
export { _TextArea as TextArea };

        