/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { createContext, useContext, useEffect, useRef, useState, } from 'react';
import { X } from '@jengaicons/react';
import styled from 'styled-components';
import { Block } from '../../Block';
import { Action } from '../../actions/Action';
import { Space } from '../../layout/Space';
import { Flex } from '../../layout/Flex';
import { tasty } from '../../../tasty';
import { Button } from '../../actions';
import { useLayoutEffect } from '../../../utils/react';
const FileTabsContext = createContext({
    addTab() { },
    removeTab() { },
    setTab() { },
    setDirtyTab() { },
});
const TabsPanelElement = tasty(Space, {
    styles: {
        gap: '.5x',
        flexShrink: 0,
    },
});
const StyledTabsPanelElement = styled(TabsPanelElement) `
  position: relative;
  overflow: auto hidden;
  top: 1px;
  white-space: nowrap;

  ::-webkit-scrollbar-track {
    background: var(--grey-light-color);
  }

  ::-webkit-scrollbar-thumb {
    border-radius: 1px;
    background: var(--dark-04-color);
    background-clip: padding-box;
  }

  ::-webkit-scrollbar-corner {
    background-color: transparent;
  }

  ::-webkit-scrollbar {
    width: 3px;
    height: 3px;
  }
`;
const TabsContainerElement = tasty(Flex, {
    styles: {
        flow: 'column',
        height: 'max 100%',
        width: 'max 100%',
        position: 'relative',
    },
});
const StyledTabsContainerElement = styled(TabsContainerElement) `
  &::before {
    content: '';
    display: block;
    opacity: 0;
    position: absolute;
    top: 0;
    left: 0;
    pointer-events: none;
    width: 32px;
    height: 37px;
    transition: all 0.15s linear;
    background-image: linear-gradient(
      to left,
      rgba(255, 255, 255, 0),
      rgba(255, 255, 255, 1)
    );
    z-index: 1;
  }

  &::after {
    content: '';
    display: block;
    opacity: 0;
    position: absolute;
    top: 0;
    right: 0;
    width: 32px;
    height: 37px;
    pointer-events: none;
    transition: all 0.15s linear;
    background-image: linear-gradient(
      to right,
      rgba(255, 255, 255, 0),
      rgba(255, 255, 255, 1)
    );
    z-index: 1;
  }

  &[data-is-left-fade]::before,
  &[data-is-right-fade]::after {
    opacity: 1;
  }
`;
const DirtyBadge = tasty({
    element: 'DirtyBadge',
    styles: {
        position: 'absolute',
        top: '50%',
        left: '50%',
        transform: 'translate(-50%, -50%)',
        width: '1x',
        height: '1x',
        fill: '#dark.30',
        radius: 'round',
    },
});
const TabElement = tasty(Action, {
    styles: {
        radius: '1r 1r 0 0',
        padding: '1x 1.5x',
        border: {
            '': 'left top right #clear',
            disabled: 'left top right rgb(227, 227, 233)',
        },
        fill: {
            '': '#dark.04',
            hovered: '#dark.08',
            'disabled, disabled & hover': '#white',
        },
        color: {
            '': '#dark.75',
            'disabled, hovered, hovered & disabled': '#dark',
        },
        cursor: {
            '': 'pointer',
            disabled: 'default',
        },
        fontWeight: 500,
        opacity: 1,
        preset: 'default',
        outline: {
            '': 'inset #purple-03.0',
            'focused & focus-visible': 'inset #purple-03',
        },
        transform: {
            '': 'translate(0, 0)',
            '[disabled]': 'translate(0, 1bw)',
        },
        transition: 'theme 0.2s',
        margin: '1bw bottom',
        DirtyBadge: {
            opacity: {
                '': 1,
                'dirty & :hover': 0,
            },
            pointerEvents: {
                '': 'auto',
                'dirty & :hover': 'none',
            },
        },
        CloseButton: {
            opacity: {
                '': 0,
                '!dirty | :hover': 1,
            },
        },
    },
});
const CloseButton = tasty(Button, {
    element: 'CloseButton',
    type: 'neutral',
    styles: {
        color: {
            '': '#dark.50',
            hovered: '#dark',
        },
        padding: '.25x',
        outline: {
            '': '#purple-03.0',
            'focused & focus-visible': '#purple-03',
        },
        radius: '1r',
    },
});
function Tab({ isDirty, isDisabled, children, isClosable, onClose, ...props }) {
    return (_jsx(TabElement, { mods: {
            dirty: isDirty,
        }, isDisabled: isDisabled, ...props, children: _jsxs(Space, { gap: ".75x", children: [_jsx(Block, { children: children }, void 0), (isClosable || isDirty) && (_jsxs(Flex, { placeItems: "center", style: { position: 'relative' }, children: [isClosable ? (_jsx(CloseButton, { onPress: onClose, children: _jsx(X, {}, void 0) }, void 0)) : (_jsx("div", {}, void 0)), isDirty ? _jsx(DirtyBadge, {}, void 0) : null] }, void 0))] }, void 0) }, void 0));
}
export function FileTabs({ defaultActiveKey, activeKey: activeKeyProp, onTabClick, onTabClose, paneStyles, isClosable = true, children, ...props }) {
    const tabsRef = useRef(null);
    const [tabs, setTabs] = useState([]);
    const [activeKey, setActiveKey] = useState(activeKeyProp || defaultActiveKey);
    const [leftFade, setLeftFade] = useState(false);
    const [rightFade, setRightFade] = useState(false);
    function updateScroll() {
        const el = tabsRef && tabsRef.current;
        if (!el)
            return;
        setLeftFade(!!el.scrollLeft);
        setRightFade(el.scrollWidth !== el.offsetWidth &&
            !!(el.scrollWidth - el.offsetWidth - el.scrollLeft));
    }
    useLayoutEffect(updateScroll, [tabs]);
    function scrollCurrentIntoView() {
        const el = tabsRef && tabsRef.current;
        if (!el)
            return;
        const current = el.querySelector('button[disabled]');
        if (!current)
            return;
        current.scrollIntoView({ behavior: 'smooth', inline: 'end', block: 'end' });
    }
    useEffect(() => {
        function update() {
            updateScroll();
        }
        if (tabsRef && tabsRef.current) {
            tabsRef.current.addEventListener('scroll', update);
            tabsRef.current.addEventListener('mousewheel', update);
            window.addEventListener('resize', update);
        }
        return () => {
            if (tabsRef && tabsRef.current) {
                tabsRef.current.removeEventListener('scroll', update);
                tabsRef.current.removeEventListener('mousewheel', update);
            }
            window.removeEventListener('resize', update);
        };
    }, [tabsRef]);
    useEffect(scrollCurrentIntoView, [activeKey]);
    useEffect(() => {
        setActiveKey(activeKeyProp);
    }, [activeKeyProp]);
    function getTab(tabs, key) {
        return tabs.find((tab) => tab.id === key);
    }
    function setTab(key) {
        if (getTab(tabs, key)) {
            setActiveKey(key);
        }
    }
    function addTab(tab) {
        setTabs((tabs) => {
            if (!getTab(tabs, tab.id)) {
                return [...tabs, tab];
            }
            return tabs;
        });
    }
    function setDirtyTab(id, isDirty) {
        setTabs((tabs) => {
            const tab = getTab(tabs, id);
            if (tab) {
                tab.isDirty = isDirty;
                return [...tabs];
            }
            return tabs;
        });
    }
    function handleClose(tab) {
        if (getTab(tabs, tab.id)) {
            onTabClose && onTabClose(tab.id);
        }
    }
    function removeTab(tab) {
        setTabs((tabs) => {
            const _tabs = tabs.filter((_tab) => _tab.id !== tab.id);
            setActiveKey((prevActiveKey) => {
                if (prevActiveKey === tab.id) {
                    return _tabs[0] && _tabs[0].id;
                }
                return prevActiveKey;
            });
            return _tabs;
        });
    }
    function onPress(tab) {
        setTab(tab.id);
        onTabClick && onTabClick(tab.id);
    }
    return (_jsx(StyledTabsContainerElement, { "data-is-left-fade": leftFade || null, "data-is-right-fade": rightFade || null, ...props, children: _jsxs(FileTabsContext.Provider, { value: {
                addTab,
                setTab,
                removeTab,
                setDirtyTab,
                currentTab: activeKey,
            }, children: [_jsx(StyledTabsPanelElement, { ref: tabsRef, children: tabs.map((tab) => {
                        return (_jsx(Tab, { isClosable: isClosable, isDisabled: tab.id === activeKey || false, isDirty: tab.isDirty, onPress: () => onPress(tab), onClose: () => isClosable && handleClose(tab), children: tab.title }, tab.id));
                    }) }, void 0), _jsx(Flex, { flexGrow: 1, border: "top rgb(227, 227, 233)", ...(paneStyles || {}), children: children }, void 0)] }, void 0) }, void 0));
}
FileTabs.TabPane = function FileTabPane(allProps) {
    let { id, title, isDirty, children, ...props } = allProps;
    const { addTab, removeTab, currentTab, setDirtyTab } = useContext(FileTabsContext);
    useEffect(() => {
        const tabData = {
            id,
            title,
            isDirty,
        };
        addTab(tabData);
        return () => {
            removeTab(tabData);
        };
    }, [id, title]);
    useEffect(() => {
        setDirtyTab(id, isDirty || false);
    }, [isDirty]);
    const isCurrent = id === currentTab;
    return (_jsx(Block, { style: { display: isCurrent ? 'block' : 'none' }, flexGrow: 1, ...props, children: children }, void 0));
};

        