/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { createElement as _createElement } from "react";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useCallback, useEffect, useState } from 'react';
import ReactDOM from 'react-dom';
import styled from 'styled-components';
import { X } from '@jengaicons/react';
import { CSSTransition } from 'react-transition-group';
import { Action } from '../../actions/Action';
import { Card } from '../../content/Card/Card';
import { Flow } from '../../layout/Flow';
import { Flex } from '../../layout/Flex';
import { Block } from '../../Block';
import { Button } from '../../actions';
import { Space } from '../../layout/Space';
import { Title } from '../../content/Title';
const Overlay = styled.div `
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: rgba(0, 0, 0, 0.4);
  place-content: center;
  place-items: center;
  z-index: 1000;
  display: none;
  white-space: normal;

  .jenga-modal {
    --enter-transition-time: 250ms;
    --leave-transition-time: 160ms;
    --base-translate: ((50vh - 50%) / -3);
    transform: translate(0, calc(var(--base-translate)));
  }

  &.jenga-modal-transition-enter {
    opacity: 0;
    display: flex;

    & .jenga-modal {
      transform: translate(0, calc(-32px + var(--base-translate))) scale(0.5);
    }
  }

  &.jenga-modal-transition-enter-active {
    opacity: 1;
    transition: all var(--enter-transition-time) cubic-bezier(0, 0.5, 0, 1);

    & .jenga-modal {
      transform: translate(0, calc(var(--base-translate))) scale(1);
      transition: all var(--enter-transition-time) cubic-bezier(0.5, 0.5, 0, 1);
    }
  }

  &.jenga-modal-transition-enter-done {
    display: flex;
  }

  &.jenga-modal-transition-exit {
    opacity: 1;
    display: flex;

    & .jenga-modal {
      transform: translate(0, calc(var(--base-translate))) scale(1);
    }
  }

  &.jenga-modal-transition-exit-active {
    opacity: 0;
    transition: all var(--leave-transition-time) ease-in;

    & .jenga-modal {
      transform: translate(0, calc(-32px + var(--base-translate))) scale(0.5);
      transition: all var(--leave-transition-time) ease-in;
    }
  }

  &.jenga-modal-transition-exit-done {
    display: none;
  }
`;
/**
 * @deprecated Prefer using Dialog instead
 *
 * DEPRECATED Modal component
 * Designed after AntD Modal component and almost duplicate its API.
 * Use Dialog component instead
 */
export function Modal(allProps) {
    let { title, isVisible, type, okType, isClosable, isLoading, children, okText, cancelText, width, onOk, onCancel, onClose, qa, isDisabled, ...props } = allProps;
    isClosable = !!isClosable;
    const [inProp, setInProp] = useState(false);
    const [localLoading, setLocalLoading] = useState(false);
    useEffect(() => {
        setInProp(isVisible || false);
    }, [isVisible]);
    function cancel() {
        if (onCancel) {
            onCancel();
        }
        else if (onClose) {
            onClose();
        }
    }
    function close() {
        if (!isVisible)
            return;
        if (onClose || onCancel) {
            if (isClosable) {
                // @ts-ignore
                (onClose || onCancel)();
            }
            else if (onCancel) {
                onCancel();
            }
        }
    }
    const onOverlayClick = (evt) => {
        if (!evt || !evt.target)
            return;
        if (evt.target.classList.contains('jenga-modal-overlay') && !isLoading) {
            close();
        }
    };
    useEffect(() => {
        function handleKeyDown(evt) {
            if (evt.key === 'Escape' && !isLoading) {
                close();
            }
        }
        window.addEventListener('keydown', handleKeyDown);
        return () => {
            window.removeEventListener('keydown', handleKeyDown);
        };
    }, []);
    const handleOk = useCallback((arg) => {
        setLocalLoading(true);
        (async () => {
            if (onOk) {
                try {
                    if ((await onOk(arg)) === false && (onClose || onCancel)) {
                        // @ts-ignore
                        (onClose || onCancel)();
                    }
                }
                catch (e) {
                }
                finally {
                    setLocalLoading(false);
                }
            }
        })();
    }, [onOk]);
    return (_jsx(CSSTransition, { in: inProp, timeout: 250, classNames: "jenga-modal-transition", children: _jsx(Overlay, { className: "jenga-modal-overlay", onClick: onOverlayClick, children: _jsxs(Card, { "data-qa": qa || 'Modal', className: "jenga-modal", display: "flex", role: "region", color: "#dark.85", padding: "0", shadow: true, border: false, radius: "1.5r", width: `288px (100% - 32px) ${typeof width === 'number' ? `${width}px` : width || '360px'}`, style: { textAlign: 'left' }, ...props, children: [_jsxs(Flex, { placeContent: "space-between", padding: "2x 3x", border: "bottom", children: [typeof title === 'object' ? (title) : (_jsx(Title, { ellipsis: true, level: 4, flexGrow: 1, children: title }, void 0)), isClosable ? (_jsx(Action, { qa: "ModalCloseButton", width: "3x", height: "3x", color: { '': '#dark.75', hovered: '#purple' }, outline: {
                                    '': '#purple-03.0',
                                    'focused & focus-visible': '#purple-03',
                                }, label: "Close", onPress: onClose || onCancel, children: _jsx(X, { style: { fontSize: 16 } }, void 0) }, void 0)) : null] }, void 0), _jsxs(Flow, { padding: "3x", gap: "3x", height: "max (100vh - 90px)", style: { overflow: 'auto' }, children: [typeof children === 'string' ? (_jsx(Block, { children: children }, void 0)) : (children), type !== 'info' && (onOk || onCancel) ? (_jsxs(Space, { gap: "1.5x", children: [_jsx(Button, { "data-qa": 'ConfirmButton', isDisabled: isDisabled, type: "primary", theme: okType === 'danger' ? 'danger' : undefined, isLoading: isLoading || localLoading, onPress: handleOk, children: okText || 'OK' }, void 0), _jsx(Button, { "data-qa": 'CancelButton', isDisabled: isLoading, onPress: cancel, children: cancelText || (okText === 'Yes' ? 'No' : 'Cancel') }, void 0)] }, void 0)) : null, type === 'info' ? (_jsx(Space, { children: _jsx(Button, { "data-qa": 'OkButton', isDisabled: isDisabled, type: okType === 'danger' ? 'danger' : 'primary', onPress: close, children: okText || 'OK' }, void 0) }, void 0)) : null] }, void 0)] }, void 0) }, void 0) }, void 0));
}
let ID = 0;
const modal = {
    root: null,
    items: [],
    init() {
        if (this.root)
            return;
        this.root = document.createElement('div');
        this.root.classList.add('jenga-modal-container');
        document.body.appendChild(this.root);
        this._render([]);
    },
    render() {
        this.init();
        this._render();
    },
    _render(items) {
        if (!items) {
            items = this.items;
        }
        ReactDOM.render(items.map((item) => {
            const { id, onOk, onCancel, onClose, content, ...options } = item;
            const wrapOnOk = async (arg) => {
                onOk && (await onOk(arg));
                this.resolve(item, arg);
            };
            const wrapOnCancel = () => {
                onCancel && onCancel();
                if (item.type === 'info') {
                    this.resolve(item);
                }
                else {
                    this.reject(item);
                }
            };
            const wrapOnClose = () => {
                onClose && onClose();
                if (item.type === 'info') {
                    this.resolve(item);
                }
                else {
                    this.reject(item);
                }
            };
            return (_createElement(Modal, { ...options, key: id, onOk: wrapOnOk, onCancel: wrapOnCancel, onClose: wrapOnClose }, content));
        }), this.root);
    },
    open(item) {
        item.isVisible = false;
        item.id = ++ID;
        this.items.push(item);
        this.render();
        setTimeout(() => {
            item.isVisible = true;
            this.render();
        });
        return new Promise((resolve, reject) => {
            item.resolve = resolve;
            item.reject = reject;
        });
    },
    close(item) {
        item.isVisible = false;
        this.render();
        setTimeout(() => {
            this.items = this.items.filter((modal) => item.id !== modal.id);
            this.render();
        }, 1000);
    },
    resolve(item, arg) {
        item.resolve(arg);
        this.close(item);
    },
    reject(item, arg) {
        item.reject(arg);
        this.close(item);
    },
};
Modal.confirm = (options) => {
    return modal.open({ type: 'confirm', ...options });
};
Modal.info = (options) => {
    return modal.open({ type: 'info', ...options });
};

        