/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { useTable } from '@react-aria/table';
import { useTableState } from '@react-stately/table';
import { forwardRef, useRef } from 'react';
import { useProviderProps } from '../../../provider';
import { useCombinedRefs } from '../../../utils/react';
import { TableBase, TableWrapper } from './TableElementsBase';
import { TableHeadSection } from './TableHeadSection';
import { TableBodySection } from './TableBodySection';
import { TableFooter } from './TableFooter';
const DefaultTableProps = {
    showFooter: true,
    customHeaderRowPostion: 'top',
    selectionMode: 'none',
    selectionBehavior: 'toggle',
    stickyHeader: false,
    zebraStripes: false,
    checkboxProps: {},
    checkboxStyles: {},
    wrapperProps: {},
    wrapperStyles: {},
    headerStyles: {},
    tableBodyStyles: {},
    tableBodyProps: {},
    footerStyles: {},
    footerProps: {},
    headerProps: {},
    cellPadding: 'regular',
    showAlternateBody: false,
    cellProps: {},
    cellStyles: {},
    setKeyboardNavigationDisabled: false,
    rowStyles: {},
    headerRowProps: {},
    headerRowStyles: {},
    rowProps: {},
};
function withDefaultTableProps(props) {
    for (let key of Object.keys(DefaultTableProps)) {
        if (!props.hasOwnProperty(key)) {
            props[key] = DefaultTableProps[key];
        }
    }
    return props;
}
function _Table(props, ref) {
    props = withDefaultTableProps(useProviderProps(props));
    let { showFooter = true, alternateBody, showAlternateBody, headerProps, headerStyles, wrapperProps, wrapperStyles, footerProps, footerStyles, customHeaderRowPostion, tableBodyProps, tableBodyStyles, customHeaderRow, customFooter, onEmpty, headerRowProps, headerRowStyles, stickyHeader, ...otherProps } = props;
    let state = useTableState({
        ...props,
        showSelectionCheckboxes: props.selectionMode === 'multiple' &&
            props.selectionBehavior !== 'replace',
    });
    ref = useCombinedRefs([ref, useRef(null)]);
    let { gridProps } = useTable(props, state, ref);
    const { styles: wrapperStylesFromProps, ...wrapperOtherProps } = wrapperProps || { styles: {} };
    const { styles: headerStylesFromProps, ...headerOtherProps } = headerProps || { styles: {} };
    const { styles: tableBodyStylesFromProps, ...tableBodyOtherProps } = tableBodyProps || { styles: {} };
    const { styles: footerStylesFromProps, ...footerOtherProps } = footerProps || { styles: {} };
    return (_jsx(TableWrapper, { ...wrapperOtherProps, styles: { ...wrapperStylesFromProps, ...wrapperStyles }, children: _jsxs(TableBase, { ref: ref, ...gridProps, ...otherProps, children: [_jsx(TableHeadSection, { customHeaderPosition: customHeaderRowPostion || 'top', state: state, headerRowProps: {
                        ...headerRowProps,
                        styles: {
                            ...(headerRowProps?.styles || {}),
                            ...headerRowStyles,
                        },
                    }, stickyHeader: stickyHeader, ...headerOtherProps, styles: { ...headerStylesFromProps, ...headerStyles }, children: customHeaderRow }, void 0), _jsx(TableBodySection, { state: state, alternateBody: alternateBody, showAlternateBody: showAlternateBody, onEmpty: onEmpty, ...tableBodyOtherProps, styles: { ...tableBodyStylesFromProps, ...tableBodyStyles } }, void 0), showFooter ? (customFooter ? (customFooter) : (_jsx(TableFooter, { styles: { ...footerStylesFromProps, ...footerStyles }, ...footerOtherProps, totalRecords: [...state.collection.body.childNodes].length }, void 0))) : (_jsx(_Fragment, {}, void 0))] }, void 0) }, void 0));
}
const Table = forwardRef(_Table);
export { Table };

        