/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { forwardRef } from 'react';
import { Button, ButtonGroup } from '../../actions';
import { Content } from '../../content/Content';
import { Paragraph } from '../../content/Paragraph';
import { Dialog } from '../Dialog/Dialog';
import { useDialogContext } from '../Dialog/context';
import { Title } from '../../content/Title';
import { Header } from '../../content/Header';
import { Footer } from '../../content/Footer';
import { chain } from '../../../utils/react';
const DEFAULT_CONFIRM_PROPS = {
    label: 'Ok',
    type: 'primary',
};
const DEFAULT_CANCEL_PROPS = {
    label: 'Cancel',
};
/**
 * AlertDialogs are a specific type of Dialog. They display important information that users need to acknowledge.
 */
function AlertDialog(props, ref) {
    const { onClose } = useDialogContext();
    const { danger, actions, title, styles, noActions, content, ...otherProps } = props;
    let { confirm: confirmProps, secondary: secondaryProps, cancel: cancelProps, } = actions ?? {};
    // the confirm button is present by default
    confirmProps =
        confirmProps !== false
            ? {
                ...DEFAULT_CONFIRM_PROPS,
                ...(typeof confirmProps === 'object' ? confirmProps : null),
            }
            : undefined;
    // the cancel button is hidden by default
    cancelProps = cancelProps
        ? {
            ...DEFAULT_CANCEL_PROPS,
            ...(typeof cancelProps === 'object' ? cancelProps : null),
        }
        : undefined;
    return (_jsxs(Dialog, { ref: ref, role: "alertdialog", isDismissable: false, ...otherProps, children: [title ? (_jsx(Header, { children: _jsx(Title, { children: title }, void 0) }, void 0)) : null, content ? (_jsx(Content, { children: typeof content === 'string' ? (_jsx(Paragraph, { children: content }, void 0)) : (content) }, void 0)) : null, !noActions ? (_jsx(Footer, { children: _jsxs(ButtonGroup, { align: "end", children: [_jsx(Button, { autoFocus: true, theme: danger ? 'danger' : undefined, ...confirmProps, onPress: (e) => chain(confirmProps?.onPress?.(e), onClose?.('confirm')) }, void 0), secondaryProps && (_jsx(Button, { ...secondaryProps, onPress: (e) => chain(secondaryProps?.onPress?.(e), onClose?.('secondary')) }, void 0)), cancelProps && (_jsx(Button, { ...cancelProps, onPress: (e) => chain(cancelProps?.onPress?.(e), onClose?.('cancel')) }, void 0))] }, void 0) }, void 0)) : null] }, void 0));
}
/**
 * AlertDialogs are a specific type of Dialog. They display important information that users need to acknowledge.
 */
const _AlertDialog = forwardRef(AlertDialog);
export { _AlertDialog as AlertDialog };

        