/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx } from "react/jsx-runtime";
import { Children, useRef, isValidElement, } from 'react';
import { Modal } from '../Modal/Modal';
import { DialogContext } from './context';
/**
 * A DialogContainer accepts a single Dialog as a child, and manages to show and hide
 * it in a modal.
 * Useful in cases where there is no trigger element
 * or when the trigger unmounts while the dialog is open.
 */
export function DialogContainer(props) {
    const { children, type = 'modal', onDismiss, isDismissable, isKeyboardDismissDisabled, isOpen, } = props;
    const childArray = Children.toArray(children);
    if (childArray.length > 1) {
        throw new Error('Only a single child can be passed to DialogContainer.');
    }
    const lastChild = useRef();
    const child = isValidElement(childArray[0]) ? childArray[0] : null;
    if (child) {
        lastChild.current = child;
    }
    const isActuallyOpened = typeof isOpen !== 'boolean' ? !!child : isOpen;
    const context = {
        type,
        onClose: onDismiss,
        isDismissable,
    };
    return (_jsx(Modal, { isOpen: isActuallyOpened, type: type, isDismissable: isDismissable, isKeyboardDismissDisabled: isKeyboardDismissDisabled, onClose: isDismissable ? onDismiss : undefined, children: _jsx(DialogContext.Provider, { value: context, children: child }, void 0) }, void 0));
}

        