/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment, useEffect, useRef } from 'react';
import { useOverlayTriggerState } from '@react-stately/overlays';
import { PressResponder } from '@react-aria/interactions';
import { useMediaQuery } from '@react-spectrum/utils';
import { useOverlayPosition, useOverlayTrigger } from '@react-aria/overlays';
import { Modal, Popover, Tray } from '../Modal';
import { DialogContext } from './context';
function DialogTrigger(props) {
    let { children, type = 'modal', mobileType = type === 'popover' ? 'modal' : type, hideArrow, targetRef, onDismiss, isDismissable = true, isKeyboardDismissDisabled, styles, mobileViewport = 700, hideOnClose, shouldCloseOnInteractOutside, ...positionProps } = props;
    if (!Array.isArray(children) || children.length > 2) {
        throw new Error('DialogTrigger must have exactly 2 children');
    }
    // if a function is passed as the second child, it won't appear in toArray
    let [trigger, content] = children;
    // On small devices, show a modal or tray instead of a popover.
    let isMobile = useMediaQuery(`(max-width: ${mobileViewport}px)`);
    if (isMobile) {
        // handle cases where desktop popovers need a close button for the mobile modal view
        if (type !== 'modal' && mobileType === 'modal') {
            isDismissable = true;
        }
        type = mobileType;
    }
    let state = useOverlayTriggerState(props);
    let wasOpen = useRef(false);
    let isExiting = useRef(false);
    let onExiting = () => (isExiting.current = true);
    let onExited = () => (isExiting.current = false);
    wasOpen.current = state.isOpen;
    useEffect(() => {
        return () => {
            if ((wasOpen.current || isExiting.current) &&
                type !== 'popover' &&
                type !== 'tray') {
                console.warn('JengaUIKit: A DialogTrigger unmounted while open. This is likely due to being placed within a trigger that unmounts or inside a conditional. Consider using a DialogContainer instead.');
            }
        };
    }, []);
    function onClose(action) {
        if (isDismissable) {
            onDismiss && onDismiss(action);
            state.close();
        }
    }
    if (type === 'popover') {
        return (_jsx(PopoverTrigger, { ...positionProps, hideOnClose: hideOnClose, state: state, targetRef: targetRef, trigger: trigger, content: content, isKeyboardDismissDisabled: isKeyboardDismissDisabled, hideArrow: hideArrow, shouldCloseOnInteractOutside: shouldCloseOnInteractOutside, onClose: onClose }, void 0));
    }
    let renderOverlay = () => {
        switch (type) {
            case 'panel':
            case 'fullscreen':
            case 'fullscreenTakeover':
            case 'modal':
                return (_jsx(Modal, { hideOnClose: hideOnClose, isOpen: state.isOpen, isDismissable: isDismissable, type: type, isKeyboardDismissDisabled: isKeyboardDismissDisabled, styles: styles, shouldCloseOnInteractOutside: shouldCloseOnInteractOutside, onClose: onClose, onExiting: onExiting, onExited: onExited, children: typeof content === 'function' ? content(state.close) : content }, void 0));
            case 'tray':
                return (_jsx(Tray, { hideOnClose: hideOnClose, isOpen: state.isOpen, isKeyboardDismissDisabled: isKeyboardDismissDisabled, styles: styles, onClose: onClose, children: typeof content === 'function' ? content(state.close) : content }, void 0));
        }
    };
    return (_jsx(DialogTriggerBase, { type: type, state: state, isDismissable: isDismissable, trigger: trigger, overlay: renderOverlay(), onClose: onClose }, void 0));
}
/**
 * DialogTrigger serves as a wrapper around a Dialog and its associated trigger, linking the Dialog's
 * open state with the trigger's press state. Additionally, it allows you to customize the type and
 * positioning of the Dialog.
 */
let _DialogTrigger = DialogTrigger;
export { _DialogTrigger as DialogTrigger };
function PopoverTrigger(allProps) {
    let { state, targetRef, trigger, content, hideArrow, onClose, isKeyboardDismissDisabled, hideOnClose, shouldCloseOnInteractOutside, ...props } = allProps;
    let triggerRef = useRef(null);
    let overlayRef = useRef(null);
    let { overlayProps: popoverProps, placement, arrowProps, updatePosition, } = useOverlayPosition({
        targetRef: targetRef || triggerRef,
        overlayRef: overlayRef,
        placement: props.placement,
        containerPadding: props.containerPadding,
        offset: props.offset || 8,
        crossOffset: props.crossOffset,
        shouldFlip: props.shouldFlip,
        isOpen: state.isOpen,
    });
    let { triggerProps, overlayProps } = useOverlayTrigger({ type: 'dialog' }, state, triggerRef);
    let triggerPropsWithRef = {
        ...triggerProps,
        ref: targetRef ? undefined : triggerRef,
    };
    let overlay = (_jsx(Popover, { ref: overlayRef, hideOnClose: hideOnClose, isOpen: state.isOpen, style: popoverProps.style, placement: placement, arrowProps: arrowProps, isKeyboardDismissDisabled: isKeyboardDismissDisabled, hideArrow: hideArrow, updatePosition: updatePosition, shouldCloseOnInteractOutside: shouldCloseOnInteractOutside, onClose: onClose, children: typeof content === 'function' ? content(state.close) : content }, void 0));
    return (_jsx(DialogTriggerBase, { type: "popover", state: state, triggerProps: triggerPropsWithRef, dialogProps: overlayProps, trigger: trigger, overlay: overlay, onClose: onClose }, void 0));
}
function DialogTriggerBase(props) {
    let { type, state, onClose, isDismissable, dialogProps = {}, triggerProps = {}, overlay, trigger, } = props;
    let context = {
        type,
        onClose,
        isDismissable,
        ...dialogProps,
    };
    return (_jsxs(Fragment, { children: [_jsx(PressResponder, { ...triggerProps, isPressed: state.isOpen &&
                    type !== 'modal' &&
                    type !== 'fullscreen' &&
                    type !== 'fullscreenTakeover', onPress: state.toggle, children: trigger }, void 0), _jsx(DialogContext.Provider, { value: context, children: overlay }, void 0)] }, void 0));
}

        