/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useDOMRef } from '@react-spectrum/utils';
import { forwardRef } from 'react';
import { useModal, useOverlay, usePreventScroll } from '@react-aria/overlays';
import { tasty } from '../../../tasty';
import { mergeProps } from '../../../utils/react';
import { Underlay } from './Underlay';
import { Overlay } from './Overlay';
export const OVERLAY_WRAPPER_STYLES = {
    position: 'fixed',
    display: 'grid',
    left: 0,
    top: 0,
    placeItems: {
        '': 'center',
        '[data-type="fullscreen"]': 'center',
        '[data-type="fullscreenTakeover"] | [data-type="panel"]': 'stretch',
    },
    boxSizing: 'border-box',
    width: '100vw',
    height: '100dvh',
    pointerEvents: 'none',
    zIndex: 2,
    transition: {
        '': 'visibility .5s steps(2, start)',
        open: 'visibility 0s linear',
    },
};
const ModalWrapperElement = tasty({
    qa: 'ModalWrapper',
    styles: OVERLAY_WRAPPER_STYLES,
});
const ModalElement = tasty({
    styles: {
        display: {
            '': 'none',
            'entering | entered': 'grid',
            exiting: 'grid',
            exited: 'none',
        },
        zIndex: 2,
        height: {
            '': 'max 90dvh',
            '[data-type="fullscreenTakeover"] | [data-type="panel"]': '100dvh 100dvh',
            '[data-type="fullscreen"]': '90dvh 90dvh',
            '[data-type="fullscreenTakeover"]': '100dvh 100dvh',
        },
        width: {
            width: '288px 90vw',
        },
        pointerEvents: 'none',
        transition: 'opacity .25s linear, transform .25s ease-in-out',
        transform: {
            '': 'translate(0, 0) scale(1, 1)',
            '[data-type="modal"] & !open': 'translate(0, -3x) scale(1, 1)',
            '[data-type^="fullscreen"] & !open': 'translate(0, 0) scale(1.02, 1.02)',
        },
        opacity: {
            '': 0,
            open: 0.9999,
        },
    },
});
function Modal(props, ref) {
    let { qa, children, onClose, type, styles, ...otherProps } = props;
    let domRef = useDOMRef(ref);
    let { overlayProps, underlayProps } = useOverlay({ ...props }, domRef);
    return (_jsxs(Overlay, { ...otherProps, children: [type !== 'fullscreenTakeover' && _jsx(Underlay, { ...underlayProps }, void 0), _jsx(ModalWrapper, { ref: domRef, qa: qa, type: type, overlayProps: overlayProps, styles: styles, onClose: onClose, children: children }, void 0)] }, void 0));
}
let ModalWrapper = forwardRef(function ModalWrapper(props, ref) {
    let { qa, children, isOpen, type, placement, styles, overlayProps, transitionState, ...otherProps } = props;
    usePreventScroll({ isDisabled: transitionState !== 'entered' });
    let { modalProps } = useModal({ isDisabled: transitionState !== 'entered' });
    return (_jsx(ModalWrapperElement, { "data-type": type, "data-placement": placement, children: _jsx(ModalElement, { qa: qa || 'Modal', styles: styles, mods: {
                open: isOpen,
                entering: transitionState === 'entering',
                exiting: transitionState === 'exiting',
                exited: transitionState === 'exited',
                entered: transitionState === 'entered',
            }, "data-type": type, "data-placement": placement, ...mergeProps(otherProps, overlayProps, modalProps), ref: ref, children: children }, void 0) }, void 0));
});
let _Modal = forwardRef(Modal);
export { _Modal as Modal };

        