/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx } from "react/jsx-runtime";
import { forwardRef, useEffect } from 'react';
import { useModal, useOverlay } from '@react-aria/overlays';
import { tasty } from '../../../tasty';
import { mergeProps } from '../../../utils/react';
import { Overlay } from './Overlay';
const PopoverElement = tasty({
    role: 'presentation',
    styles: {
        display: {
            '': 'none',
            'entering | entered': 'initial',
            exiting: 'initial',
            exited: 'none',
        },
        pointerEvents: 'auto',
        position: 'absolute',
        transition: 'opacity .120s linear, visibility 0ms linear, transform .120s ease-in-out',
        transform: {
            '': 'scale(1, .9)',
            open: 'scale(1, 1)',
        },
        opacity: {
            '': 0,
            open: '.9999',
        },
        transformOrigin: {
            '': 'top center',
            '[data-placement="top"]': 'bottom center',
        },
    },
});
function Popover(props, ref) {
    let { qa, style, styles, children, placement, arrowProps, onClose, shouldCloseOnBlur, isKeyboardDismissDisabled, isNonModal, isDismissable = true, updatePosition, shouldCloseOnInteractOutside, ...otherProps } = props;
    return (_jsx(Overlay, { ...otherProps, children: _jsx(PopoverWrapper, { ref: ref, qa: qa, style: style, styles: styles, placement: placement, arrowProps: arrowProps, shouldCloseOnBlur: shouldCloseOnBlur, isKeyboardDismissDisabled: isKeyboardDismissDisabled, isNonModal: isNonModal, isDismissable: isDismissable, updatePosition: updatePosition, shouldCloseOnInteractOutside: shouldCloseOnInteractOutside, onClose: onClose, children: children }, void 0) }, void 0));
}
const PopoverWrapper = forwardRef(function PopoverWrapper(props, ref) {
    let { qa, children, placement = 'bottom', arrowProps, isOpen, style, styles, shouldCloseOnBlur, isKeyboardDismissDisabled, isNonModal, isDismissable, updatePosition, transitionState, ...otherProps } = props;
    let { overlayProps } = useOverlay({ ...props, isDismissable: isDismissable && isOpen }, 
    // @ts-ignore
    ref);
    let { modalProps } = useModal({
        isDisabled: isNonModal,
    });
    useEffect(() => {
        if (transitionState === 'entered') {
            updatePosition?.();
        }
    }, [updatePosition, transitionState]);
    return (_jsx(PopoverElement, { qa: qa || 'Popover', ...mergeProps(otherProps, overlayProps, modalProps), ref: ref, styles: styles, mods: {
            open: isOpen,
            entering: transitionState === 'entering',
            exiting: transitionState === 'exiting',
            exited: transitionState === 'exited',
            entered: transitionState === 'entered',
        }, "data-placement": placement, style: style, children: children }, void 0));
});
let _Popover = forwardRef(Popover);
export { _Popover as Popover };

        