/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { forwardRef } from 'react';
import { useHover } from '@react-aria/interactions';
import { useFocusRing } from '@react-aria/focus';
import { tasty } from '../../../../tasty';
import { useEvent, useTimer } from '../../../../_internal';
import { ClearSlots, mergeProps } from '../../../../utils/react';
import { useId } from '../../../../utils/react/useId';
import { NotificationIcon } from './NotificationIcon';
import { NotificationHeader } from './NotificationHeader';
import { NotificationDescription } from './NotificationDescription';
import { NotificationFooter } from './NotificationFooter';
import { NotificationCloseButton } from './NotificationCloseButton';
import { NotificationProvider } from './NotificationProvider';
const NotificationContainer = tasty({
    styles: {
        boxSizing: 'border-box',
        position: 'relative',
        display: 'grid',
        width: '100%',
        padding: '0.5x 0.5x 1.5x 1.5x',
        gridAreas: `
      ".    . .           .      close"
      "icon . header      .      close"
      "icon . description .      close"
      ".    . footer      footer footer"
    `,
        gridColumns: 'min-content 1x minmax(0, auto) 1x minmax(0, min-content)',
        gridRows: '1x minmax(0, auto) minmax(0, auto) minmax(0, auto)',
        fill: '#white',
        boxShadow: {
            '': '0 0 0 4bw #purple-04.0 inset',
            focused: '0 0 0 4bw #purple-04 inset',
        },
    },
});
/**
 * @internal This component is unstable and is a subject to change.
 */
export const NotificationView = forwardRef(function NotificationView(props, ref) {
    const { onClose, actions, header, icon, description, id, styles, type = 'attention', isDismissible = true, duration = null, attributes = {}, qa = 'notification', timer: propsTimer, onDismiss, } = props;
    const labelID = useId();
    const descriptionID = useId();
    const onCloseEvent = useEvent(() => {
        onClose?.();
    });
    const onDismissEvent = useEvent(() => {
        if (isDismissible) {
            onDismiss?.();
        }
    });
    const { hoverProps, isHovered } = useHover({});
    const { isFocusVisible, focusProps } = useFocusRing({ within: true });
    useTimer({
        timer: propsTimer,
        delay: duration,
        callback: onDismissEvent,
        isDisabled: isFocusVisible || isHovered || !isDismissible,
    });
    return (_jsx(ClearSlots, { children: _jsx(NotificationProvider, { onClose: onClose, children: _jsxs(NotificationContainer, { ...mergeProps(attributes, hoverProps, focusProps), ref: ref, styles: styles, "data-id": id, "data-qa": qa, "aria-labelledby": labelID, "aria-describedby": descriptionID, mods: { focused: isFocusVisible, 'is-dismissible': isDismissible }, children: [_jsx(NotificationIcon, { icon: icon, type: type }, void 0), _jsx(NotificationHeader, { header: header, id: labelID }, void 0), description && (_jsx(NotificationDescription, { description: description, id: descriptionID }, void 0)), _jsx(NotificationFooter, { hasDescription: !!description, actions: actions, onClose: onCloseEvent, onDismiss: onDismissEvent }, void 0), isDismissible && (_jsx(NotificationCloseButton, { onPress: onDismissEvent }, void 0))] }, void 0) }, void 0) }, void 0));
});

        