/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React, { cloneElement } from 'react';
import { Item as BaseItem, Section as BaseSection, } from '@react-stately/collections';
import { useMenu } from '@react-aria/menu';
import { useSyncRef } from '@react-aria/utils';
import { useDOMRef } from '@react-spectrum/utils';
import { useTreeState } from '@react-stately/tree';
import { CONTAINER_STYLES, extractStyles, filterBaseProps, } from '../../../tasty';
import { mergeProps } from '../../../utils/react';
import { StyledMenu, StyledMenuHeader } from './styled';
import { MenuItem } from './MenuItem';
import { MenuSection } from './MenuSection';
import { useMenuContext } from './context';
function Menu(props, ref) {
    const { header, footer, itemStyles, sectionStyles, sectionHeadingStyles, selectionIcon, qa, } = props;
    const domRef = useDOMRef(ref);
    const contextProps = useMenuContext();
    const completeProps = mergeProps(contextProps, props);
    const state = useTreeState(completeProps);
    const items = [...state.collection];
    const hasSections = items.some((item) => item.type === 'section');
    const { menuProps } = useMenu(completeProps, state, domRef);
    const styles = extractStyles(completeProps, CONTAINER_STYLES);
    const defaultProps = {
        qa,
        styles,
        mods: {
            sections: hasSections,
            footer: !!footer,
            header: !!header,
        },
    };
    useSyncRef(contextProps, domRef);
    return (_jsxs(StyledMenu, { ...mergeProps(defaultProps, menuProps, filterBaseProps(completeProps)), ref: domRef, children: [header && _jsx(StyledMenuHeader, { children: header }, void 0), items.map((item) => {
                if (item.type === 'section') {
                    return (_jsx(MenuSection, { item: item, state: state, styles: sectionStyles, itemStyles: itemStyles, headingStyles: sectionHeadingStyles, selectionIcon: selectionIcon, onAction: completeProps.onAction }, item.key));
                }
                let menuItem = (_jsx(MenuItem, { item: item, state: state, styles: itemStyles, selectionIcon: selectionIcon, onAction: completeProps.onAction }, item.key));
                if (item.props.wrapper) {
                    menuItem = item.props.wrapper(menuItem);
                }
                return cloneElement(menuItem, {
                    key: item.key,
                });
            })] }, void 0));
}
// forwardRef doesn't support generic parameters, so cast the result to the correct type
// https://stackoverflow.com/questions/58469229/react-with-typescript-generics-while-using-react-forwardref
const _Menu = React.forwardRef(Menu);
const Item = Object.assign(BaseItem, {
    displayName: 'Item',
});
const Section = Object.assign(BaseSection, {
    displayName: 'Section',
});
const __Menu = Object.assign(_Menu, {
    Item,
    Section,
    displayName: 'Menu',
});
__Menu.displayName = 'Menu';
export { __Menu as Menu };

        