/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx } from "react/jsx-runtime";
import { useRef } from 'react';
import { useHover } from '@react-aria/interactions';
import { FocusRing } from '@react-aria/focus';
import { useMenuItem } from '@react-aria/menu';
import { mergeProps, ClearSlots, SlotProvider } from '../../../utils/react';
import { useMenuContext } from './context';
import { StyledMenuItem } from './styled';
import { MenuButton } from './MenuButton';
/** @private */
export function MenuItem(props) {
    const { item, state, styles, selectionIcon, isVirtualized, onAction } = props;
    const { onClose, closeOnSelect } = useMenuContext();
    const { rendered, key, props: itemProps } = item;
    const isSelectable = state.selectionManager.selectionMode !== 'none';
    const isDisabledKey = state.disabledKeys.has(key);
    const ref = useRef(null);
    const { hoverProps, isHovered } = useHover({ isDisabled: isDisabledKey });
    const { menuItemProps, labelProps, descriptionProps, keyboardShortcutProps, isFocused, isSelected, isPressed, isDisabled, } = useMenuItem({
        isSelected: state.selectionManager.isSelected(key),
        isDisabled: isDisabledKey,
        'aria-label': item['aria-label'],
        key,
        onClose,
        closeOnSelect,
        isVirtualized,
        onAction,
    }, state, ref);
    const buttonProps = {
        qa: itemProps.qa ? itemProps.qa : `MenuButton-${key}`,
        mods: {
            ...itemProps.mods,
            hovered: isHovered,
            focused: isFocused,
            pressed: isPressed,
        },
    };
    const contents = (_jsx(MenuButton, { ...mergeProps(itemProps, buttonProps), styles: styles, selectionIcon: selectionIcon, isSelectable: isSelectable, isSelected: isSelected, isDisabled: isDisabled, children: rendered }, void 0));
    return (_jsx(FocusRing, { children: _jsx(StyledMenuItem, { ...mergeProps(menuItemProps, hoverProps), ref: ref, "data-qa": itemProps.qa ? `MenuItem-${itemProps.qa}` : `MenuItem-${key}`, mods: {
                disabled: isDisabled,
                selected: isSelected,
                selectable: isSelectable,
                hovered: isHovered,
                focused: isFocused,
            }, children: _jsx(ClearSlots, { children: _jsx(SlotProvider, { slots: {
                        text: { className: 'itemLabel', ...labelProps },
                        end: { className: 'end', ...descriptionProps },
                        icon: { className: 'icon', size: 'S' },
                        description: { className: 'description', ...descriptionProps },
                        keyboard: { className: 'keyboard', ...keyboardShortcutProps },
                    }, children: contents }, void 0) }, void 0) }, void 0) }, void 0));
}

        