/**
 * @license MIT
 * author: undefined
 * jenga-ui v0.6.0
 * Released under the MIT license.
 */

import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import React, { forwardRef, Fragment, useRef } from 'react';
import { useDOMRef, useIsMobileDevice } from '@react-spectrum/utils';
import { DismissButton, useOverlayPosition } from '@react-aria/overlays';
import { PressResponder } from '@react-aria/interactions';
import { useMenuTrigger } from '@react-aria/menu';
import { useMenuTriggerState } from '@react-stately/menu';
import { Popover, Tray } from '../../overlays/Modal';
import { SlotProvider } from '../../../utils/react';
import { MenuContext } from './context';
function MenuTrigger(props, ref) {
    const menuPopoverRef = useRef(null);
    const triggerRef = useRef();
    const domRef = useDOMRef(ref);
    const menuTriggerRef = domRef || triggerRef;
    const menuRef = useRef(null);
    const { children, align = 'start', shouldFlip = true, direction = 'bottom', closeOnSelect, trigger = 'press', isDisabled, } = props;
    const [menuTrigger, menu] = React.Children.toArray(children);
    const state = useMenuTriggerState(props);
    const { menuTriggerProps, menuProps } = useMenuTrigger({ isDisabled }, state, menuTriggerRef);
    let initialPlacement;
    switch (direction) {
        case 'left':
        case 'right':
        case 'start':
        case 'end':
            initialPlacement = `${direction} ${align === 'end' ? 'bottom' : 'top'}`;
            break;
        case 'bottom':
        case 'top':
        default:
            initialPlacement = `${direction} ${align}`;
    }
    const isMobile = useIsMobileDevice();
    const { overlayProps: positionProps, placement } = useOverlayPosition({
        targetRef: menuTriggerRef,
        overlayRef: menuPopoverRef,
        scrollRef: menuRef,
        placement: initialPlacement,
        shouldFlip: shouldFlip,
        isOpen: state.isOpen && !isMobile,
        onClose: state.close,
        containerPadding: props.containerPadding,
        offset: props.offset || 8,
        crossOffset: props.crossOffset,
    });
    const menuContext = {
        ...menuProps,
        ref: menuRef,
        onClose: state.close,
        closeOnSelect,
        autoFocus: state.focusStrategy || true,
        style: isMobile
            ? {
                width: '100%',
                maxHeight: 'inherit',
            }
            : undefined,
        mods: {
            popover: !isMobile,
        },
    };
    const contents = (_jsxs(_Fragment, { children: [_jsx(DismissButton, { onDismiss: state.close }, void 0), menu, _jsx(DismissButton, { onDismiss: state.close }, void 0)] }, void 0));
    // On small screen devices, the menu is rendered in a tray, otherwise a popover.
    let overlay;
    if (isMobile) {
        overlay = (_jsx(Tray, { isOpen: state.isOpen, onClose: state.close, children: contents }, void 0));
    }
    else {
        overlay = (_jsx(Popover, { ref: menuPopoverRef, hideArrow: true, isNonModal: true, isOpen: state.isOpen, style: positionProps.style, placement: placement, onClose: state.close, children: contents }, void 0));
    }
    return (_jsxs(Fragment, { children: [_jsx(SlotProvider, { slots: { actionButton: { holdAffordance: trigger === 'longPress' } }, children: _jsx(PressResponder, { ...menuTriggerProps, ref: menuTriggerRef, isPressed: state.isOpen, children: menuTrigger }, void 0) }, void 0), _jsx(MenuContext.Provider, { value: menuContext, children: overlay }, void 0)] }, void 0));
}
/**
 * The MenuTrigger serves as a wrapper around a Menu and its associated trigger,
 * linking the Menu's open state with the trigger's press state.
 */
let _MenuTrigger = forwardRef(MenuTrigger);
_MenuTrigger.displayName = 'MenuTrigger';
export { _MenuTrigger as MenuTrigger };

        