import { ReactElement, ReactNode } from 'react';
import { LabelPosition, OptionalFieldBaseProps, ValidationRule } from '../../../shared';
import { Styles } from '../../../tasty';
import { JengaFormInstance } from './useForm';
import { FieldTypes } from './types';
export interface JengaFieldProps<T extends FieldTypes> extends OptionalFieldBaseProps {
    /** The initial value of the input. */
    defaultValue?: any;
    /** The type of the input. `Input`, `Checkbox`, RadioGroup`, `Select`, `ComboBox` etc... */
    type?: string;
    /** The unique ID of the field */
    id?: string;
    /** The id prefix for the field to avoid collisions between forms */
    idPrefix?: string;
    children?: ReactElement | ((JengaFormInstance: any) => ReactElement);
    /** Function that checks whether to perform update of the form state. */
    shouldUpdate?: boolean | ((prevValues: any, nextValues: any) => boolean);
    /** Validation rules */
    rules?: ValidationRule[];
    /** The form instance */
    form?: JengaFormInstance<T>;
    /** The message for the field or text for the error */
    message?: ReactNode;
    /** The description for the field */
    description?: ReactNode;
    /** Tooltip for the label that explains something. */
    tooltip?: ReactNode;
    /** Field name. It's used as a key the form data. */
    name?: string | string[];
    /** Whether the field is hidden. */
    isHidden?: boolean;
    /** Whether the field is disabled. */
    isDisabled?: boolean;
    /** Whether the field is loading. */
    isLoading?: boolean;
    styles?: Styles;
    labelPosition?: LabelPosition;
    labelStyles?: Styles;
    labelSuffix?: ReactNode;
}
export declare function Field<T extends FieldTypes>(props: JengaFieldProps<T>): JSX.Element | null;
export declare function useInsideLegacyField(): boolean;
