import { ReactNode } from 'react';
import { JengaFieldData, FieldTypes, SetFieldsArrType } from './types';
export declare type JengaFormData<T extends FieldTypes> = {
    [K in keyof T]?: JengaFieldData<K, T[K]>;
};
export declare class JengaFormInstance<T extends FieldTypes, TFormData extends JengaFormData<T> = JengaFormData<T>> {
    forceReRender: () => void;
    private initialFields;
    private fields;
    ref: {};
    isSubmitting: boolean;
    submitError: unknown;
    onValuesChange: (data: T) => void | Promise<void>;
    onSubmit: (data: T) => void | Promise<void>;
    constructor(forceReRender?: () => void);
    submit(): Promise<void>;
    setFieldsValue: (newData: Partial<T>, touched?: boolean | undefined, skipRender?: boolean | undefined, createFields?: boolean, inputOnly?: boolean) => void;
    getFieldValue<Name extends keyof T>(name: Name): T[Name] | undefined;
    getFieldsValue(): Partial<T>;
    /**
     * Similar to getFieldsValue() but respects '.' notation and creates nested objects.
     */
    getFormData(): T;
    setFieldValue<Name extends keyof T>(name: Name, value: T[Name], touched?: boolean, skipRender?: boolean, inputOnly?: boolean): void;
    getFieldInstance<Name extends keyof T>(name: Name): TFormData[Name];
    setInitialFieldsValue(values: Partial<T>): void;
    resetFields(names?: (keyof T)[], skipRender?: boolean): void;
    validateField<Name extends keyof T>(name: Name): Promise<any>;
    validateFields<Names extends (keyof T)[]>(names?: Names): Promise<any>;
    isFieldValid<Name extends keyof T>(name: Name): boolean;
    isFieldInvalid<Name extends keyof T>(name: Name): boolean;
    isFieldTouched<Name extends keyof T>(name: Name): boolean;
    getFieldError<Name extends keyof T>(name: Name): ReactNode[];
    createField<Name extends keyof T>(name: Name, skipRender?: boolean): TFormData[Name];
    removeField<Name extends keyof T>(name: Name, skipRender?: boolean): void;
    setFields<Names extends keyof T>(newFields: SetFieldsArrType<T, Names>[]): void;
    setSubmitting(isSubmitting: boolean): void;
    _createField<Name extends keyof T, Data extends TFormData[Name]>(name: Name, data?: Data): Data;
}
export declare function useForm<TSourceType extends FieldTypes>(form?: JengaFormInstance<TSourceType, JengaFormData<TSourceType>>, ref?: any, options?: {
    onSubmit?: JengaFormInstance<TSourceType>['onSubmit'];
    onValuesChange?: JengaFormInstance<TSourceType>['onValuesChange'];
}): [JengaFormInstance<TSourceType>];
