import { ForwardedRef, ReactElement, RefObject } from 'react';
import { FilterFn } from '@react-stately/combobox';
import { Item } from '@react-stately/collections';
import { JengaSelectBaseProps } from '../Select/Select';
import type { CollectionBase, KeyboardDelegate, LoadingState } from '@react-types/shared';
import type { ComboBoxProps } from '@react-types/combobox';
export interface JengaComboBoxProps<T> extends Omit<JengaSelectBaseProps<T>, 'onOpenChange'>, ComboBoxProps<T>, CollectionBase<T> {
    icon?: ReactElement;
    multiLine?: boolean;
    autoComplete?: string;
    wrapperRef?: RefObject<HTMLDivElement>;
    inputRef?: RefObject<HTMLInputElement>;
    /** The ref for the list box popover. */
    popoverRef?: RefObject<HTMLDivElement>;
    /** The ref for the list box. */
    listBoxRef?: RefObject<HTMLElement>;
    /** An optional keyboard delegate implementation, to override the default. */
    keyboardDelegate?: KeyboardDelegate;
    loadingState?: LoadingState;
    /**
     * The filter function used to determine if a option should be included in the combo box list.
     * Has no effect when `items` is provided.
     */
    filter?: FilterFn;
    size?: 'small' | 'default' | 'large' | string;
    suffixPosition?: 'before' | 'after';
}
export declare const ComboBox: (<T>(props: JengaComboBoxProps<T> & {
    ref?: ForwardedRef<HTMLDivElement> | undefined;
}) => JSX.Element) & {
    Item: typeof Item;
};
