import { ComponentType } from 'react';
import { AllBaseProps, BaseProps, BaseStyleProps, Props } from './types';
import { Styles, StylesInterface } from './styles/types';
import { ResponsiveStyleValue } from './utils/styles';
declare type StyleList = readonly (keyof {
    [key in keyof StylesInterface]: StylesInterface[key];
})[];
export declare type PropsWithStyles = {
    styles?: Styles;
} & Omit<Props, 'styles'>;
export declare type VariantMap = Record<string, Styles>;
export declare type WithVariant<V extends VariantMap> = {
    variant?: keyof V;
};
export declare type TastyProps<K extends StyleList, V extends VariantMap, DefaultProps = Props> = {
    /** The tag name of the element. */
    as?: string;
    /** Default styles of the element. */
    styles?: Styles;
    /** The list of styles that can be provided by props */
    styleProps?: K;
    element?: BaseProps['element'];
    variants?: V;
} & Partial<Omit<DefaultProps, 'as' | 'styles' | 'styleProps'>> & Pick<BaseProps, 'qa' | 'qaVal'> & WithVariant<V>;
export interface GlobalTastyProps {
    breakpoints?: number[];
}
export declare type AllBasePropsWithMods<K extends StyleList> = AllBaseProps & {
    [key in K[number]]?: ResponsiveStyleValue<StylesInterface[key]>;
} & BaseStyleProps;
declare type TastyComponentPropsWithDefaults<Props extends PropsWithStyles, DefaultProps extends Partial<Props>> = keyof DefaultProps extends never ? Props : {
    [key in Extract<keyof Props, keyof DefaultProps>]?: Props[key];
} & {
    [key in keyof Omit<Props, keyof DefaultProps>]: Props[key];
};
declare function tasty<K extends StyleList, V extends VariantMap>(options: TastyProps<K, V>, secondArg?: never): ComponentType<Omit<Props, 'variant'> & WithVariant<V>>;
declare function tasty(selector: string, styles?: Styles): any;
declare function tasty<Props extends PropsWithStyles, DefaultProps extends Partial<Props> = Partial<Props>>(Component: ComponentType<Props>, options?: TastyProps<never, never, Props>): ComponentType<TastyComponentPropsWithDefaults<Props, DefaultProps>>;
declare const Element: ComponentType<Omit<Props, "variant"> & WithVariant<VariantMap>>;
export { tasty, Element };
